@@ -47,13 +47,7 @@ enum
 // メインビュー
 
 ArticleViewMain::ArticleViewMain( const std::string& url )
-    : ArticleViewBase( url, url ),
-      m_gotonum_reserve_to( 0 ),
-      m_gotonum_reserve_from( 0 ),
-      m_gotonum_seen( 0 ),
-      m_playsound( false ),
-      m_reload_reserve( false ),
-      m_cancel_reload_counter( 0 )
+    : ArticleViewBase( url, url )
 {
 #ifdef _DEBUG
     std::cout << "ArticleViewMain::ArticleViewMain " << get_url() << " url_article = " << url_article() << std::endl;
@@ -81,7 +75,7 @@ ArticleViewMain::~ArticleViewMain()
     std::cout << "ArticleViewMain::~ArticleViewMain : " << get_url() << " url_article = " << url_article() << std::endl;
 #endif
 
-    save_session();
+    ArticleViewMain::save_session();
 
     // 閉じたタブ履歴更新
     HISTORY::append_history( URL_HISTCLOSEVIEW,
@@ -90,7 +84,7 @@ ArticleViewMain::~ArticleViewMain()
 
     CORE::core_set_command( "close_message" ,url_article() );
 
-    if( get_live() ) live_stop();
+    if( get_live() ) ArticleViewMain::live_stop();
 }
 
 
