@@ -108,7 +108,7 @@ namespace ARTICLE
         // HBoxに張り付けるウイジット
         Gtk::DrawingArea m_view;
         Gtk::EventBox* m_event{};
-        Gtk::VScrollbar* m_vscrbar{};
+        Gtk::Scrollbar* m_vscrbar{};
 
         // レイアウトツリー
         LayoutTree* m_layout_tree{};
@@ -122,26 +122,18 @@ namespace ARTICLE
 
         // 描画用
         Glib::RefPtr< Gdk::Window > m_window;
-#if GTKMM_CHECK_VERSION(3,0,0)
+
         // cairomm 1.12.0 がメモリリークを起こしたので
         // C API を使うことで問題を回避する
         std::unique_ptr< cairo_t, void ( * )( cairo_t* ) > m_cr;
         std::unique_ptr< cairo_surface_t, void ( * )( cairo_surface_t* ) > m_backscreen;
-#else
-        Glib::RefPtr< Gdk::GC > m_gc;
-        Glib::RefPtr< Gdk::Pixmap > m_backscreen;
-#endif
+
         Glib::RefPtr< Pango::Layout > m_pango_layout;
         Glib::RefPtr< Pango::Context > m_context;
         RECTANGLE m_rect_backscreen{}; // バックスクリーンが描画されている範囲
         bool m_enable_draw;
         DRAWINFO m_drawinfo{};
 
-        // 高速スクロール描画実行
-        // DrawingAreaの領域が全て表示されているときは Gdk::Window::scroll() を使ってスクロール
-        // 一部が隠れている時はバックスクリーン内でスクロール処理してバックスクリーン全体をウィンドウにコピーする
-        bool m_scroll_window; 
-
         // キャレット情報
         CARET_POSITION m_caret_pos;           // 現在のキャレットの位置(クリックやドラッグすると移動)
         CARET_POSITION m_caret_pos_pre;       // 移動前のキャレットの位置(選択範囲の描画などで使用する)
@@ -150,21 +142,13 @@ namespace ARTICLE
         // 色
         int m_colorid_text{}; // デフォルトの文字色
         int m_colorid_back{}; // デフォルトの背景色
-#if GTKMM_CHECK_VERSION(3,0,0)
         std::vector< Gdk::RGBA > m_color;
-#else
-        std::vector< Gdk::Color > m_color;
-#endif
 
         // 枠
         bool m_draw_frame{};  // 枠を描画する
-#if GTKMM_CHECK_VERSION(3,0,0)
         // 枠線に隠れる部分のバックアップを分ける
         std::unique_ptr< cairo_surface_t, void ( * )( cairo_surface_t* ) > m_back_frame_top;
         std::unique_ptr< cairo_surface_t, void ( * )( cairo_surface_t* ) > m_back_frame_bottom;
-#else
-        Glib::RefPtr< Gdk::Pixmap > m_back_frame; // 枠の背景
-#endif
         bool m_ready_back_frame{};
 
         // 範囲選択
@@ -195,9 +179,7 @@ namespace ARTICLE
         int m_configure_height{};
 
         // スクロール情報
-#if GTKMM_CHECK_VERSION(3,3,18)
         double m_smooth_dy{}; // GDK_SCROLL_SMOOTH のスクロール変化量
-#endif
         SCROLLINFO m_scrollinfo{};
         guint32 m_wheel_scroll_time{}; // 前回ホイールを回した時刻
         int m_goto_num_reserve{}; // 初期化時のジャンプ予約(レス番号)
@@ -205,11 +187,8 @@ namespace ARTICLE
         int m_pre_pos_y; // ひとつ前のスクロールバーの位置。スクロールした時の差分量計算に使用する
         std::vector< int > m_jump_history;  // ジャンプ履歴
         bool m_cancel_change_adjust{}; // adjust の値変更イベントをキャンセル
-#if GTKMM_CHECK_VERSION(3,0,0)
+
         std::unique_ptr< cairo_surface_t, void ( * )( cairo_surface_t* ) > m_back_marker;
-#else
-        Glib::RefPtr< Gdk::Pixmap > m_back_marker; // オートスクロールマーカの背景
-#endif
         RECTANGLE m_clip_marker{};
         bool m_ready_back_marker{};
         time_t m_wait_scroll{};  // 処理落ちした時にスクロールにウエイトを入れる
@@ -226,7 +205,7 @@ namespace ARTICLE
         bool m_r_drugging{}; // 右ドラッグ中
         std::string m_link_current; // 現在マウスポインタの下にあるリンクの文字列
         LAYOUT* m_layout_current{}; // 現在マウスポインタの下にあるlayoutノード(下が空白ならnullptr)
-        Gdk::CursorType m_cursor_type; // カーソルの形状
+        Glib::ustring m_cursor_type; // カーソルの形状
 
         // 入力コントローラ
         CONTROL::Control m_control;
@@ -243,7 +222,6 @@ namespace ARTICLE
         // 自分の書き込みに対するレスマークアイコン
         Glib::RefPtr< Gdk::Pixbuf > m_pixbuf_refer_post;
 
-#if GTKMM_CHECK_VERSION(3,14,0)
         // マウスのクリックとタッチスクリーンのタップ
         Glib::RefPtr< Gtk::GestureMultiPress > m_gesture_multipress;
 
@@ -260,7 +238,6 @@ namespace ARTICLE
             gint64 last_time; // 前回コールバックが呼び出された時間(frame)
             guint id; // コールバックのID
         } m_deceleration{};
-#endif
 
       public:
 
@@ -407,7 +384,7 @@ namespace ARTICLE
         virtual bool slot_configure_event( GdkEventConfigure* event );
 
         Gtk::DrawingArea* get_view(){ return &m_view; }
-        Gtk::VScrollbar* get_vscrbar(){ return m_vscrbar; }
+        Gtk::Scrollbar* get_vscrbar(){ return m_vscrbar; }
 
       private:
 
@@ -478,10 +455,10 @@ namespace ARTICLE
         bool motion_mouse();
 
         // 現在のポインターの下のノードからカーソルのタイプを決定する
-        Gdk::CursorType get_cursor_type();
+        Glib::ustring get_cursor_type();
 
         // カーソルの形状の変更
-        void change_cursor( const Gdk::CursorType type );
+        void change_cursor( const Glib::ustring& cursor_type );
 
         // スクロールマーカの描画
         void draw_marker();
@@ -498,14 +475,9 @@ namespace ARTICLE
 
         // スロット
         void slot_change_adjust();
-#if GTKMM_CHECK_VERSION(3,0,0)
         bool slot_draw( const Cairo::RefPtr< Cairo::Context >& cr );
-#else
-        bool slot_expose_event( GdkEventExpose* event );
-#endif
         bool slot_scroll_event( GdkEventScroll* event );
         bool slot_leave_notify_event( GdkEventCrossing* event );
-        bool slot_visibility_notify_event( GdkEventVisibility* event );
         void slot_realize();
 
         bool slot_button_press_event( GdkEventButton* event );
@@ -515,7 +487,6 @@ namespace ARTICLE
         bool slot_key_press_event( GdkEventKey* event );
         bool slot_key_release_event( GdkEventKey* event );
 
-#if GTKMM_CHECK_VERSION(3,14,0)
         void setup_event_controller();
 
         void slot_multipress_pressed( int n_press, double x, double y );
@@ -531,7 +502,6 @@ namespace ARTICLE
         static gboolean deceleration_tick_cb( GtkWidget* cwidget, GdkFrameClock* clock, gpointer );
         gboolean deceleration_tick_impl( GdkFrameClock* clock );
         void cancel_deceleration();
-#endif
     };
 
 
