@@ -121,7 +121,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
 
     if( CONFIG::get_abone_transparent() || CONFIG::get_abone_chain() ){
         m_label_abone.set_text( "チェック出来ない場合は設定メニューから「デフォルトで透明/連鎖あぼ〜ん」を解除して下さい" );
-        m_label_abone.set_alignment( Gtk::ALIGN_START, Gtk::ALIGN_CENTER );
+        m_label_abone.set_xalign( 0 );
         m_vbox_abone.pack_start( m_label_abone, Gtk::PACK_SHRINK );
     }
 
@@ -200,7 +200,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     const int page_abone = 1;
     m_notebook.append_page( m_notebook_abone, "あぼ〜ん設定" );
 
-    get_vbox()->pack_start( m_notebook );
+    get_content_area()->pack_start( m_notebook );
     set_title( "「" + DBTREE::article_subject( get_url() ) + "」のプロパティ" );
     resize( 600, 400 );
     show_all_children();
@@ -273,5 +273,5 @@ void Preferences::slot_clear_post_history()
     CORE::core_set_command( "redraw_article" );
 
     // BoardViewの行を更新
-    CORE::core_set_command( "update_board_item", DBTREE::url_subject( get_url() ), DBTREE::article_id( get_url() ) );
+    CORE::core_set_command( "update_board_item", DBTREE::url_boardbase( get_url() ), DBTREE::article_id( get_url() ) );
 }
