@@ -26,7 +26,7 @@ namespace ARTICLE
       public:
 
         SearchToolBar();
-        ~SearchToolBar() noexcept {}
+        ~SearchToolBar() noexcept;
 
         // タブが切り替わった時に呼び出される( Viewの情報を取得する )
         void set_view( SKELETON::View * view ) override;
