@@ -45,6 +45,8 @@
 #include "dndmanager.h"
 #include "sign.h"
 
+#include <glib/gi18n.h>
+
 
 enum
 {
@@ -172,9 +174,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     m_treeview.set_show_expanders( CONFIG::get_tree_show_expanders() );
     m_treeview.set_level_indentation( CONFIG::get_tree_level_indent() );
 
-#if GTKMM_CHECK_VERSION(3,3,18)
     m_treeview.add_events( Gdk::SMOOTH_SCROLL_MASK );
-#endif
 
     // treeviewのシグナルにコネクト
     m_treeview.signal_row_expanded().connect( sigc::mem_fun(*this, &BBSListViewBase::slot_row_exp ) );
@@ -616,7 +616,7 @@ void BBSListViewBase::set_fgcolor_of_comment( const Gtk::TreeModel::Children& ch
         Gtk::TreeModel::Row row = *it;
 
         const int type = row2type( row );
-        if( type == TYPE_COMMENT ) row[ m_columns.m_fgcolor ] = Gdk::Color( CONFIG::get_color( COLOR_CHAR_BBS_COMMENT ) );
+        if( type == TYPE_COMMENT ) row[ m_columns.m_fgcolor ] = Gdk::RGBA( CONFIG::get_color( COLOR_CHAR_BBS_COMMENT ) );
         else if( type == TYPE_DIR ) set_fgcolor_of_comment( row.children() );
     }
 }
@@ -1697,7 +1697,7 @@ void BBSListViewBase::check_update_dir( const bool root, const bool open )
 
         if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE ) CORE::get_checkupdate_manager()->push_back( DBTREE::url_dat( url ), open );
         else if( CONFIG::get_check_update_board() && ( type == TYPE_BOARD || type == TYPE_BOARD_UPDATE ) )
-            CORE::get_checkupdate_manager()->push_back( DBTREE::url_subject( url ), open );
+            CORE::get_checkupdate_manager()->push_back( DBTREE::url_boardbase( url ), open );
 
     }
 
@@ -1798,7 +1798,8 @@ void BBSListViewBase::slot_preferences_board()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_BOARD, DBTREE::url_subject( url ) );
+    SKELETON::PrefDiag* pref = CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_BOARD,
+                                                      DBTREE::url_boardbase( url ) );
     pref->run();
     delete pref;
 }
@@ -1874,15 +1875,16 @@ void BBSListViewBase::slot_row_col( const Gtk::TreeModel::iterator&, const Gtk::
 //
 bool BBSListViewBase::open_row( Gtk::TreePath& path, const bool tab )
 {
-    if( ! m_treeview.get_row( path ) ) return false;
+    const Gtk::TreeModel::Row row = m_treeview.get_row( path );
+    if( ! row ) return false;
 
     std::string str_tab = "false";
     if( tab ) str_tab = "opentab";
 
     const std::string str_mode = "";
 
-    const Glib::ustring url = path2url( path );
-    const int type = path2type( path );
+    const std::string url = row2url( row );
+    const int type = row2type( row );
 
     if( type != TYPE_DIR && url.empty() ) return false;
 
@@ -1890,7 +1892,7 @@ bool BBSListViewBase::open_row( Gtk::TreePath& path, const bool tab )
 
         case TYPE_BOARD:
         case TYPE_BOARD_UPDATE:
-            CORE::core_set_command( "open_board", DBTREE::url_subject( url ), str_tab, str_mode );
+            CORE::core_set_command( "open_board", url, str_tab, str_mode );
             break;
 
         case TYPE_THREAD_OLD:
@@ -1898,7 +1900,7 @@ bool BBSListViewBase::open_row( Gtk::TreePath& path, const bool tab )
             // fallthrough
         case TYPE_THREAD:
         case TYPE_THREAD_UPDATE:
-            CORE::core_set_command( "open_article", DBTREE::url_dat( url ), str_tab, str_mode );
+            CORE::core_set_command( "open_article", url, str_tab, str_mode );
             break;
 
         case TYPE_IMAGE:
@@ -1960,31 +1962,25 @@ void BBSListViewBase::open_selected_rows()
     std::string list_url_board;
     std::string list_url_article;
 
-    std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
-    std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
-    for( ; it != list_it.end(); ++it ){
+    for( Gtk::TreeIter& iter : m_treeview.get_selected_iterators() ) {
 
-        Gtk::TreeModel::Row row = *( *it );
-        Gtk::TreePath path = GET_PATH( row );
-
-        int type = path2type( path );
-        std::string url = path2url( path );
+        Gtk::TreeModel::Row row = *iter;
+        const int type = row2type( row );
+        const std::string url = row2url( row );
 
         switch( type ){
 
             case TYPE_BOARD:
             case TYPE_BOARD_UPDATE:
-                url = DBTREE::url_subject( url );
-                if( !list_url_board.empty() ) list_url_board += " ";
-                list_url_board += url;
+                if( ! list_url_board.empty() ) list_url_board.push_back( ' ' );
+                list_url_board.append( url );
                 break;
 
             case TYPE_THREAD:
             case TYPE_THREAD_UPDATE:
             case TYPE_THREAD_OLD:
-                url = DBTREE::url_dat( url );
-                if( !list_url_article.empty() ) list_url_article += " ";
-                list_url_article += url;
+                if( ! list_url_article.empty() ) list_url_article.push_back( ' ' );
+                list_url_article.append( url );
                 break;
 
             case TYPE_IMAGE:
@@ -2006,19 +2002,18 @@ void BBSListViewBase::open_selected_rows()
 //
 void BBSListViewBase::checkupdate_selected_rows( const bool open )
 {
-    std::list< Gtk::TreeModel::iterator > list_it = m_treeview.get_selected_iterators();
-    std::list< Gtk::TreeModel::iterator >::iterator it = list_it.begin();
-    for( ; it != list_it.end(); ++it ){
+    for( Gtk::TreeIter& iter : m_treeview.get_selected_iterators() ) {
 
-        Gtk::TreeModel::Row row = *( *it );
-        Gtk::TreePath path = GET_PATH( row );
+        Gtk::TreeModel::Row row = *iter;
+        const int type = row2type( row );
+        const std::string url = row2url( row );
 
-        int type = path2type( path );
-        std::string url = path2url( path );
-
-        if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE ) CORE::get_checkupdate_manager()->push_back( DBTREE::url_dat( url ), open );
-        else if( CONFIG::get_check_update_board() && ( type == TYPE_BOARD || type == TYPE_BOARD_UPDATE ) )
-            CORE::get_checkupdate_manager()->push_back( DBTREE::url_subject( url ), open );
+        if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE ) {
+            CORE::get_checkupdate_manager()->push_back( url, open );
+        }
+        else if( CONFIG::get_check_update_board() && ( type == TYPE_BOARD || type == TYPE_BOARD_UPDATE ) ) {
+            CORE::get_checkupdate_manager()->push_back( url, open );
+        }
     }
 }
 
@@ -2046,32 +2041,21 @@ void BBSListViewBase::slot_sort( const int mode )
 //
 // path -> url 変換
 //
-Glib::ustring BBSListViewBase::path2rawurl( const Gtk::TreePath& path )
+std::string BBSListViewBase::path2rawurl( const Gtk::TreePath& path )
 {
-    Gtk::TreeModel::Row row = m_treeview.get_row( path );
-    if( !row ) return Glib::ustring();
-    Glib::ustring url =  row[ m_columns.m_url ];
-    return url;
+    const Gtk::TreeModel::Row row = m_treeview.get_row( path );
+    return row2url( row );
 }
 
 
 // 移転をチェックするバージョン
-Glib::ustring BBSListViewBase::path2url( const Gtk::TreePath& path )
+std::string BBSListViewBase::path2url( const Gtk::TreePath& path )
 {
-    Gtk::TreeModel::Row row = m_treeview.get_row( path );
-    if( !row ) return Glib::ustring();
+    const Gtk::TreeModel::Row row = m_treeview.get_row( path );
+    std::string url = row2url( row );
 
-    Glib::ustring url =  row[ m_columns.m_url ];
-    if( url.empty() ) return url;
-
-    // 移転があったら url を最新のものに変換しておく
-    int type = path2type( path );
-    switch( type ){
-
-        case TYPE_BOARD:
-        case TYPE_BOARD_UPDATE:
-            url = DBTREE::url_boardbase( url );
-            break;
+    // url を最新のものに変換しておく
+    switch( row2type( row ) ){
 
         case TYPE_THREAD:
         case TYPE_THREAD_UPDATE:
@@ -2090,30 +2074,11 @@ Glib::ustring BBSListViewBase::path2url( const Gtk::TreePath& path )
 // 板の場合は boardbase
 // スレの場合は dat 型のアドレスを返す
 //
-Glib::ustring BBSListViewBase::row2url( const Gtk::TreeModel::Row& row )
+std::string BBSListViewBase::row2url( const Gtk::TreeModel::Row& row )
 {
-    if( ! row ) return Glib::ustring();
-
-    Glib::ustring url =  row[ m_columns.m_url ];
-    if( url.empty() ) return url;
-
-    // 移転があったら url を最新のものに変換しておく
-    int type = row2type( row );
-    switch( type ){
-
-        case TYPE_BOARD:
-        case TYPE_BOARD_UPDATE:
-            url = DBTREE::url_boardbase( url );
-            break;
-
-        case TYPE_THREAD:
-        case TYPE_THREAD_UPDATE:
-        case TYPE_THREAD_OLD:
-            url = DBTREE::url_dat( url );
-            break;
-    }
-
-    return url;
+    if( ! row ) return {};
+    const Glib::ustring& ustr_url = row[ m_columns.m_url ];
+    return ustr_url.raw();
 }
 
 
@@ -2121,23 +2086,32 @@ Glib::ustring BBSListViewBase::row2url( const Gtk::TreeModel::Row& row )
 //
 // path -> name 変換
 //
-Glib::ustring BBSListViewBase::path2name( const Gtk::TreePath& path )
+std::string BBSListViewBase::path2name( const Gtk::TreePath& path )
 {
-    Gtk::TreeModel::Row row = m_treeview.get_row( path );
-    if( !row ) return Glib::ustring();
-    return row[ m_columns.m_name ];
+    const Gtk::TreeModel::Row row = m_treeview.get_row( path );
+    return row2name( row );
 }
 
 
 
+//
+// row -> name 変換
+//
+std::string BBSListViewBase::row2name( const Gtk::TreeModel::Row& row )
+{
+    if( ! row ) return {};
+    const Glib::ustring& ustr_name = row[ m_columns.m_name ];
+    return ustr_name.raw();
+}
+
+
 //
 // path -> type 変換
 //
 int BBSListViewBase::path2type( const Gtk::TreePath& path )
 {
-    Gtk::TreeModel::Row row = m_treeview.get_row( path );
-    if( !row ) return TYPE_UNKNOWN;
-    return row[ m_columns.m_type ];
+    const Gtk::TreeModel::Row row = m_treeview.get_row( path );
+    return row2type( row );
 }
 
 
@@ -2151,16 +2125,6 @@ int BBSListViewBase::row2type( const Gtk::TreeModel::Row& row )
 }
 
 
-//
-// row -> name 変換
-//
-Glib::ustring BBSListViewBase::row2name( const Gtk::TreeModel::Row& row )
-{
-    if( !row ) return Glib::ustring();
-    return row[ m_columns.m_name ];
-}
-
-
 //
 // row -> dirid 変換
 //
@@ -2630,8 +2594,8 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
                                                       Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE
                             );
 
-                        mdiag.add_default_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
-                        mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+                        mdiag.add_default_button( g_dgettext( GTK_DOMAIN, "_No" ), Gtk::RESPONSE_NO );
+                        mdiag.add_button( g_dgettext( GTK_DOMAIN, "_Yes" ), Gtk::RESPONSE_YES );
                         mdiag.add_button( "新スレをお気に入りに追加(_F)", Gtk::RESPONSE_CANCEL );
 
                         mdiag.set_title( "お気に入り更新" );
@@ -2667,7 +2631,7 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
 #ifdef _DEBUG
                         std::cout << "name_row = " << ustr_name << std::endl;
 #endif
-                        if( ustr_name.raw() == name_old ){
+                        if( MISC::remove_space( ustr_name ) == name_old ){
 #ifdef _DEBUG
                             std::cout << "replace name\n";
 #endif
@@ -2709,9 +2673,6 @@ void BBSListViewBase::replace_thread( const std::string& url, const std::string&
 //
 void BBSListViewBase::exec_search()
 {
-    JDLIB::Regex regex_name;
-    JDLIB::Regex regex_url;
-
     CORE::core_set_command( "set_info", "", "" );
 
     std::string query = get_search_query();
@@ -2740,17 +2701,19 @@ void BBSListViewBase::exec_search()
     std::cout << "BBSListViewBase::exec_search() path = " << path.to_string() << " query = " << query << std::endl;
 #endif
 
-    const bool icase_name = true; // 大文字小文字区別しない
-    const bool newline_name = true; // . に改行をマッチさせない
-    const bool usemigemo_name = true; // migemo使用
-    const bool wchar_name = true;  // 全角半角の区別をしない
-    regex_name.compile( query, icase_name, newline_name, usemigemo_name, wchar_name );
+    constexpr bool icase_name = true; // 大文字小文字区別しない
+    constexpr bool newline_name = true; // . に改行をマッチさせない
+    constexpr bool usemigemo_name = true; // migemo使用
+    constexpr bool wchar_name = true;  // 全角半角の区別をしない
+    const JDLIB::RegexPattern regex_name( query, icase_name, newline_name, usemigemo_name, wchar_name );
 
-    const bool icase_url = true; // 大文字小文字区別しない
-    const bool newline_url = true;
-    const bool usemigemo_url = false;
-    const bool wchar_url = false;
-    regex_url.compile( query, icase_url, newline_url, usemigemo_url, wchar_url );
+    constexpr bool icase_url = true; // 大文字小文字区別しない
+    constexpr bool newline_url = true;
+    constexpr bool usemigemo_url = false;
+    constexpr bool wchar_url = false;
+    const JDLIB::RegexPattern regex_url( query, icase_url, newline_url, usemigemo_url, wchar_url );
+
+    JDLIB::Regex regex;
 
     bool hit = false;
     for(;;){
@@ -2781,11 +2744,11 @@ void BBSListViewBase::exec_search()
             else path = m_treeview.prev_path( path, false );
         }
 
-        Glib::ustring name = path2name( path );
-        Glib::ustring url = path2url( path );
+        const std::string name = path2name( path );
+        const std::string url = path2url( path );
 
         const size_t offset = 0;
-        if( regex_name.exec( name, offset ) || regex_url.exec( url, offset ) ) hit = true;
+        if( regex.match( regex_name, name, offset ) || regex.match( regex_url, url, offset ) ) hit = true;
 
         // 一周したら終わり
         if( path == path_start ) break;
