@@ -25,7 +25,7 @@ namespace BBSLIST
 
       public:
 
-        EditListWin( const std::string& url, Glib::RefPtr< Gtk::TreeStore >& treestore );
+        EditListWin( const std::string& url, const Glib::RefPtr< Gtk::TreeStore >& treestore );
         ~EditListWin() noexcept;
 
         void clock_in();
