@@ -125,8 +125,8 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
     // 次スレ検索ビューのようにURLの途中に http が入っている場合は取り除く
     size_t pos = url.rfind( "http://" );
     if( pos == std::string::npos || pos == 0 ) pos = url.rfind( "https://" );
-    if( pos != std::string::npos && pos != 0 ) m_url_board = DBTREE::url_subject( url.substr( 0, pos ) );
-    else m_url_board = DBTREE::url_subject( url );
+    if( pos != std::string::npos && pos != 0 ) m_url_board = DBTREE::url_boardbase( url.substr( 0, pos ) );
+    else m_url_board = DBTREE::url_boardbase( url );
 
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
@@ -162,9 +162,7 @@ BoardViewBase::BoardViewBase( const std::string& url, const bool show_col_board
     m_liststore->set_sort_func( COL_SPEED, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
     m_liststore->set_sort_func( COL_DIFF, sigc::mem_fun( *this, &BoardViewBase::slot_compare_row ) );
 
-#if GTKMM_CHECK_VERSION(3,3,18)
     m_treeview.add_events( Gdk::SMOOTH_SCROLL_MASK );
-#endif
 
     m_treeview.sig_button_press().connect( sigc::mem_fun(*this, &BoardViewBase::slot_button_press ) );
     m_treeview.sig_button_release().connect( sigc::mem_fun(*this, &BoardViewBase::slot_button_release ) );
@@ -239,7 +237,7 @@ int BoardViewBase::get_icon( const std::string& iconname ) const
 //
 std::string BoardViewBase::url_for_copy() const
 {
-    return DBTREE::url_boardbase( get_url_board() );
+    return get_url_board();
 }
 
 
@@ -652,10 +650,8 @@ void BoardViewBase::update_columns()
 
         // ヘッダをクリックしたときに呼ぶslot
         column->signal_clicked().connect( sigc::bind< int >( sigc::mem_fun( *this, &BoardViewBase::slot_col_clicked ), id ) );
-#if GTKMM_CHECK_VERSION(3,0,0)
         // 列の幅が変わったらセッション情報に記憶する
         column->connect_property_changed( "width", [this]{ save_column_width(); } );
-#endif
 
         // ヘッダの位置
         switch( id ){
@@ -1338,6 +1334,8 @@ void BoardViewBase::update_status()
 //
 void BoardViewBase::select_item( const std::string& url )
 {
+    if( m_url_board != DBTREE::url_boardbase( url ) ) return;
+
     const Gtk::TreeModel::Row row = get_row_from_url( url );
     if( row ){
         Gtk::TreePath path = GET_PATH( row );
@@ -1753,7 +1751,7 @@ Gtk::Menu* BoardViewBase::get_popupmenu( const std::string& url )
 //
 // 特定の行だけの表示内容更新
 //
-// url : subject.txt のアドレス
+// url : boardbase アドレス
 // id : DAT の ID(拡張子付き), empty なら全ての行の表示内容を更新する
 //
 void BoardViewBase::update_item( const std::string& url, const std::string& id )
@@ -2265,12 +2263,6 @@ void BoardViewBase::slot_dropped_url_list( const std::list< std::string >& url_l
         CORE::DATA_INFO info;
         info.type = TYPE_FILE;
         info.url = MISC::remove_str( ( *it ), "file://" );
-#ifdef _WIN32
-        // 「file:///C:/hoge/123456789.dat」などの場合、追加の/を削除する。
-        if( ( info.url[ 0 ] == '/' && isalpha( info.url[ 1 ] ) && info.url[ 2 ] == ':' ) ){
-            info.url = info.url.erase( 0, 1 );
-        }
-#endif
         list_info.push_back( info );
 
 #ifdef _DEBUG
@@ -2560,7 +2552,7 @@ std::string BoardViewBase::path2url_board( const Gtk::TreePath& path )
 {
     if( ! get_url_board().empty() ) return get_url_board();
     if( path.empty() ) return std::string();
-    return DBTREE::url_subject( path2daturl( path ) );
+    return DBTREE::url_boardbase( path2daturl( path ) );
 }
 
 
@@ -2584,15 +2576,16 @@ bool BoardViewBase::drawout( const bool force_reset )
     unsorted_column();
 
     JDLIB::Regex regex;
-    const bool icase = true; // 大文字小文字区別しない
-    const bool newline = true; // . に改行をマッチさせない
-    const bool usemigemo = true; // migemo使用
-    const bool wchar = true;  // 全角半角の区別をしない
+    JDLIB::RegexPattern regexptn;
+    constexpr bool icase = true; // 大文字小文字区別しない
+    constexpr bool newline = true; // . に改行をマッチさせない
+    constexpr bool usemigemo = true; // migemo使用
+    constexpr bool wchar = true;  // 全角半角の区別をしない
 
     Gtk::TreeModel::Children child = m_liststore->children();
     Gtk::TreeModel::Children::iterator it = child.begin();
 
-    if ( ! reset ) regex.compile( query, icase, newline, usemigemo, wchar );
+    if ( ! reset ) regexptn.set( query, icase, newline, usemigemo, wchar );
 
     for( ; it != child.end() ; ++it ){
 
@@ -2600,7 +2593,7 @@ bool BoardViewBase::drawout( const bool force_reset )
         const Glib::ustring subject = row[ m_columns.m_col_subject ];
 
         if( reset ) row[ m_columns.m_col_drawbg ] = false;
-        else if( regex.exec( subject, 0 ) ){
+        else if( regex.match( regexptn, subject, 0 ) ){
             row[ m_columns.m_col_drawbg ] = true;
             ++hit;
 
@@ -2668,11 +2661,11 @@ void BoardViewBase::exec_search()
 
     Gtk::TreePath path_start = path;
     JDLIB::Regex regex;
-    const size_t offset = 0;
-    const bool icase = true; // 大文字小文字区別しない
-    const bool newline = true; // . に改行をマッチさせない
-    const bool usemigemo = true; // migemo使用
-    const bool wchar = true;  // 全角半角の区別をしない
+    constexpr size_t offset = 0;
+    constexpr bool icase = true; // 大文字小文字区別しない
+    constexpr bool newline = true; // . に改行をマッチさせない
+    constexpr bool usemigemo = true; // migemo使用
+    constexpr bool wchar = true;  // 全角半角の区別をしない
 
 #ifdef _DEBUG
     std::cout << "BoardViewBase::search start = " << path_start.to_string() << " query = " <<  query << std::endl;
@@ -2939,7 +2932,7 @@ void BoardViewBase::slot_search_next()
     if( m_path_selected.empty() ) return;
     const std::string url = path2daturl( m_path_selected );
 
-    CORE::core_set_command( "open_board_next", DBTREE::url_subject( url ) , url );
+    CORE::core_set_command( "open_board_next", DBTREE::url_boardbase( url ), url );
 }
 
 
