@@ -7,7 +7,8 @@
 
 #include "boardviewbase.h"
 
-#include "jdlib/hash_set.h"
+#include <string>
+#include <unordered_set>
 
 namespace BOARD
 {
@@ -18,7 +19,7 @@ namespace BOARD
 
         bool m_set_history;
 
-        JDLIB::hash_set_thread m_set_thread;
+        std::unordered_set< std::string > m_set_thread;
 
       public:
 
