@@ -109,7 +109,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
         str_cookies = "クッキー:\n未取得\n";
     }
     else {
-        str_cookies = "クッキー:\n" + MISC::Iconv( temp_cookies, DBTREE::board_charset( get_url() ), "UTF-8" ) + "\n";
+        str_cookies = "クッキー:\n" + MISC::Iconv( temp_cookies, "UTF-8", DBTREE::board_charset( get_url() ) ) + "\n";
     }
 
     std::string keyword = DBTREE::board_keyword_for_write( get_url() );
@@ -357,7 +357,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_notebook.append_page( m_edit_settingtxt, "SETTING.TXT" );
     m_notebook.signal_switch_page().connect( sigc::mem_fun( *this, &Preferences::slot_switch_page ) );
 
-    get_vbox()->pack_start( m_notebook );
+    get_content_area()->pack_start( m_notebook );
     set_title( "「" + DBTREE::board_name( get_url() ) + "」のプロパティ" );
     resize( 600, 400 );
     show_all_children();
@@ -405,7 +405,7 @@ void Preferences::slot_clear_post_history()
     DBTREE::board_clear_all_post_history( get_url() );
 
     // スレ一覧とスレビューの表示更新
-    CORE::core_set_command( "update_board", DBTREE::url_subject( get_url() ) );
+    CORE::core_set_command( "update_board", DBTREE::url_boardbase( get_url() ) );
     CORE::core_set_command( "redraw_article" );
 }
 
@@ -459,7 +459,7 @@ void Preferences::slot_remove_old_title()
 }
 
 
-void Preferences::slot_switch_page( GtkNotebookPage*, guint page )
+void Preferences::slot_switch_page( Gtk::Widget*, guint page )
 {
     if( m_notebook.get_nth_page( page ) == m_localrule ){
         m_localrule->set_command( "clear_screen" );
