@@ -19,6 +19,7 @@
 
 #include "dbtree/interface.h"
 
+#include <glib/gi18n.h>
 #include <gtkmm.h>
 
 #include <fstream>
@@ -30,9 +31,7 @@
 
 #include <fcntl.h>
 #include <cstring>
-#if defined(_WIN32)
-#include <utime.h>
-#endif
+
 
 enum
 {
@@ -154,6 +153,13 @@ std::string CACHE::path_linkfilter()
 }
 
 
+// 文字列置換設定ファイル
+std::string CACHE::path_replacestr()
+{
+    return CACHE::path_root() + "replacestr.xml";
+}
+
+
 // URL変換設定ファイル
 std::string CACHE::path_urlreplace()
 {
@@ -749,14 +755,6 @@ int CACHE::file_exists( const std::string& path )
     if( path.empty() ) return EXIST_ERROR;
 
     std::string path_s = path;
-#ifdef _WIN32
-    // on windows fail stat() directory path with ends '/'
-    // "c:/" = ok, "c:" = fail
-    // "c:/dir/" = fail, "c:/dir" = ok
-    if( path.length() > 3 && path[ path.length() - 1 ] == '/' ){
-        path_s = path.substr( 0, path.length() - 1 );
-    }
-#endif
     if( stat( to_locale_cstr( path_s ), &buf_stat ) != 0 ) return EXIST_ERROR;
 
     if( S_ISREG( buf_stat.st_mode ) ) return EXIST_FILE;
@@ -799,15 +797,6 @@ bool CACHE::set_filemtime( const std::string& path, const time_t mtime )
     if( stat( to_locale_cstr( path ), &buf_stat ) != 0 ) return false;
     if( S_ISREG( buf_stat.st_mode ) ){
 
-#if defined(_WIN32)
-        struct utimbuf tb;
-
-        tb.actime = buf_stat.st_atime;
-        tb.modtime = mtime;
-
-        if( ! utime( to_locale_cstr( path ), &tb ) ) return true;
-
-#else // WIN32
         struct timeval tv[2];
 
         tv[0].tv_sec  = buf_stat.st_atime;
@@ -816,7 +805,6 @@ bool CACHE::set_filemtime( const std::string& path, const time_t mtime )
         tv[1].tv_usec = 0;
 
         if( ! utimes( to_locale_cstr( path ), tv ) ) return true;
-#endif // WIN32
     }
 
     return false;
@@ -844,12 +832,7 @@ bool CACHE::jdmkdir( const std::string& path )
         target = homedir + path.substr( 2 );
     }
 
-#ifdef _WIN32
-    // on windows has case of start drive letter "c:/...", or UNC "//pcname/..."
-    if( target[ 0 ] != '/' && target[ 1 ] != ':' ) return false;
-#else
     if( target[ 0 ] != '/' ) return false;
-#endif
     if( target[ target.length() -1 ] != '/' ) target += "/";
 
 #ifdef _DEBUG
@@ -870,11 +853,7 @@ bool CACHE::jdmkdir( const std::string& path )
         
         if( CACHE::file_exists( currentdir ) == EXIST_DIR ) continue;
 
-#ifdef _WIN32
-        if( mkdir( to_locale_cstr( currentdir ) ) != 0 ){
-#else
         if( mkdir( to_locale_cstr( currentdir ), 0755 ) != 0 ){
-#endif
             MISC::ERRMSG( "mkdir failed " + currentdir );
             return false;
         }
@@ -976,45 +955,25 @@ void CACHE::add_filter_to_diag( Gtk::FileChooserDialog& diag, const int type )
 {
     if( type == FILE_TYPE_ALL ) return;
 
-#if GTKMM_CHECK_VERSION(3,0,0)
     Glib::RefPtr< Gtk::FileFilter > filter = Gtk::FileFilter::create();
-#else
-    Gtk::FileFilter filter;
-#endif
     switch( type ) 
     {
         case FILE_TYPE_TEXT:
-#if GTKMM_CHECK_VERSION(3,0,0)
             filter->set_name( "全てのテキストファイル" );
             filter->add_mime_type( "text/plain" );
-#else
-            filter.set_name( "全てのテキストファイル" );
-            filter.add_mime_type( "text/plain" );
-#endif
             diag.add_filter( filter );
             break;
 
         case FILE_TYPE_DAT:
-#if GTKMM_CHECK_VERSION(3,0,0)
             filter->set_name( "全てのDATファイル" );
             filter->add_pattern( "*.dat" );
-#else
-            filter.set_name( "全てのDATファイル" );
-            filter.add_pattern( "*.dat" );
-#endif
             diag.add_filter( filter );
             break;
     }
 
-#if GTKMM_CHECK_VERSION(3,0,0)
     Glib::RefPtr< Gtk::FileFilter > all = Gtk::FileFilter::create();
     all->set_name( "全てのファイル" );
     all->add_pattern( "*" );
-#else
-    Gtk::FileFilter all;
-    all.set_name( "全てのファイル" );
-    all.add_pattern( "*" );
-#endif
     diag.add_filter( all );
 }
 
@@ -1091,8 +1050,8 @@ std::string CACHE::open_save_diag( Gtk::Window* parent, const std::string& dir,
 
         SKELETON::MsgDiag mdiag( parent, "ファイルが存在します。ファイル名を変更して保存しますか？", 
                                  false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
-        mdiag.add_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
-        mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+        mdiag.add_button( g_dgettext( GTK_DOMAIN, "_No" ), Gtk::RESPONSE_NO );
+        mdiag.add_button( g_dgettext( GTK_DOMAIN, "_Yes" ), Gtk::RESPONSE_YES );
         mdiag.add_button( "上書き", Gtk::RESPONSE_YES + 100 );
 
         int ret = mdiag.run();
@@ -1179,12 +1138,7 @@ std::string CACHE::get_realpath( const std::string& path )
     std::string path_real;
 
     char resolved_path[ PATH_MAX + 1 ];
-#ifdef _WIN32
-    // _fullpath() are not checked　the path is completely available
-    char* ret = _fullpath( resolved_path, to_locale_cstr( path ), PATH_MAX );
-#else
     char* ret = realpath( to_locale_cstr( path ), resolved_path );
-#endif
     if( ret ){
         path_real = ret;
     }
