@@ -70,14 +70,12 @@ void AboutConfig::pack_widgets()
     m_scrollwin.add( m_treeview );
     m_scrollwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
 
-    get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_label, Gtk::PACK_SHRINK );
-    get_vbox()->pack_start( m_scrollwin );
+    get_content_area()->set_spacing( 8 );
+    get_content_area()->pack_start( m_label, Gtk::PACK_SHRINK );
+    get_content_area()->pack_start( m_scrollwin );
 
     set_title( "about:config 高度な設定" );
-#if GTKMM_CHECK_VERSION(3,0,0)
     set_default_size_ratio( 0.666 );
-#endif
     show_all_children();
 
     append_rows();
