@@ -106,7 +106,7 @@ bool CONFIG::get_tree_show_expanders(){ return get_confitem()->tree_show_expande
 // ツリービューのレベルインデント調整量(ピクセル)
 int CONFIG::get_tree_level_indent(){ return get_confitem()->tree_level_indent; }
 
-// カテゴリを開いたときにツリービューをスクロールする
+// カテゴリやディレクトリを開いたときにツリービューをスクロールする
 bool CONFIG::get_scroll_tree(){ return get_confitem()->scroll_tree; }
 
 // ツリービューの選択を表示中のビューと同期する ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
@@ -161,14 +161,11 @@ const std::string& CONFIG::get_url_jdimhp() { return get_confitem()->url_jdimhp;
 // 2chの認証サーバのアドレス
 const std::string& CONFIG::get_url_login2ch() { return get_confitem()->url_login2ch; }
 
-// p2の認証サーバのアドレス
-const std::string& CONFIG::get_url_loginp2() { return get_confitem()->url_loginp2; }
-void CONFIG::set_url_loginp2( const std::string& url ) { get_confitem()->url_loginp2 = url; }
-
 // BEの認証サーバのアドレス
 const std::string& CONFIG::get_url_loginbe() { return get_confitem()->url_loginbe; }
 
 const std::string& CONFIG::get_url_bbsmenu() { return get_confitem()->url_bbsmenu; }
+void CONFIG::set_url_bbsmenu( std::string url ) { get_confitem()->url_bbsmenu = std::move( url ); }
 
 bool CONFIG::use_link_as_board(){ return get_confitem()->use_link_as_board; }
 
@@ -182,32 +179,34 @@ const std::string& CONFIG::get_regex_search_title(){ return get_confitem()->rege
 const std::string& CONFIG::get_menu_search_web(){ return get_confitem()->menu_search_web; }
 const std::string& CONFIG::get_url_search_web(){ return get_confitem()->url_search_web; }
 
-const std::string& CONFIG::get_url_writep2(){ return get_confitem()->url_writep2; }
-const std::string& CONFIG::get_url_resp2(){ return get_confitem()->url_resp2; }
-
 const std::string& CONFIG::get_agent_for2ch() { return get_confitem()->agent_for2ch; }
 
 bool CONFIG::get_use_proxy_for2ch() { return get_confitem()->use_proxy_for2ch; }
+bool CONFIG::get_send_cookie_to_proxy_for2ch() { return get_confitem()->send_cookie_to_proxy_for2ch; }
 const std::string& CONFIG::get_proxy_for2ch() { return get_confitem()->proxy_for2ch; }
 int CONFIG::get_proxy_port_for2ch() { return get_confitem()->proxy_port_for2ch; }
 const std::string& CONFIG::get_proxy_basicauth_for2ch() { return get_confitem()->proxy_basicauth_for2ch; }
 
 void CONFIG::set_use_proxy_for2ch( bool set ){ get_confitem()->use_proxy_for2ch = set; }
+void CONFIG::set_send_cookie_to_proxy_for2ch( bool set ){ get_confitem()->send_cookie_to_proxy_for2ch = set; }
 void CONFIG::set_proxy_for2ch( const std::string& proxy ){ get_confitem()->set_proxy_for2ch( proxy ); }
 void CONFIG::set_proxy_port_for2ch( int port ){ get_confitem()->proxy_port_for2ch = port; }
 
 bool CONFIG::get_use_proxy_for2ch_w() { return get_confitem()->use_proxy_for2ch_w; }
+bool CONFIG::get_send_cookie_to_proxy_for2ch_w() { return get_confitem()->send_cookie_to_proxy_for2ch_w; }
 const std::string& CONFIG::get_proxy_for2ch_w() { return get_confitem()->proxy_for2ch_w; }
 int CONFIG::get_proxy_port_for2ch_w() { return get_confitem()->proxy_port_for2ch_w; }
 const std::string& CONFIG::get_proxy_basicauth_for2ch_w() { return get_confitem()->proxy_basicauth_for2ch_w; }
 
 void CONFIG::set_use_proxy_for2ch_w( bool set ){ get_confitem()->use_proxy_for2ch_w = set; }
+void CONFIG::set_send_cookie_to_proxy_for2ch_w( bool set ){ get_confitem()->send_cookie_to_proxy_for2ch_w = set; }
 void CONFIG::set_proxy_for2ch_w( const std::string& proxy ){ get_confitem()->set_proxy_for2ch_w( proxy ); }
 void CONFIG::set_proxy_port_for2ch_w( int port ){ get_confitem()->proxy_port_for2ch_w = port; }
 
 const std::string& CONFIG::get_agent_for_data() { return get_confitem()->agent_for_data; }
 
 bool CONFIG::get_use_proxy_for_data() { return get_confitem()->use_proxy_for_data; }
+bool CONFIG::get_send_cookie_to_proxy_for_data() { return get_confitem()->send_cookie_to_proxy_for_data; }
 const std::string& CONFIG::get_proxy_for_data() { return get_confitem()->proxy_for_data; }
 int CONFIG::get_proxy_port_for_data() { return get_confitem()->proxy_port_for_data; }
 const std::string& CONFIG::get_proxy_basicauth_for_data() { return get_confitem()->proxy_basicauth_for_data; }
@@ -215,6 +214,7 @@ const std::string& CONFIG::get_proxy_basicauth_for_data() { return get_confitem(
 const std::string& CONFIG::get_x_2ch_ua() { return get_confitem()->x_2ch_ua; }
 
 void CONFIG::set_use_proxy_for_data( bool set ){ get_confitem()->use_proxy_for_data = set; }
+void CONFIG::set_send_cookie_to_proxy_for_data( bool set ){ get_confitem()->send_cookie_to_proxy_for_data = set; }
 void CONFIG::set_proxy_for_data( const std::string& proxy ){ get_confitem()->set_proxy_for_data( proxy ); }
 void CONFIG::set_proxy_port_for_data( int port ){ get_confitem()->proxy_port_for_data = port; }
 
@@ -232,16 +232,13 @@ void CONFIG::set_use_ipv6( const bool set ){ get_confitem()->use_ipv6 = set; }
 // 同一ホストに対する最大コネクション数( 1 または 2 )
 int CONFIG::get_connection_num(){ return get_confitem()->connection_num; }
 
-// 2chのクッキー:HAP
+// 2chのクッキー (互換性のため設定名は旧名称を使う)
 bool CONFIG::get_use_cookie_hap(){ return get_confitem()->use_cookie_hap; }
 const std::string& CONFIG::get_cookie_hap(){ return get_confitem()->cookie_hap; }
 const std::string& CONFIG::get_cookie_hap_bbspink(){ return get_confitem()->cookie_hap_bbspink; }
 void CONFIG::set_cookie_hap( const std::string& cookie_hap ){ get_confitem()->cookie_hap = cookie_hap; }
 void CONFIG::set_cookie_hap_bbspink( const std::string& cookie_hap ){ get_confitem()->cookie_hap_bbspink = cookie_hap; }
 
-// 2chの過去ログ取得時にofflaw2を使用する
-bool CONFIG::get_use_offlaw2_2ch(){ return get_confitem()->use_offlaw2_2ch; }
-
 const std::string& CONFIG::get_command_openurl() { return get_confitem()->command_openurl; }
 void CONFIG::set_command_openurl( const std::string& command ){ get_confitem()->command_openurl = command; }
 
