@@ -65,7 +65,7 @@ namespace CONFIG
     // ツリービューのレベルインデント調整量(ピクセル)
     int get_tree_level_indent();
 
-    // カテゴリを開いたときにツリービューをスクロールする
+    // カテゴリやディレクトリを開いたときにツリービューをスクロールする
     bool get_scroll_tree();
 
     // ツリービューの選択を表示中のビューと同期する ( 0: 同期しない 1: 同期する 2: 同期する(フォルダを開く) )
@@ -105,15 +105,15 @@ namespace CONFIG
     // 2chの認証サーバのアドレス
     const std::string& get_url_login2ch();
 
-    // p2の認証サーバのアドレス
-    const std::string& get_url_loginp2();
-    void set_url_loginp2( const std::string& url );
+    const std::string& get_url_loginp2() = delete; // Removed in v0.3.0 (2020-05)
+    void set_url_loginp2( const std::string& url ) = delete; // Removed in v0.3.0 (2020-05)
 
     // BEの認証サーバのアドレス
     const std::string& get_url_loginbe();
 
     // bbsmenu.htmlのURL
-    const std::string& get_url_bbsmenu();    
+    const std::string& get_url_bbsmenu();
+    void set_url_bbsmenu( std::string url );
 
     // bbsmenu.html内にあるリンクは全て板とみなす
     bool use_link_as_board();
@@ -133,9 +133,8 @@ namespace CONFIG
     const std::string& get_menu_search_web();
     const std::string& get_url_search_web();
 
-    // p2 書き込み用アドレス
-    const std::string& get_url_writep2();
-    const std::string& get_url_resp2();
+    const std::string& get_url_writep2() = delete; // Removed in v0.3.0 (2020-05)
+    const std::string& get_url_resp2() = delete; // Removed in v0.3.0 (2020-05)
 
     // 2ch にアクセスするときのエージェント名
     const std::string& get_agent_for2ch();
@@ -145,21 +144,25 @@ namespace CONFIG
 
     // 2ch 読み込み用プロクシとポート番号
     bool get_use_proxy_for2ch();
+    bool get_send_cookie_to_proxy_for2ch();
     const std::string& get_proxy_for2ch();
     int get_proxy_port_for2ch();
     const std::string& get_proxy_basicauth_for2ch();
 
     void set_use_proxy_for2ch( const bool set );
+    void set_send_cookie_to_proxy_for2ch( bool set );
     void set_proxy_for2ch( const std::string& proxy );
     void set_proxy_port_for2ch( const int port );
 
     // 2ch 書き込み用プロクシとポート番号
     bool get_use_proxy_for2ch_w();
+    bool get_send_cookie_to_proxy_for2ch_w();
     const std::string& get_proxy_for2ch_w();
     int get_proxy_port_for2ch_w();
     const std::string& get_proxy_basicauth_for2ch_w();
 
     void set_use_proxy_for2ch_w( const bool set );
+    void set_send_cookie_to_proxy_for2ch_w( bool set );
     void set_proxy_for2ch_w( const std::string& proxy );
     void set_proxy_port_for2ch_w( const int port );
 
@@ -168,11 +171,13 @@ namespace CONFIG
 
     // 2chの外にアクセスするときのプロクシとポート番号
     bool get_use_proxy_for_data();
+    bool get_send_cookie_to_proxy_for_data();
     const std::string& get_proxy_for_data();
     int get_proxy_port_for_data();
     const std::string& get_proxy_basicauth_for_data();
 
     void set_use_proxy_for_data( const bool set );
+    void set_send_cookie_to_proxy_for_data( bool set );
     void set_proxy_for_data( const std::string& proxy );
     void set_proxy_port_for_data( const int port );
 
@@ -193,15 +198,14 @@ namespace CONFIG
     // 同一ホストに対する最大コネクション数( 1 または 2 )
     int get_connection_num();
 
-    // 2chのクッキー:HAP
+    // 2chのクッキー (互換性のため設定名は旧名称を使う)
     bool get_use_cookie_hap();
     const std::string& get_cookie_hap();
     const std::string& get_cookie_hap_bbspink();
     void set_cookie_hap( const std::string& cookie_hap );
     void set_cookie_hap_bbspink( const std::string& cookie_hap );
 
-    // 2chの過去ログ取得時にofflaw2を使用する
-    bool get_use_offlaw2_2ch();
+    bool get_use_offlaw2_2ch() = delete; // Removed in v0.3.0 (2020-04)
 
     // リンクをクリックしたときに実行するコマンド
     const std::string& get_command_openurl();
@@ -335,7 +339,7 @@ namespace CONFIG
     // 板一覧でカテゴリを常にひとつだけ開く
     bool get_open_one_category();
 
-    // お気に入りでカテゴリを常にひとつだけ開く
+    // お気に入りでディレクトリを常にひとつだけ開く
     bool get_open_one_favorite();
 
     // デフォルトの書き込み名
