@@ -15,6 +15,8 @@
 
 #include "colorid.h"
 
+#include <glib/gi18n.h>
+
 
 using namespace CONTROL;
 
@@ -38,7 +40,7 @@ InputDiag::InputDiag( Gtk::Window* parent, const std::string& url,
     set_title( CONTROL::get_label( m_id ) + " ( " + CONTROL::get_mode_label( m_controlmode ) + " )" );
     resize( 400, 400 );
 
-    get_vbox()->pack_start( m_label );
+    get_content_area()->pack_start( m_label );
 
     show_all_children();
 }
@@ -269,8 +271,8 @@ MouseKeyDiag::MouseKeyDiag( Gtk::Window* parent, const std::string& url,
       m_controlmode( CONTROL::get_mode( m_id ) ),
       m_single( false ),
       m_label( "編集したい" + target + "設定をダブルクリックして下さい。" ),
-      m_button_delete( Gtk::Stock::DELETE ),
-      m_button_add( Gtk::Stock::ADD ),
+      m_button_delete( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Delete", 12 ), true ),
+      m_button_add( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Add", 12 ), true ),
       m_button_reset( "デフォルト" )
 {
     m_liststore = Gtk::ListStore::create( m_columns );
@@ -298,9 +300,9 @@ MouseKeyDiag::MouseKeyDiag( Gtk::Window* parent, const std::string& url,
     m_hbox.pack_start( m_scrollwin, Gtk::PACK_EXPAND_WIDGET );
     m_hbox.pack_start( m_vbuttonbox, Gtk::PACK_SHRINK );
 
-    get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_label, Gtk::PACK_SHRINK );
-    get_vbox()->pack_start( m_hbox );
+    get_content_area()->set_spacing( 8 );
+    get_content_area()->pack_start( m_label, Gtk::PACK_SHRINK );
+    get_content_area()->pack_start( m_hbox );
 
     show_all_children();
     set_title( CONTROL::get_label( m_id ) + " ( " + CONTROL::get_mode_label( m_controlmode ) + " )" );
@@ -529,14 +531,12 @@ MouseKeyPref::MouseKeyPref( Gtk::Window* parent, const std::string& url, const s
     m_button_reset.signal_clicked().connect( sigc::mem_fun( *this, &MouseKeyPref::slot_reset ) );
     m_hbox.pack_start( m_button_reset, Gtk::PACK_SHRINK );
 
-    get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_label, Gtk::PACK_SHRINK );
-    get_vbox()->pack_start( m_scrollwin );
-    get_vbox()->pack_start( m_hbox, Gtk::PACK_SHRINK );
+    get_content_area()->set_spacing( 8 );
+    get_content_area()->pack_start( m_label, Gtk::PACK_SHRINK );
+    get_content_area()->pack_start( m_scrollwin );
+    get_content_area()->pack_start( m_hbox, Gtk::PACK_SHRINK );
 
-#if GTKMM_CHECK_VERSION(3,0,0)
     set_default_size_ratio( 0.666 );
-#endif
     show_all_children();
     set_title( target + "設定" );
 }
