@@ -16,6 +16,8 @@
 #include "jdlib/miscutil.h"
 #include "jdlib/miscmsg.h"
 
+#include <glib/gi18n.h>
+
 #include <sys/time.h>
 
 
@@ -25,15 +27,15 @@ using namespace DBIMG;
 DelImgCacheDiag::DelImgCacheDiag()
     : m_label( "画像キャッシュ削除中・・・\n\nしばらくお待ち下さい" )
 {
-    add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL )
+    add_button( g_dgettext( GTK_DOMAIN, "_Cancel" ), Gtk::RESPONSE_CANCEL )
     ->signal_clicked().connect( sigc::mem_fun(*this, &DelImgCacheDiag::slot_cancel_clicked ) );
 
     set_title( "JDim 画像キャッシュ削除中" );
 
     const int mrg = 8;
-    get_vbox()->set_spacing( mrg );
+    get_content_area()->set_spacing( mrg );
     set_border_width( mrg );
-    get_vbox()->pack_start( m_label, Gtk::PACK_SHRINK );
+    get_content_area()->pack_start( m_label, Gtk::PACK_SHRINK );
     show_all_children();
 }
 
@@ -48,7 +50,6 @@ DelImgCacheDiag::~DelImgCacheDiag()
 }
 
 
-#if GTKMM_CHECK_VERSION(3,0,0)
 bool DelImgCacheDiag::on_draw( const Cairo::RefPtr< Cairo::Context >& cr )
 {
 #ifdef _DEBUG
@@ -58,17 +59,6 @@ bool DelImgCacheDiag::on_draw( const Cairo::RefPtr< Cairo::Context >& cr )
     launch_thread();
     return Gtk::Dialog::on_draw( cr );
 }
-#else
-bool DelImgCacheDiag::on_expose_event( GdkEventExpose* event )
-{
-#ifdef _DEBUG
-    std::cout << "DelImgCacheDiag::on_expose_event\n";
-#endif
-
-    launch_thread();
-    return Gtk::Dialog::on_expose_event( event );
-}
-#endif // GTKMM_CHECK_VERSION(3,0,0)
 
 
 void DelImgCacheDiag::launch_thread()
