@@ -35,11 +35,7 @@ namespace DBIMG
 
       protected:
 
-#if GTKMM_CHECK_VERSION(3,0,0)
         bool on_draw( const Cairo::RefPtr< Cairo::Context >& cr ) override;
-#else
-        bool on_expose_event( GdkEventExpose* event ) override;
-#endif
 
       private:
 
