@@ -256,7 +256,7 @@ std::string Img::get_cache_path()
 // mosaic : モザイク表示するか
 // waitsec: 指定した秒数経過後にロード開始
 //
-void Img::download_img( const std::string refurl, const bool mosaic, const int waitsec )
+void Img::download_img( const std::string& refurl, const bool mosaic, const int waitsec )
 {
     // ダウンロード初回(リダイレクトでは無い)
     if( ! m_count_redirect ) m_url_alt = std::string();
@@ -777,8 +777,6 @@ void Img::read_info()
 */
         // TODO : JDLIB::ConfLoaderFast を作る
         std::string str_info, str_tmp;
-        std::list< std::string > list_tmp;
-        std::list< std::string >::iterator it_tmp;
         CACHE::load_rawdata( path_info, str_info );
 
         std::list< std::string > lines = MISC::get_lines( str_info );
@@ -864,7 +862,7 @@ void Img::save_info()
     }
 
     if( m_protect ) path_info = CACHE::path_img_protect_info( m_url );
-    if( m_abone ) path_info = CACHE::path_img_abone( m_url );
+    else if( m_abone ) path_info = CACHE::path_img_abone( m_url );
     else path_info = CACHE::path_img_info( m_url );
 
     std::ostringstream oss;
