@@ -122,7 +122,7 @@ namespace DBTREE
         ArticleBase( const std::string& datbase, const std::string& id, bool cached );
         ~ArticleBase();
 
-        bool empty();
+        bool empty() const noexcept { return m_url.empty(); }
 
         const std::string& get_url() const { return m_url; }
 
@@ -196,6 +196,9 @@ namespace DBTREE
         // 書き込みしたレス番号をリストにして取得
         std::list< int > get_res_posted();
 
+        // 高参照レスをリストにして取得
+        std::list< int > get_highly_referenced_res();
+
         // number番のレスを参照しているレス番号をリストにして取得
         std::list< int > get_res_reference( const int number );
 
@@ -213,9 +216,6 @@ namespace DBTREE
         // ref == true なら先頭に ">" を付ける
         std::string get_res_str( int number, bool ref = false );
 
-        // number　番のレスの生文字列を返す
-        std::string get_raw_res_str( int number );
-
         // 書き込み時の名前とメアド
         const std::string& get_write_name() const { return m_write_name; }
         void set_write_name( const std::string& str ){ m_save_info = true; m_write_name = str; }
