@@ -20,21 +20,24 @@ namespace DBTREE
     {
         friend class ArticleHashIterator;
 
-        size_t m_size;
+        size_t m_size{};
         size_t m_min_hash;
         ArticleHashIterator* m_iterator;
         std::vector< std::vector< ArticleBase* > > m_table;
 
         // iterator 用変数
-        size_t m_it_hash;
-        size_t m_it_pos;
-        size_t m_it_size;
+        size_t m_it_hash{};
+        size_t m_it_pos{};
+        size_t m_it_size{};
 
       public:
 
         ArticleHash();
+        ArticleHash( const ArticleHash& ) = delete;
         virtual ~ArticleHash();
 
+        ArticleHash& operator=( const ArticleHash& ) = delete;
+
         size_t size() const { return m_size; }
 
         void push( ArticleBase* article );
@@ -64,7 +67,7 @@ namespace DBTREE
 
       public:
 
-        ArticleHashIterator( ArticleHash* hashtable );
+        explicit ArticleHashIterator( ArticleHash* hashtable );
 
         ArticleBase* operator * ();
         ArticleBase* operator ++ ();
