@@ -18,17 +18,17 @@ namespace DBTREE
       public:
 
         ArticleJBBS( const std::string& datbase, const std::string& id, bool cached );
-        ~ArticleJBBS();
+        ~ArticleJBBS() noexcept;
 
         // 書き込みメッセージ変換
-        const std::string create_write_message( const std::string& name, const std::string& mail,
-                                                const std::string& msg ) override;
+        std::string create_write_message( const std::string& name, const std::string& mail,
+                                          const std::string& msg ) override;
 
         // bbscgi のURL
-        const std::string url_bbscgi() override;
+        std::string url_bbscgi() override;
         
         // subbbscgi のURL
-        const std::string url_subbbscgi() override;
+        std::string url_subbbscgi() override;
 
       private:
         
