@@ -18,8 +18,10 @@
 #include "httpcode.h"
 #include "global.h"
 
-#include <sstream>
+#include <algorithm>
 #include <cstring>
+#include <iterator>
+#include <sstream>
 
 using namespace DBTREE;
 
@@ -73,70 +75,61 @@ Board2chCompati::~Board2chCompati()
 //
 // キャッシュのファイル名が正しいか
 //
-bool Board2chCompati::is_valid( const std::string& filename )
+bool Board2chCompati::is_valid( const std::string& filename ) const
 {
-    if( filename.find( get_ext() ) == std::string::npos ) return false;
-    if( filename.length() - filename.rfind( get_ext() ) != get_ext().length() ) return false;
+    const std::string& ext = get_ext();
+    if( filename.size() <= ext.size() ) return false;
+    if( filename.compare( filename.size() - ext.size(), ext.size(), ext ) != 0 ) return false;
 
-    size_t dig, n;
-    MISC::str_to_uint( filename.c_str(), dig, n );
-    if( dig != n ) return false;
-    if( dig == 0 ) return false;
-        
-    return true;
+    return std::all_of( filename.cbegin(), std::prev( filename.cend(), ext.size() ),
+                        []( char c ) { return '0' <= c && c <= '9'; } );
 }
 
 
-std::string Board2chCompati::analyze_keyword_impl( const std::string& html )
+std::string Board2chCompati::analyze_keyword_impl( const std::string& html, bool full_parse )
 {
     std::string keyword;
 
-    JDLIB::Regex regex;
-    std::size_t offset = 0;
-    constexpr bool icase = true; // 大文字小文字区別しない
-    constexpr bool newline = false;  // . に改行をマッチさせる
-    constexpr bool usemigemo = false;
-    constexpr bool wchar = false;
-
-    for(;;){
-
-        // <input type=hidden> のタグを解析して name と value を取得
-        constexpr const char regex_input[] = R"(<input +type=("hidden"|hidden) +name=([^ ]*) +value=([^>]*)>)";
-        if( ! regex.exec( regex_input, html, offset, icase, newline, usemigemo, wchar ) ) break;
-
-        offset = regex.pos( 0 );
-
-        std::string name = MISC::remove_space( regex.str( 2 ) );
-        if( name[ 0 ] == '\"' ) name = MISC::cut_str( name, "\"", "\"" );
-
-        std::string value = MISC::remove_space( regex.str( 3 ) );
-        if( value[ 0 ] == '\"' ) value = MISC::cut_str( value, "\"", "\"" );
-
+    // form要素から action属性(送信先URLのパス) を取得する
+    const std::string path = MISC::parse_html_form_action( html );
+    // action属性が見つかったら m_path_subbbscgi に設定する
+    if( ! path.empty() ) {
 #ifdef _DEBUG
-        std::cout << "offset = " << offset << " "
-                  << regex.str( 0 ) << std::endl
-                  << "name = " << name << " value = " << value << std::endl;
+        std::cout << "Board2chCompati::analyze_keyword_impl update subbbscgi path = " << path << std::endl;
 #endif
-        ++offset;
-
-        // 除外する name の判定
-        // 2ch の仕様が変わったら項目を追加すること
-        const std::string lowname = MISC::tolower_str( name );
-        if( lowname == "subject"
-            || lowname == "from"
-            || lowname == "mail"
-            || lowname == "message"
-            || lowname == "bbs"
-            || lowname == "time"
-            || lowname == "key" ) continue;
-
-        // キーワード取得
-        if( ! keyword.empty() ) keyword += "&";
-        keyword += MISC::charset_url_encode( name, get_charset() ) + "=" + MISC::charset_url_encode( value, get_charset() );
+        set_path_subbbscgi( path );
     }
 
+    std::vector<MISC::FormDatum> data = MISC::parse_html_form_data( html );
+    for( MISC::FormDatum& d : data ) {
+
+        const std::string lowname = MISC::tolower_str( d.name );
+        if( ! full_parse ) {
+            // 除外する name の判定
+            // 2ch の仕様が変わったら項目を追加すること
+            if( lowname == "subject"
+                || lowname == "from"
+                || lowname == "mail"
+                || lowname == "message"
+                || lowname == "bbs"
+                || lowname == "time"
+                || lowname == "key"
+                || lowname == "submit" ) continue;
+        }
+        if( lowname == "message" ) {
+            // アンカー記号(>>)などがエスケープされる(&gt;&gt;)ため
+            // 一度HTMLエスケープされた文字をデコードする
+            d.value = MISC::html_unescape( d.value );
+        }
+
+        // キーワード取得
+        if( ! keyword.empty() ) keyword.push_back( '&' );
+        keyword.append( MISC::charset_url_encode( d.name, get_charset() ) );
+        keyword.push_back( '=' );
+        keyword.append( MISC::charset_url_encode( d.value, get_charset() ) );
+    }
 #ifdef _DEBUG
-    std::cout << "Board2chCompati::analyze_keyword_impl keyword = " << keyword << std::endl;
+    std::cout << "Board2chCompati::analyze_keyword_impl form data = " << keyword << std::endl;
 #endif
 
     return keyword;
@@ -152,7 +145,8 @@ void Board2chCompati::analyze_keyword_for_write( const std::string& html )
     std::cout << html << std::endl << "--------------------\n";
 #endif
 
-    std::string keyword = analyze_keyword_impl( html );
+    constexpr bool full_parse{ false };
+    std::string keyword = analyze_keyword_impl( html, full_parse );
     set_keyword_for_write( keyword );
 }
 
@@ -165,11 +159,29 @@ void Board2chCompati::analyze_keyword_for_newarticle( const std::string& html )
     std::cout << html << std::endl << "--------------------\n";
 #endif
 
-    std::string keyword = analyze_keyword_impl( html );
+    // XXX: スレ立てフォームはページの最後にあると決め打ちしている
+    std::size_t i = html.rfind( "<form" );
+    if( i == std::string::npos ) i = 0;
+
+    constexpr bool full_parse{ false };
+    std::string keyword = analyze_keyword_impl( html.substr( i ), full_parse );
     set_keyword_for_newarticle( keyword );
 }
 
 
+// 確認画面のHTMLから書き込み、スレ立て時に使うフォームデータを取得する
+std::string Board2chCompati::parse_form_data( const std::string& html )
+{
+#ifdef _DEBUG
+    std::cout << "Board2chCompati::parse_form_data\n";
+    std::cout << html << std::endl << "--------------------\n";
+#endif
+
+    constexpr bool full_parse{ true };
+    return analyze_keyword_impl( html, full_parse );
+}
+
+
 // 新スレ作成時の書き込みメッセージ作成
 std::string Board2chCompati::create_newarticle_message( const std::string& subject,
                                                        const std::string& name, const std::string& mail, const std::string& msg )
@@ -202,7 +214,7 @@ std::string Board2chCompati::create_newarticle_message( const std::string& subje
 // (例) "http://www.hoge2ch.net/test/bbs.cgi"
 //
 //
-std::string Board2chCompati::url_bbscgi_new()
+std::string Board2chCompati::url_bbscgi_new() const
 {
     std::string cgibase = url_bbscgibase();
     return cgibase.substr( 0, cgibase.length() -1 ); // 最後の '/' を除く
@@ -214,7 +226,7 @@ std::string Board2chCompati::url_bbscgi_new()
 //
 // (例) "http://www.hoge2ch.net/test/subbbs.cgi"
 //
-std::string Board2chCompati::url_subbbscgi_new()
+std::string Board2chCompati::url_subbbscgi_new() const
 {
     std::string cgibase = url_subbbscgibase();
     return cgibase.substr( 0, cgibase.length() -1 ); // 最後の '/' を除く
@@ -399,7 +411,7 @@ void Board2chCompati::regist_article( const bool is_online )
 }
 
 
-std::string Board2chCompati::localrule()
+std::string Board2chCompati::localrule() const
 {
     if( m_ruleloader ){
         if( m_ruleloader->is_loading() ) return "ロード中です";
@@ -414,7 +426,18 @@ std::string Board2chCompati::localrule()
 }
 
 
-std::string Board2chCompati::settingtxt()
+//
+// SETTING.TXTのURL
+//
+// (例) "http://hoge.2ch.net/hogeboard/SETTING.TXT"
+//
+std::string Board2chCompati::url_settingtxt() const
+{
+    return url_boardbase() + DBTREE::kSettingTxt;
+}
+
+
+std::string Board2chCompati::settingtxt() const
 {
     if( m_settingloader ){
         if( m_settingloader->is_loading() ) return "ロード中です";
@@ -429,7 +452,7 @@ std::string Board2chCompati::settingtxt()
 }
 
 
-std::string Board2chCompati::default_noname()
+std::string Board2chCompati::default_noname() const
 {
     if( m_settingloader
         && m_settingloader->get_code() == HTTP_OK ) return m_settingloader->default_noname();
@@ -438,7 +461,7 @@ std::string Board2chCompati::default_noname()
 }
 
 
-int Board2chCompati::line_number()
+int Board2chCompati::line_number() const
 {
     if( m_settingloader
         && m_settingloader->get_code() == HTTP_OK ) return m_settingloader->line_number();
@@ -447,7 +470,7 @@ int Board2chCompati::line_number()
 }
 
 
-int Board2chCompati::message_count()
+int Board2chCompati::message_count() const
 {
     if( m_settingloader
         && m_settingloader->get_code() == HTTP_OK ) return m_settingloader->message_count();
@@ -456,7 +479,7 @@ int Board2chCompati::message_count()
 }    
 
 
-std::string Board2chCompati::get_unicode()
+std::string Board2chCompati::get_unicode() const
 {
     if( m_settingloader
         && m_settingloader->get_code() == HTTP_OK ) return m_settingloader->get_unicode();
@@ -506,7 +529,7 @@ void Board2chCompati::download_rule_setting()
 //
 // レス数であぼーん(グローバル)
 //
-int Board2chCompati::get_abone_number_global()
+int Board2chCompati::get_abone_number_global() const
 {
     return CONFIG::get_abone_number_thread();
 }
