@@ -28,6 +28,8 @@
 #include "session.h"
 #include "boardcolumnsid.h"
 
+#include <glib/gi18n.h>
+
 #include <sstream>
 #include <cstring>
 
@@ -116,7 +118,7 @@ ArticleBase* BoardBase::get_article_null()
 }
 
 
-bool BoardBase::empty()
+bool BoardBase::empty() const
 {
     return m_root.empty();
 }
@@ -125,7 +127,7 @@ bool BoardBase::empty()
 //
 // url がこの板のものかどうか
 //
-bool BoardBase::equal( const std::string& url )
+bool BoardBase::equal( const std::string& url ) const
 {
     if( url.find( get_root() ) == 0
         && url.find( get_path_board() + "/" ) != std::string::npos ) return true;
@@ -151,20 +153,20 @@ void BoardBase::update_name( const std::string& name )
 
 // ユーザエージェント
 // ダウンロード用
-const std::string& BoardBase::get_agent()
+const std::string& BoardBase::get_agent() const
 {
     return CONFIG::get_agent_for_data();
 }
 
 // 書き込み用
-const std::string& BoardBase::get_agent_w()
+const std::string& BoardBase::get_agent_w() const
 {
     return get_agent();
 }
 
 
 // 読み込み用プロキシ
-std::string BoardBase::get_proxy_host()
+std::string BoardBase::get_proxy_host() const
 {
     const int mode = get_mode_local_proxy();
 
@@ -177,7 +179,7 @@ std::string BoardBase::get_proxy_host()
     return std::string();
 }
 
-int BoardBase::get_proxy_port()
+int BoardBase::get_proxy_port() const
 {
     const int mode = get_mode_local_proxy();
 
@@ -187,7 +189,7 @@ int BoardBase::get_proxy_port()
     return 0;
 }
 
-std::string BoardBase::get_proxy_basicauth()
+std::string BoardBase::get_proxy_basicauth() const
 {
     const int mode = get_mode_local_proxy();
 
@@ -199,7 +201,7 @@ std::string BoardBase::get_proxy_basicauth()
 
 
 // 書き込み用プロキシ
-std::string BoardBase::get_proxy_host_w()
+std::string BoardBase::get_proxy_host_w() const
 {
     const int mode = get_mode_local_proxy_w();
 
@@ -212,7 +214,7 @@ std::string BoardBase::get_proxy_host_w()
     return std::string();
 }
 
-int BoardBase::get_proxy_port_w()
+int BoardBase::get_proxy_port_w() const
 {
     const int mode = get_mode_local_proxy_w();
 
@@ -223,7 +225,7 @@ int BoardBase::get_proxy_port_w()
 }
 
 
-std::string BoardBase::get_proxy_basicauth_w()
+std::string BoardBase::get_proxy_basicauth_w() const
 {
     const int mode = get_mode_local_proxy_w();
 
@@ -235,41 +237,41 @@ std::string BoardBase::get_proxy_basicauth_w()
 
 
 // ローカルルール
-std::string BoardBase::localrule()
+std::string BoardBase::localrule() const
 {
     return "利用できません";
 }
 
 
 // setting.txt
-std::string BoardBase::settingtxt()
+std::string BoardBase::settingtxt() const
 {
     return "利用できません";
 }
 
 // デフォルトの名無し名
-std::string BoardBase::default_noname()
+std::string BoardBase::default_noname() const
 {
     return "???";
 }
 
 
 // 最大改行数/2
-int BoardBase::line_number()
+int BoardBase::line_number() const
 {
     return 0;
 }
 
 
 // 最大書き込みバイト数
-int BoardBase::message_count()
+int BoardBase::message_count() const
 {
     return 0;
 }
 
 
 // 特殊文字書き込み可能か( pass なら可能、 change なら不可 )
-std::string BoardBase::get_unicode()
+std::string BoardBase::get_unicode() const
 {
     return {};
 }
@@ -373,7 +375,7 @@ void BoardBase::send_update_board()
     // "update_board" コマンドの後に"update_board_item"を送ると
     // ローディングが終了しているため行を二回更新してしまうので注意
     // 詳しくは BoardViewBase::update_item() を参照
-    CORE::core_set_command( "update_board_item", url_subject(),
+    CORE::core_set_command( "update_board_item", url_boardbase(),
                             std::string() // IDとして空文字を送る
         );
 
@@ -421,7 +423,7 @@ void BoardBase::update_writetime()
 //
 // 経過時間(秒)
 //
-time_t BoardBase::get_write_pass()
+time_t BoardBase::get_write_pass() const
 {
     time_t ret = 0;
     struct timeval tv;
@@ -436,7 +438,7 @@ time_t BoardBase::get_write_pass()
 //
 // 書き込み可能までの残り秒
 //
-time_t BoardBase::get_write_leftsec()
+time_t BoardBase::get_write_leftsec() const
 {
     const time_t mrg = 2;
 
@@ -545,9 +547,9 @@ void BoardBase::update_url( const std::string& root, const std::string& path_boa
     m_root = root;
     m_path_board = path_board;
 
-    m_query_dat = std::string();
-    m_query_cgi = std::string();
-    m_query_kako = std::string();
+    m_query_dat.clear();
+    m_query_cgi.clear();
+    m_query_kako.clear();
 
     // modified 時刻をリセット
     // 自動移転処理後に bbsmenu.html を読み込んだときに、bbsmenu.html の
@@ -577,10 +579,6 @@ std::string BoardBase::url_dat( const std::string& url, int& num_from, int& num_
 
     JDLIB::Regex regex;
     const size_t offset = 0;
-    const bool icase = false;
-    const bool newline = true;
-    const bool usemigemo = false;
-    const bool wchar = false;
 
     std::string id; // スレッドのID
 
@@ -590,34 +588,42 @@ std::string BoardBase::url_dat( const std::string& url, int& num_from, int& num_
     
     num_from = num_to = 0;
 
-    if( m_query_dat.empty() ){
+    if( ! m_query_dat.compiled() ){
+
+        constexpr bool icase = false;
+        constexpr bool newline = true;
+        constexpr bool usemigemo = false;
+        constexpr bool wchar = false;
 
         // dat 型
         const std::string datpath = MISC::replace_str( url_datpath(), "?", "\\?" );
-        m_query_dat = "^ *(https?://.+" + datpath  + ")([1234567890]+" + get_ext() + ") *$";
+        const std::string reg_dat = "^ *(https?://.+" + datpath  + ")([0-9]+" + get_ext() + ") *$";
+        m_query_dat.set( reg_dat, icase, newline, usemigemo, wchar );
 
         // read.cgi型
         const std::string cgipath = MISC::replace_str( url_readcgipath(), "?", "\\?" );
-        m_query_cgi = "^ *(https?://.+" + cgipath + ")([1234567890]+)/?r?(l50)?([1234567890]+)?(-)?([1234567890]+)?.*$";
+        const std::string reg_cgi = "^ *(https?://.+" + cgipath + ")([0-9]+)/?r?(l50)?([0-9]+)?(-)?([0-9]+)?.*$";
+        m_query_cgi.set( reg_cgi, icase, newline, usemigemo, wchar );
 
         // 過去ログかどうか
         const std::string pathboard = MISC::replace_str( m_path_board, "?", "\\?" );
-        m_query_kako = "^ *(https?://.+)" + pathboard  + "/kako(/[1234567890]+)?/[1234567890]+/([1234567890]+).html *$";
+        const std::string reg_kako = "^ *(https?://.+)" + pathboard  + "/kako(/[0-9]+)?/[0-9]+/([0-9]+).html *$";
+        m_query_kako.set( reg_kako, icase, newline, usemigemo, wchar );
 
 #ifdef _DEBUG
-        std::cout << "query_dat = " << m_query_dat << std::endl;
-        std::cout << "query_cgi = " << m_query_cgi << std::endl;
-        std::cout << "query_kako = " << m_query_kako << std::endl;
+        std::cout << "reg_dat = " << reg_dat << std::endl;
+        std::cout << "reg_cgi = " << reg_cgi << std::endl;
+        std::cout << "reg_kako = " << reg_kako << std::endl;
 #endif
     }
 
-    if( regex.exec( m_query_dat , url, offset, icase, newline, usemigemo, wchar ) ) id = regex.str( 2 );
+    if( regex.match( m_query_dat, url, offset ) ) id = regex.str( 2 );
 
-    else if( regex.exec( m_query_cgi , url, offset, icase, newline, usemigemo, wchar ) ){
+    else if( regex.match( m_query_cgi, url, offset ) ){
 
         id = regex.str( 2 ) + get_ext(); 
 
-        if( !regex.str( 3 ).empty() ){ // l50
+        if( regex.length( 3 ) ){ // l50
             num_from = 1;
             num_to = 50;
         }
@@ -632,7 +638,7 @@ std::string BoardBase::url_dat( const std::string& url, int& num_from, int& num_
             num_from = MAX( 1, num_from );
 
             // 12- みたいな場合はとりあえず大きい数字を入れとく
-            if( !regex.str( 5 ).empty() && !num_to ) num_to = CONFIG::get_max_resnumber() + 1;
+            if( regex.length( 5 ) && !num_to ) num_to = CONFIG::get_max_resnumber() + 1;
         }
 
         // -15 みたいな場合
@@ -645,10 +651,7 @@ std::string BoardBase::url_dat( const std::string& url, int& num_from, int& num_
     // どちらでもない(スレのURLでない)場合
     else{
 
-#ifdef _DEBUG
-        std::cout << "query_kako = " << m_query_kako << std::endl;
-#endif
-        if( regex.exec( m_query_kako , url, offset, icase, newline, usemigemo, wchar ) ){
+        if( regex.match( m_query_kako, url, offset ) ){
 
             std::string url_tmp = regex.str( 1 ) + url_datpath() + regex.str( 3 ) + get_ext();
 #ifdef _DEBUG
@@ -758,7 +761,7 @@ std::string BoardBase::url_readcgi( const std::string& url, int num_from, int nu
 //
 // (例) "http://www.hoge2ch.net/hogeboard/subject.txt"
 //
-std::string BoardBase::url_subject()
+std::string BoardBase::url_subject() const
 {
     if( empty() ) return std::string();
 
@@ -772,7 +775,7 @@ std::string BoardBase::url_subject()
 //
 // (例) "http://www.hoge2ch.net/"  (最後に '/' がつく)
 //
-std::string BoardBase::url_root()
+std::string BoardBase::url_root() const
 {
     if( empty() ) return std::string();
 
@@ -785,7 +788,7 @@ std::string BoardBase::url_root()
 //
 // (例) "http://www.hoge2ch.net/hogeboard/"  (最後に '/' がつく)
 //
-std::string BoardBase::url_boardbase()
+std::string BoardBase::url_boardbase() const
 {
     if( empty() ) return std::string();
 
@@ -798,7 +801,7 @@ std::string BoardBase::url_boardbase()
 //
 // (例) "http://www.hoge2ch.net/hogeboard/dat/" (最後に '/' がつく)
 //
-std::string BoardBase::url_datbase()
+std::string BoardBase::url_datbase() const
 {
     if( empty() ) return std::string();
 
@@ -811,7 +814,7 @@ std::string BoardBase::url_datbase()
 //
 // (例) "/hogeboard/dat/"  (最初と最後に '/' がつく)
 //
-std::string BoardBase::url_datpath()
+std::string BoardBase::url_datpath() const
 {
     if( empty() ) return std::string();
 
@@ -825,7 +828,7 @@ std::string BoardBase::url_datpath()
 //
 // (例) "http://www.hoge2ch.net/test/read.cgi/hogeboard/"  (最後に '/' がつく)
 //
-std::string BoardBase::url_readcgibase()
+std::string BoardBase::url_readcgibase() const
 {
     if( empty() ) return std::string();
 
@@ -838,7 +841,7 @@ std::string BoardBase::url_readcgibase()
 //
 // (例) "/test/read.cgi/hogeboard/"   (最初と最後に '/' がつく)
 //
-std::string BoardBase::url_readcgipath()
+std::string BoardBase::url_readcgipath() const
 {
     if( empty() ) return std::string();
 
@@ -852,7 +855,7 @@ std::string BoardBase::url_readcgipath()
 // (例) "http://www.hoge2ch.net/test/bbs.cgi/" ( 最後に '/' がつく )
 //
 //
-std::string BoardBase::url_bbscgibase()
+std::string BoardBase::url_bbscgibase() const
 {
     if( empty() ) return std::string();
 
@@ -865,7 +868,7 @@ std::string BoardBase::url_bbscgibase()
 //
 // (例) "http://www.hoge2ch.net/test/subbbs.cgi/"  ( 最後に '/' がつく )
 //
-std::string BoardBase::url_subbbscgibase()
+std::string BoardBase::url_subbbscgibase() const
 {
     if( empty() ) return std::string();
 
@@ -995,7 +998,7 @@ ArticleBase* BoardBase::get_article_fromURL( const std::string& url )
 void BoardBase::download_subject( const std::string& url_update_view, const bool read_from_cache )
 {
 #ifdef _DEBUG
-    std::cout << "BoardBase::download_subject " << url_subject() << std::endl
+    std::cout << "BoardBase::download_subject " << url_boardbase() << std::endl
               << "url_update_view = " << url_update_view << std::endl
               << "read_from_cache = " << read_from_cache << std::endl
               << "empty = " << empty() << std::endl
@@ -1094,7 +1097,7 @@ void BoardBase::receive_data( const char* data, size_t size )
     if( m_rawdata_left.capacity() < SIZE_OF_RAWDATA ) {
         m_rawdata_left.reserve( SIZE_OF_RAWDATA );
     }
-    if( ! m_iconv ) m_iconv = new JDLIB::Iconv( m_charset, "UTF-8" );
+    if( ! m_iconv ) m_iconv = new JDLIB::Iconv( "UTF-8", m_charset );
 
     m_rawdata_left.append( data, size );
 
@@ -1158,7 +1161,7 @@ void BoardBase::receive_finish()
             if( DBTREE::move_board( url_boardbase(), location() ) ) {
                 // 再読み込み
                 const std::string str_tab = "false";
-                CORE::core_set_command( "open_board", url_subject(), str_tab );
+                CORE::core_set_command( "open_board", url_boardbase(), str_tab );
             }
         }
         // HTMLの埋め込みスクリプトで移動を指示された場合
@@ -1207,7 +1210,7 @@ void BoardBase::receive_finish()
 
                         // 再読み込み
                         const std::string str_tab = "false";
-                        CORE::core_set_command( "open_board", url_subject(), str_tab );
+                        CORE::core_set_command( "open_board", url_boardbase(), str_tab );
                     }
                 }
             }
@@ -1396,12 +1399,6 @@ void BoardBase::receive_finish()
 
                 // 古いファイルをrename
                 if( CACHE::file_exists( path_subject ) == CACHE::EXIST_FILE ){
-#ifdef _WIN32
-                    // not overwrite by rename() on windows
-                    if (CACHE::file_exists( path_oldsubject ) == CACHE::EXIST_FILE ){
-                        remove( path_oldsubject.c_str() );
-                    }
-#endif
                     if( rename( path_subject.c_str(), path_oldsubject.c_str() ) != 0 ){
                         MISC::ERRMSG( "rename failed " + path_subject );
                     }
@@ -1467,22 +1464,18 @@ bool BoardBase::start_checkking_if_board_moved()
 //
 // キャッシュのディレクトリ内にあるスレのファイル名のリストを取得
 //
-std::list< std::string > BoardBase::get_filelist_in_cache()
+std::list<std::string> BoardBase::get_filelist_in_cache() const
 {
-    std::list< std::string >list_out;
+    std::list<std::string> list_out;
     if( empty() ) return list_out;
 
-    std::list< std::string >list_file;
-    std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
+    const std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
 
-    list_file = CACHE::get_filelist( path_board_root );
-    if( ! list_file.size() ) return list_out;
+    std::list<std::string> list_file = CACHE::get_filelist( path_board_root );
+    if( list_file.empty() ) return list_out;
 
-    std::list< std::string >::iterator it = list_file.begin();
-    for(; it != list_file.end(); ++it ){
-
-        std::string& file = ( *it );
-        if( is_valid( file ) ) list_out.push_back( file );
+    for( std::string& file : list_file ) {
+        if( is_valid( file ) ) list_out.emplace_back( std::move( file ) );
     }
 
     return list_out;
@@ -1649,8 +1642,8 @@ void BoardBase::remove_old_abone_thread()
                                       "今後表示しない(_D)",
                                       Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
 
-        mdiag.add_default_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
-        mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+        mdiag.add_default_button( g_dgettext( GTK_DOMAIN, "_No" ), Gtk::RESPONSE_NO );
+        mdiag.add_button( g_dgettext( GTK_DOMAIN, "_Yes" ), Gtk::RESPONSE_YES );
 
         const int ret = mdiag.run();
 
@@ -1700,7 +1693,7 @@ void BoardBase::update_abone_thread( const bool redraw )
     const bool online = SESSION::is_online();
     SESSION::set_online( false );
 
-    download_subject( ( redraw ? url_subject() : std::string() ), false );
+    download_subject( ( redraw ? url_boardbase() : std::string() ), false );
 
     SESSION::set_online( online );
 }
@@ -1829,7 +1822,7 @@ void BoardBase::set_local_proxy( const std::string& proxy )
 
     if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
-        m_local_proxy_basicauth = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
+        m_local_proxy_basicauth = regex.str( 1 ).substr( 0, regex.length( 1 ) - 1 );
         m_local_proxy = regex.str( 2 );
     }
 }
@@ -1854,7 +1847,7 @@ void BoardBase::set_local_proxy_w( const std::string& proxy )
 
     if( regex.exec( "([^/]+:[^/]+@)(.+)$" , proxy, offset, icase, newline, usemigemo, wchar ) )
     {
-        m_local_proxy_basicauth_w = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
+        m_local_proxy_basicauth_w = regex.str( 1 ).substr( 0, regex.length( 1 ) - 1 );
         m_local_proxy_w = regex.str( 2 );
     }
 }
@@ -1875,7 +1868,7 @@ void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
     )
 {
 #ifdef _DEBUG
-    std::cout << "BoardBase::search_cache " << url_subject() << std::endl;
+    std::cout << "BoardBase::search_cache " << url_boardbase() << std::endl;
 #endif
 
     if( empty() ) return;
@@ -1885,7 +1878,7 @@ void BoardBase::search_cache( std::vector< DBTREE::ArticleBase* >& list_article,
     if( m_hash_article->size() == 0 ) return;
 
     const bool append_all = query.empty();
-    const std::string query_local = MISC::Iconv( query, "UTF-8", get_charset() );
+    const std::string query_local = MISC::Iconv( query, get_charset(), "UTF-8" );
     const std::list< std::string > list_query = MISC::split_line( query_local );
 
     const std::string path_board_root = CACHE::path_board_root_fast( url_boardbase() );
@@ -2334,7 +2327,7 @@ void BoardBase::show_updateicon( const bool update )
             m_status |= STATUS_UPDATE;
 
             // スレ一覧のタブのアイコン表示を更新
-            CORE::core_set_command( "toggle_board_icon", url_subject() );
+            CORE::core_set_command( "toggle_board_icon", url_boardbase() );
 
             // サイドバーのアイコン表示を更新
             CORE::core_set_command( "toggle_sidebar_boardicon", url_datbase() );
@@ -2354,7 +2347,7 @@ void BoardBase::show_updateicon( const bool update )
 
             // サイドバーのアイコン表示を戻す
             // スレ一覧のタブのアイコンはBoardViewがロード終了時に自動的に戻す
-            CORE::core_set_command( "toggle_sidebar_boardicon", url_subject() );
+            CORE::core_set_command( "toggle_sidebar_boardicon", url_boardbase() );
 
             save_info();
         }
