@@ -6,6 +6,8 @@
 #include "boardjbbs.h"
 #include "articlejbbs.h"
 #include "articlehash.h"
+#include "ruleloader.h"
+#include "settingloader.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/miscmsg.h"
@@ -14,9 +16,11 @@
 #include "config/globalconf.h"
 
 #include "global.h"
+#include "httpcode.h"
 
-#include <sstream>
+#include <algorithm>
 #include <cstring>
+#include <sstream>
 
 using namespace DBTREE;
 
@@ -37,19 +41,26 @@ BoardJBBS::BoardJBBS( const std::string& root, const std::string& path_board, co
 }
 
 
+BoardJBBS::~BoardJBBS() noexcept
+{
+    if( m_settingloader ) {
+        m_settingloader->terminate_load();
+    }
+    if( m_ruleloader ) {
+        m_ruleloader->terminate_load();
+    }
+}
+
+
 //
 // キャッシュのファイル名が正しいか
 //
-bool BoardJBBS::is_valid( const std::string& filename )
+bool BoardJBBS::is_valid( const std::string& filename ) const
 {
     if( filename.length() != 10 ) return false;
 
-    size_t dig, n;
-    MISC::str_to_uint( filename.c_str(), dig, n );
-    if( dig != n ) return false;
-    if( dig != 10 ) return false;
-        
-    return true;
+    return std::all_of( filename.cbegin(), filename.cend(),
+                        []( char c ) { return '0' <= c && c <= '9'; } );
 }
 
 
@@ -83,7 +94,7 @@ ArticleBase* BoardJBBS::append_article( const std::string& datbase, const std::s
 //
 // (例) "/bbs/rawmode.cgi/board/"  (最初と最後に '/' がつく)
 //
-std::string BoardJBBS::url_datpath()
+std::string BoardJBBS::url_datpath() const
 {
     if( empty() ) return std::string();
 
@@ -129,7 +140,7 @@ std::string BoardJBBS::create_newarticle_message( const std::string& subject, co
 // (例) "http://jbbs.shitaraba.net/bbs/write.cgi/computer/123/new/"
 //
 //
-std::string BoardJBBS::url_bbscgi_new()
+std::string BoardJBBS::url_bbscgi_new() const
 {
     return url_bbscgibase() + get_id() + "/new/";
 }
@@ -140,12 +151,98 @@ std::string BoardJBBS::url_bbscgi_new()
 //
 // (例) "http://jbbs.shitaraba.net/bbs/write.cgi/computer/123/new/"
 //
-std::string BoardJBBS::url_subbbscgi_new()
+std::string BoardJBBS::url_subbbscgi_new() const
 {
     return url_subbbscgibase() + get_id() + "/new/";
 }
 
 
+std::string BoardJBBS::localrule() const
+{
+    if( m_ruleloader ){
+        if( m_ruleloader->is_loading() ) return "ロード中です";
+        else if( m_ruleloader->get_code() == HTTP_OK
+                 || m_ruleloader->get_code() == HTTP_REDIRECT
+                 || m_ruleloader->get_code() == HTTP_MOVED_PERM )
+        {
+            const std::string& data = m_ruleloader->get_data();
+            return data.empty() ? "ローカルルールはありません" : data;
+        }
+        return "ロードに失敗しました : " + m_ruleloader->get_str_code();
+    }
+
+    return BoardBase::localrule();
+}
+
+
+std::string BoardJBBS::settingtxt() const
+{
+    if( m_settingloader ){
+        if( m_settingloader->is_loading() ) return "ロード中です";
+        else if( m_settingloader->get_code() == HTTP_OK
+                 || m_settingloader->get_code() == HTTP_REDIRECT
+                 || m_settingloader->get_code() == HTTP_MOVED_PERM )
+        {
+            const std::string& data = m_settingloader->get_data();
+            return data.empty() ? "SETTING.TXTはありません" : data;
+        }
+        return "ロードに失敗しました : " + m_settingloader->get_str_code();
+    }
+
+    return BoardBase::settingtxt();
+}
+
+
+std::string BoardJBBS::default_noname() const
+{
+    if( m_settingloader && m_settingloader->get_code() == HTTP_OK ) {
+        return m_settingloader->default_noname();
+    }
+    return BoardBase::default_noname();
+}
+
+
+//
+// SETTING.TXT のURL
+//
+// (例) "http://jbbs.shitaraba.net/bbs/api/setting.cgi/computer/123/"
+//
+std::string BoardJBBS::url_settingtxt() const
+{
+    return get_root() + "/bbs/api/setting.cgi/" + get_id() + "/";
+}
+
+
+//
+// ローカルルールとSETTING.TXTをキャッシュから読み込む
+//
+// BoardBase::read_info()で呼び出す
+//
+void BoardJBBS::load_rule_setting()
+{
+    if( ! m_ruleloader ) m_ruleloader.reset( new RuleLoader( url_boardbase(), "MS932" ) );
+    m_ruleloader->load_text();
+
+    if( ! m_settingloader ) m_settingloader.reset( new SettingLoader( url_boardbase() ) );
+    m_settingloader->load_text();
+}
+
+
+//
+// SETTING.TXTをサーバからダウンロード
+// ローカルルールはスレ本文とエンコーディングが異なる
+//
+// 読み込むタイミングはsubject.txtを読み終わった直後( BoardBase::receive_finish() )
+//
+void BoardJBBS::download_rule_setting()
+{
+    if( ! m_ruleloader ) m_ruleloader.reset( new RuleLoader( url_boardbase(), "MS932" ) );
+    m_ruleloader->download_text();
+
+    if( ! m_settingloader ) m_settingloader.reset( new SettingLoader( url_boardbase() ) );
+    m_settingloader->download_text();
+}
+
 
 //
 // subject.txt から Aarticle のリストにアイテムを追加・更新
