@@ -16,8 +16,9 @@
 
 #include "global.h"
 
-#include <sstream>
+#include <algorithm>
 #include <cstring>
+#include <sstream>
 
 using namespace DBTREE;
 
@@ -41,7 +42,7 @@ BoardMachi::BoardMachi( const std::string& root, const std::string& path_board,
 //
 // url がこの板のものかどうか
 //
-bool  BoardMachi::equal( const std::string& url )
+bool BoardMachi::equal( const std::string& url ) const
 {
     if( url.find( get_root() ) == 0 ){
 
@@ -57,16 +58,12 @@ bool  BoardMachi::equal( const std::string& url )
 //
 // キャッシュのファイル名が正しいか
 //
-bool BoardMachi::is_valid( const std::string& filename )
+bool BoardMachi::is_valid( const std::string& filename ) const
 {
     if( filename.length() != 10 ) return false;
 
-    size_t dig, n;
-    MISC::str_to_uint( filename.c_str(), dig, n );
-    if( dig != n ) return false;
-    if( dig != 10 ) return false;
-        
-    return true;
+    return std::all_of( filename.cbegin(), filename.cend(),
+                        []( char c ) { return '0' <= c && c <= '9'; } );
 }
 
 
@@ -142,11 +139,11 @@ std::string BoardMachi::url_dat( const std::string& url, int& num_from, int& num
     if( regex.exec( query_dat , url, offset, icase, newline, usemigemo, wchar ) ){
         id = regex.str( 2 );
 
-        if( ! regex.str( 5 ).empty() ){
+        if( regex.length( 5 ) ){
             num_from = atoi( regex.str( 5 ).c_str() );
             num_str = std::to_string( num_from );
         }
-        if( ! regex.str( 7 ).empty() ){
+        if( regex.length( 7 ) ){
             num_to = atoi( regex.str( 7 ).c_str() );
             num_str += "-" + std::to_string( num_to );
         }
@@ -169,7 +166,7 @@ std::string BoardMachi::url_dat( const std::string& url, int& num_from, int& num
 //
 // (例) "/bbs/read.cgi?BBS=board&KEY=" (最初に '/' がつく)
 //
-std::string BoardMachi::url_datpath()
+std::string BoardMachi::url_datpath() const
 {
     if( empty() ) return std::string();
 
@@ -191,7 +188,7 @@ std::string BoardMachi::create_newarticle_message( const std::string& subject, c
 //
 // 新スレ作成時のbbscgi(write.cgi) のURL
 //
-std::string BoardMachi::url_bbscgi_new()
+std::string BoardMachi::url_bbscgi_new() const
 {
     return std::string();
 }
@@ -200,7 +197,7 @@ std::string BoardMachi::url_bbscgi_new()
 //
 // 新スレ作成時のsubbbscgi のURL
 //
-std::string BoardMachi::url_subbbscgi_new()
+std::string BoardMachi::url_subbbscgi_new() const
 {
     return std::string();
 }
