@@ -60,11 +60,6 @@ DBTREE::ArticleBase* DBTREE::get_article( const std::string& url )
 
 //////////////////////////////////////
 
-std::string DBTREE::url_subject( const std::string& url )
-{
-    return DBTREE::get_board( url )->url_subject();
-}
-
 
 std::string DBTREE::url_root( const std::string& url )
 {
@@ -107,6 +102,12 @@ std::string DBTREE::url_readcgi( const std::string& url, int num_from, int num_t
 }
 
 
+std::string DBTREE::url_settingtxt( const std::string& url )
+{
+    return DBTREE::get_board( url )->url_settingtxt();
+}
+
+
 std::string DBTREE::url_bbscgibase( const std::string& url )
 {
     return DBTREE::get_board( url )->url_bbscgibase();
@@ -362,6 +363,12 @@ void DBTREE::board_analyze_keyword_for_newarticle( const std::string& url, const
 }
 
 
+std::string DBTREE::board_parse_form_data( const std::string& url, const std::string& html )
+{
+    return DBTREE::get_board( url )->parse_form_data( html );
+}
+
+
 std::string DBTREE::board_basicauth( const std::string& url )
 {
     return DBTREE::get_board( url )->get_basicauth();
@@ -1116,7 +1123,13 @@ std::string DBTREE::create_newarticle_message( const std::string& url, const std
 
 std::string DBTREE::get_write_referer( const std::string& url )
 {
-    return DBTREE::get_board( url )->get_write_referer();
+    return DBTREE::get_board( url )->get_write_referer( url );
+}
+
+
+std::string DBTREE::get_newarticle_referer( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_newarticle_referer( url );
 }
 
 
