@@ -37,7 +37,7 @@ namespace DBTREE
     ArticleBase* get_article( const std::string& url );
 
     // urlの変換関係
-    std::string url_subject( const std::string& url ); // 板の subject.txt の URL
+    std::string url_subject( const std::string& url ) = delete; // 板の subject.txt の URL
     std::string url_root( const std::string& url );
     std::string url_boardbase( const std::string& url );
     std::string url_datbase( const std::string& url );
@@ -51,6 +51,8 @@ namespace DBTREE
     // read.cgi型のurlに変換
     std::string url_readcgi( const std::string& url, int num_from, int num_to );
 
+    std::string url_settingtxt( const std::string& url );
+
     std::string url_bbscgibase( const std::string& url );
     std::string url_subbbscgibase( const std::string& url );
     std::string url_bbscgi( const std::string& url );
@@ -114,6 +116,7 @@ namespace DBTREE
     std::string board_keyword_for_newarticle( const std::string& url );
     void board_set_keyword_for_newarticle( const std::string& url, const std::string& keyword );
     void board_analyze_keyword_for_newarticle( const std::string& url, const std::string& html );
+    std::string board_parse_form_data( const std::string& url, const std::string& html );
     std::string board_basicauth( const std::string& url );
     std::string board_ext( const std::string& url );
     int board_status( const std::string& url );
@@ -304,6 +307,8 @@ namespace DBTREE
 
     // 書き込み時のリファラ
     std::string get_write_referer( const std::string& url );
+    // スレ立て時のリファラ
+    std::string get_newarticle_referer( const std::string& url );
 
     // あぼーん関係
 
