@@ -184,18 +184,17 @@ BoardBase* Root::get_board( const std::string& url, const int count )
     }
 
     // サーチ
-    for( BoardBase* board : m_list_board ) {
+    auto it_board = std::find_if( m_list_board.begin(), m_list_board.end(),
+                                  [&url]( const BoardBase* b ) { return b->equal( url ); } );
+    if( it_board != m_list_board.end() ) {
 
-        if( board->equal( url ) ){
-
-            board->read_info(); // 板情報の取得( 詳しくはBoardBase::read_info()をみること )
-            m_get_board = board;
+        m_get_board = *it_board;
+        m_get_board->read_info(); // 板情報の取得( 詳しくはBoardBase::read_info()をみること )
 
 #ifdef _SHOW_GETBOARD
             std::cout << "found\n";
 #endif
-            return board;
-        }
+        return m_get_board;;
     }
 
     // 見つからなかった
@@ -405,9 +404,9 @@ void Root::receive_finish()
     }
 
     // 文字コードを変換してXML作成
-    JDLIB::Iconv* libiconv = new JDLIB::Iconv( "MS932", "UTF-8" );
+    JDLIB::Iconv libiconv{ "UTF-8", "MS932" };
     int byte_out;
-    const char* rawdata_utf8 = libiconv->convert( &*m_rawdata.begin(), m_rawdata.size(),  byte_out );
+    const std::string rawdata_utf8 = libiconv.convert( &*m_rawdata.begin(), m_rawdata.size(),  byte_out );
     bbsmenu2xml( rawdata_utf8 );
 
     if( m_xml_document.hasChildNodes() )
@@ -419,7 +418,6 @@ void Root::receive_finish()
         CORE::core_set_command( "update_bbslist" );
     }
 
-    if( libiconv ) delete libiconv;
     clear();
 }
 
@@ -1118,7 +1116,7 @@ void Root::load_etc()
             // basic認証
             if( regex.exec( "https?://([^/]+:[^/]+@)(.+)$" , info.url, offset, icase, newline, usemigemo, wchar ) )
             {
-                info.basicauth = regex.str( 1 ).substr( 0, regex.str( 1 ).length() - 1 );
+                info.basicauth = regex.str( 1 ).substr( 0, regex.length( 1 ) - 1 );
                 info.url = ( info.url[4] == 's' ? "https://" : "http://" ) + regex.str( 2 );
             }
 
