@@ -103,9 +103,7 @@ FontColorPref::FontColorPref( Gtk::Window* parent, const std::string& url )
     m_fontbutton.set_tooltip_text( m_tooltips_font[ 0 ] );
 
     set_title( "フォントと色の詳細設定" );
-#if GTKMM_CHECK_VERSION(3,0,0)
     set_default_size_ratio( 0.5 );
-#endif
     show_all_children();
 }
 
@@ -222,15 +220,12 @@ void FontColorPref::pack_widget()
     m_hbox_change_color.pack_end( m_bt_change_color , Gtk::PACK_SHRINK );
     m_vbox_color.pack_start( m_hbox_change_color, Gtk::PACK_SHRINK );
 
-#if GTKMM_CHECK_VERSION(3,0,0)
     m_chk_use_gtktheme_message.add_label( "書き込みビューの配色設定に GTKテーマ を用いる(_W)", true );
     m_chk_use_gtktheme_message.set_active( CONFIG::get_use_message_gtktheme() );
     m_vbox_color.pack_start( m_chk_use_gtktheme_message, Gtk::PACK_SHRINK );
-#endif
 
     m_chk_use_gtkrc_tree.add_label( "ツリービューの背景色設定に gtkrc を用いる(_T)", true ),
     m_chk_use_gtkrc_tree.set_active( CONFIG::get_use_tree_gtkrc() );
-    m_chk_use_gtkrc_tree.signal_toggled().connect( sigc::mem_fun( *this, &FontColorPref::slot_chk_use_gtkrc_toggled ) );
     m_vbox_color.pack_start( m_chk_use_gtkrc_tree, Gtk::PACK_SHRINK );
 
     m_chk_use_gtkrc_selection.add_label( "スレビューの選択範囲の色設定に gtkrc を用いる(_S)", true ),
@@ -243,8 +238,8 @@ void FontColorPref::pack_widget()
     m_notebook.append_page( m_vbox_color, "色の設定" );    
 
     // 全体
-    get_vbox()->pack_start( m_notebook );
-    get_vbox()->set_spacing( mrg );
+    get_content_area()->pack_start( m_notebook );
+    get_content_area()->set_spacing( mrg );
     set_border_width( mrg );
 }
 
@@ -264,9 +259,7 @@ void FontColorPref::slot_ok_clicked()
 
     CONFIG::set_strict_char_width( m_checkbutton_font.property_active() );
 
-#if GTKMM_CHECK_VERSION(3,0,0)
     CONFIG::set_use_message_gtktheme( m_chk_use_gtktheme_message.property_active() );
-#endif
     CONFIG::set_use_tree_gtkrc( m_chk_use_gtkrc_tree.property_active() );
     CONFIG::set_use_select_gtkrc( m_chk_use_gtkrc_selection.property_active() );
 
@@ -342,17 +335,6 @@ void FontColorPref::slot_checkbutton_font_toggled()
     }
 }
 
-void FontColorPref::slot_chk_use_gtkrc_toggled()
-{
-#if !GTKMM_CHECK_VERSION(3,0,0)
-    if( m_chk_use_gtkrc_tree.property_active() )
-    {
-        SKELETON::MsgDiag mdiag( nullptr, WARNING_GTKRC_TREE );
-        mdiag.run();
-    }
-#endif
-}
-
 
 //
 // フォント選択ダイアログで OK が押された
@@ -472,7 +454,7 @@ void FontColorPref::slot_change_color()
     Gtk::ColorSelectionDialog colordiag;
     if( colorid != COLOR_NONE ) {
         Gtk::ColorSelection* sel = colordiag.get_color_selection();
-        sel->set_current_color( Gdk::Color( CONFIG::get_color( colorid ) ) );
+        sel->set_current_rgba( Gdk::RGBA( CONFIG::get_color( colorid ) ) );
     }
     colordiag.set_transient_for( *CORE::get_mainwindow() );
     const int ret = colordiag.run();
@@ -487,7 +469,7 @@ void FontColorPref::slot_change_color()
             colorid = row[ m_columns_color.m_col_colorid ];
             if( colorid != COLOR_NONE ) {
                 Gtk::ColorSelection* sel = colordiag.get_color_selection();
-                CONFIG::set_color( colorid, MISC::color_to_str( sel->get_current_color() ) );
+                CONFIG::set_color( colorid, MISC::color_to_str( sel->get_current_rgba() ) );
             }
         }
     }
@@ -525,16 +507,7 @@ void FontColorPref::slot_reset_color()
 //
 void FontColorPref::slot_reset_all_colors()
 {
-#if !GTKMM_CHECK_VERSION(3,0,0)
-    if( m_chk_use_gtkrc_tree.property_active() )
-    {
-        SKELETON::MsgDiag mdiag( nullptr, WARNING_GTKRC_TREE );
-        mdiag.run();
-    }
-#endif
-#if GTKMM_CHECK_VERSION(3,0,0)
     m_chk_use_gtktheme_message.set_active( CONFIG::CONF_USE_MESSAGE_GTKTHEME );
-#endif
     m_chk_use_gtkrc_tree.set_active( CONFIG::CONF_USE_TREE_GTKRC );
     m_chk_use_gtkrc_selection.set_active( CONFIG::CONF_USE_SELECT_GTKRC );
 
