@@ -48,13 +48,9 @@ ImageAdmin::ImageAdmin( const std::string& url )
     , m_scroll( SCROLL_NO )
 {
     m_scrwin.add( m_iconbox );
-#if GTKMM_CHECK_VERSION(3,16,0)
     // Gtk::POLICY_NEVERだとスクロール機能自体がなくなり
     // コンテンツに合わせてGtk::ScrolledWindowのサイズが拡大してしまう
     m_scrwin.set_policy( Gtk::POLICY_EXTERNAL, Gtk::POLICY_NEVER );
-#else
-    m_scrwin.set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_NEVER );
-#endif
     m_scrwin.set_size_request( ICON_SIZE ,  ICON_SIZE + 4);
 
     m_left.set_label( "<" );
@@ -63,16 +59,16 @@ ImageAdmin::ImageAdmin( const std::string& url )
     m_left.set_focus_on_click( false );
     m_right.set_focus_on_click( false );
 
-    m_left.signal_pressed().connect( sigc::mem_fun( *this, &ImageAdmin::slot_press_left ) );
-    m_right.signal_pressed().connect( sigc::mem_fun( *this, &ImageAdmin::slot_press_right ) );
-    m_left.signal_released().connect( sigc::mem_fun( *this, &ImageAdmin::slot_release_left ) );
-    m_right.signal_released().connect( sigc::mem_fun( *this, &ImageAdmin::slot_release_right ) );
+    m_gesture_press_left = Gtk::GestureMultiPress::create( m_left );
+    m_gesture_press_right = Gtk::GestureMultiPress::create( m_right );
+    m_gesture_press_left->signal_pressed().connect( sigc::mem_fun( *this, &ImageAdmin::slot_press_left ) );
+    m_gesture_press_right->signal_pressed().connect( sigc::mem_fun( *this, &ImageAdmin::slot_press_right ) );
+    m_gesture_press_left->signal_released().connect( sigc::mem_fun( *this, &ImageAdmin::slot_release_left ) );
+    m_gesture_press_right->signal_released().connect( sigc::mem_fun( *this, &ImageAdmin::slot_release_right ) );
 
     // マウスホイールによる画像ビューのタブ切り替えを設定する
     m_tab.add_events( Gdk::SCROLL_MASK );
-#if GTKMM_CHECK_VERSION(3,3,18)
     m_tab.add_events( Gdk::SMOOTH_SCROLL_MASK );
-#endif
     m_tab.signal_scroll_event().connect( sigc::mem_fun( *this, &ImageAdmin::slot_scroll_event ) );
 
     m_tab.pack_start( m_scrwin );
@@ -660,9 +656,8 @@ void ImageAdmin::close_left_views( const std::string& url )
     set_command( "set_imgtab_operating", "", "true" );
 
     for( auto&& widget : m_iconbox.get_children() ) {
-        auto view = dynamic_cast< SKELETON::View* >( widget );
-        if( view->get_url() == url ) break;
-        if( view ) {
+        if( auto view{ dynamic_cast<SKELETON::View*>( widget ) } ) {
+            if( view->get_url() == url ) break;
             set_command( "close_view", view->get_url() );
         }
     }
@@ -997,7 +992,7 @@ void ImageAdmin::scroll_tab( int scroll )
 
 
 //左押した
-void ImageAdmin::slot_press_left()
+void ImageAdmin::slot_press_left( int, double, double )
 {
     m_scroll = SCROLL_LEFT;
     m_counter_scroll = 0;
@@ -1005,7 +1000,7 @@ void ImageAdmin::slot_press_left()
 }
 
 //右押した
-void ImageAdmin::slot_press_right()
+void ImageAdmin::slot_press_right( int, double, double )
 {
     m_scroll = SCROLL_RIGHT;
     m_counter_scroll = 0;
@@ -1014,13 +1009,13 @@ void ImageAdmin::slot_press_right()
 
 
 //左離した
-void ImageAdmin::slot_release_left()
+void ImageAdmin::slot_release_left( int, double, double )
 {
     m_scroll = SCROLL_NO;
 }
 
 // 右離した
-void ImageAdmin::slot_release_right()
+void ImageAdmin::slot_release_right( int, double, double )
 {
     m_scroll = SCROLL_NO;
 }
@@ -1035,7 +1030,6 @@ bool ImageAdmin::slot_scroll_event( GdkEventScroll* event )
     const char* command_name = nullptr;
     if( event->direction == GDK_SCROLL_UP ) command_name = "tab_left";
     else if( event->direction == GDK_SCROLL_DOWN ) command_name = "tab_right";
-#if GTKMM_CHECK_VERSION(3,3,18)
     else if( event->direction == GDK_SCROLL_SMOOTH ) {
         constexpr double smooth_scroll_factor{ 2.0 };
         m_smooth_dy += smooth_scroll_factor * event->delta_y;
@@ -1048,7 +1042,6 @@ bool ImageAdmin::slot_scroll_event( GdkEventScroll* event )
             m_smooth_dy = 0.0;
         }
     }
-#endif // GTKMM_CHECK_VERSION(3,3,18)
 
     if( command_name ) set_command( command_name );
     set_command( "switch_admin" );
