@@ -31,6 +31,7 @@ ImageViewPopup::ImageViewPopup( const std::string& url )
     get_control().add_mode( CONTROL::MODE_IMAGEVIEW );
     get_control().add_mode( CONTROL::MODE_IMAGEICON );
 
+    // TODO: JDimのスタイルシート機能からGTKのcssに切り替えるか？
     int border_width = 1;
     int margin = 0;
     std::string border_color = "black";
@@ -56,22 +57,12 @@ ImageViewPopup::ImageViewPopup( const std::string& url )
     get_event().set_border_width( margin );
 
     // 枠色
-#if GTKMM_CHECK_VERSION(3,0,0)
     m_event_frame.override_background_color( Gdk::RGBA( border_color ), Gtk::STATE_FLAG_NORMAL );
-#else
-    m_event_frame.modify_bg( Gtk::STATE_NORMAL, Gdk::Color( border_color ) );
-#endif
 
     // 背景色
-#if GTKMM_CHECK_VERSION(3,0,0)
     const Gdk::RGBA color_bg( bg_color );
     m_event_margin.override_background_color( color_bg, Gtk::STATE_FLAG_NORMAL );
     get_event().override_background_color( color_bg, Gtk::STATE_FLAG_NORMAL );
-#else
-    const Gdk::Color color_bg( bg_color );
-    m_event_margin.modify_bg( Gtk::STATE_NORMAL, color_bg );
-    get_event().modify_bg( Gtk::STATE_NORMAL, color_bg );
-#endif
 
     // 全ての領域を表示できないならカーソルの上に表示
     set_popup_upside( true );
@@ -137,13 +128,8 @@ void ImageViewPopup::set_label( const std::string& status )
             CORE::CSS_PROPERTY css = CORE::get_css_manager()->get_property( classid );
             if( css.color >= 0 ) text_color = CORE::get_css_manager()->get_color( css.color );
         }
-#if GTKMM_CHECK_VERSION(3,0,0)
         const Gdk::RGBA color_text( text_color );
         m_label->override_color( color_text, Gtk::STATE_FLAG_NORMAL );
-#else
-        const Gdk::Color color_text( text_color );
-        m_label->modify_fg( Gtk::STATE_NORMAL, color_text );
-#endif
 
         m_label->show();
     }
