@@ -7,10 +7,7 @@
 #define _IOMONITOR_H
 
 #include <gtkmm.h>
-#ifdef _WIN32
-#include "jdlib/jdthread.h"
-#include <windows.h>
-#endif
+
 
 namespace CORE
 {
@@ -23,16 +20,10 @@ namespace CORE
 
     class IOMonitor
     {
-#ifndef _WIN32
         // FIFOのファイルディスクリプタ
         int m_fifo_fd;
         // I/Oの架け橋
         Glib::RefPtr< Glib::IOChannel > m_iochannel;
-#else
-        HANDLE m_slot_hd;
-        std::string m_slot_name;
-        JDLIB::Thread m_thread;
-#endif
 
         // FIFOファイル名
         std::string m_fifo_file;
@@ -48,16 +39,11 @@ namespace CORE
         // 初期化
         void init();
 
-#ifndef _WIN32
         // FIFOを削除する
         void delete_fifo();
-#endif
 
         // FIFOに書き込まれたら呼び出される
         bool slot_ioin( Glib::IOCondition io_condition );
-#ifdef _WIN32
-        static void* monitor_launcher( void* dat );
-#endif
 
       public:
 
