@@ -917,6 +917,86 @@ std::string MISC::html_unescape( const std::string& str )
 
 
 
+//
+// 文字参照のデコード内部処理
+//
+// strは'&'で始まる文字列を指定すること
+// completely = true の時は'"' '&' '<' '>'も含めて変換する
+//
+static std::string chref_decode_one( const char* str, int& n_in, const bool completely )
+{
+    std::string out_char( 15u, '\0' );
+    int n_out;
+    const int type = DBTREE::decode_char( str, n_in, &*out_char.begin(), n_out, false );
+    out_char.resize( n_out );
+
+    // 改行、タブ、スペースの処理
+    if( type != DBTREE::NODE_NONE && ( out_char[0] == ' ' || out_char[0] == '\n' ) ) {
+        out_char.assign( 1u, ' ' );
+    }
+    // 変換できない文字
+    else if( type == DBTREE::NODE_NONE ) {
+        out_char.assign( 1u, *str );
+        n_in = 1;
+    }
+    // エスケープする文字の場合は元に戻す
+    else if( ! completely && n_out == 1 ) {
+        switch( out_char[0] ) {
+            case '"':
+                out_char.assign( "&quot;" );
+                break;
+            case '&':
+                out_char.assign( "&amp;" );
+                break;
+            case '<':
+                out_char.assign( "&lt;" );
+                break;
+            case '>':
+                out_char.assign( "&gt;" );
+                break;
+            default:
+                break;
+        }
+    }
+
+    return out_char;
+}
+
+
+//
+// HTMLの文字参照をデコード
+//
+// completely = true の時は'"' '&' '<' '>'もデコードする
+//
+std::string MISC::chref_decode( const char* str, const int lng, const bool completely )
+{
+    std::string str_out;
+
+    if( lng <= 0 ) return str_out;
+    if( std::memchr( str, '&', lng ) == nullptr ) {
+        str_out.assign( str, lng );
+        return str_out;
+    }
+
+    const char* pos = str;
+    const char* pos_end = str + lng;
+
+    while( pos < pos_end ) {
+
+        // '&' までコピーする
+        while( *pos != '&' && pos < pos_end ) str_out.push_back( *pos++ );
+        if( pos >= pos_end ) break;
+
+        // 文字参照のデコード
+        int n_in;
+        str_out.append( chref_decode_one( pos, n_in, completely ) );
+        pos += n_in;
+    }
+
+    return str_out;
+}
+
+
 //
 // URL中のスキームを判別する
 //
@@ -1126,7 +1206,7 @@ std::string MISC::charset_url_encode( const std::string& str, const std::string&
 {
     if( charset.empty() || charset == "UTF-8" ) return MISC::url_encode( str.c_str(), str.length() );
 
-    const std::string str_enc = MISC::Iconv( str, "UTF-8", charset );
+    const std::string str_enc = MISC::Iconv( str, charset, "UTF-8" );
     return  MISC::url_encode( str_enc.c_str(), str_enc.length() );
 }
 
@@ -1204,13 +1284,13 @@ std::string MISC::base64( const std::string& str )
 //
 // 遅いので連続的な処理が必要な時は使わないこと
 //
-std::string MISC::Iconv( const std::string& str, const std::string& coding_from, const std::string& coding_to )
+std::string MISC::Iconv( const std::string& str, const std::string& coding_to, const std::string& coding_from )
 {
     if( coding_from == coding_to ) return str;
 
     std::string str_bk = str;
 
-    JDLIB::Iconv* libiconv = new JDLIB::Iconv( coding_from, coding_to );
+    JDLIB::Iconv* libiconv = new JDLIB::Iconv( coding_to, coding_from );
     int byte_out;
 
     std::string str_enc = libiconv->convert( &*str_bk.begin(), str_bk.size(), byte_out );
@@ -1344,7 +1424,8 @@ static int sanitize_numeric_character_reference( int raw_point )
     else if( raw_point <= 0x0008 // Control character
             || raw_point == 0x000B // Control character (Vertical tab)
             || ( 0x000D <= raw_point && raw_point <= 0x001F ) // Control character
-            || ( 0xFDD0 <= raw_point && raw_point <= 0xFDEF ) // Noncharacters
+            || ( 0xFDD0 <= raw_point // && raw_point <= 0xFDEF の境界は上でチェックしているので不要
+                ) // Noncharacters
             ) {
         parse_error = true;
     }
@@ -1693,14 +1774,9 @@ std::string MISC::getenv_limited( const char *name, const size_t size )
 {
     if( ! name || ! getenv( name ) ) return std::string();
 
-    std::vector< char > env( size + 1, '\0' );
-    strncpy( env.data(), getenv( name ), size );
-
-#ifdef _WIN32
-    return recover_path( Glib::locale_to_utf8( std::string( env.data() ) ) );
-#else
-    return env.data();
-#endif
+    std::string env = getenv( name );
+    if( env.size() > size ) env.resize( size );
+    return env;
 }
 
 
@@ -1709,29 +1785,12 @@ std::string MISC::getenv_limited( const char *name, const size_t size )
 //
 std::string MISC::recover_path( const std::string& str )
 {
-#ifdef _WIN32
-    // Windowsのpathセパレータ \ を、jdの / に置き換える
-    std::string ret( str );
-    for (int i=ret.length()-1; i>=0; i--)
-        if (ret[ i ] == '\\')
-            ret[ i ] = '/';
-    return ret;
-#else
     return str;
-#endif
 }
 
 std::vector< std::string > MISC::recover_path( std::vector< std::string > list_str )
 {
-#ifdef _WIN32
-    std::vector< std::string > list_ret;
-    std::vector< std::string >::const_iterator it = list_str.begin();
-    for( ; it != list_str.end() ; ++it )
-        list_ret.push_back( MISC::recover_path( *it ) );
-    return list_ret;
-#else
     return list_str;
-#endif
 }
 
 
@@ -1897,3 +1956,86 @@ bool MISC::starts_with( const char* self, const char* starts )
     }
     return true;
 }
+
+
+//
+// HTMLからform要素を解析してinput,textarea要素の名前と値を返す
+//
+std::vector<MISC::FormDatum> MISC::parse_html_form_data( const std::string& html )
+{
+    JDLIB::Regex regex;
+    JDLIB::RegexPattern pat;
+    constexpr bool icase = true; // 大文字小文字区別しない
+    constexpr bool newline = false;  // . に改行をマッチさせる
+    constexpr bool usemigemo = false;
+    constexpr bool wchar = false;
+
+    // <input type=(hidden|submit)> or <textarea> のタグを解析して name と value を取得
+    const std::string pattern = R"((<input +type=("hidden"|hidden|"submit"|submit) +(name=([^ ]*) +value=([^>]*)|value=([^ ]*) +name=([^>]*))>|<textarea +name=([^ >]*)[^>]*>(.*?)</textarea>))";
+    pat.set( pattern, icase, newline, usemigemo, wchar );
+
+    std::vector<MISC::FormDatum> data;
+    for( std::size_t offset = 0; ; ++offset){
+        std::string name;
+        std::string value;
+
+        if( regex.match( pat, html, offset ) ) {
+            const std::string name_value = MISC::tolower_str( regex.str( 3 ) );
+            if( name_value.compare( 0, 5, "name=" ) == 0 ) {
+                name = MISC::remove_space( regex.str( 4 ) );
+                value = MISC::remove_space( regex.str( 5 ) );
+            }
+            else if( name_value.compare( 0, 6, "value=" ) == 0 ) {
+                name = MISC::remove_space( regex.str( 7 ) );
+                value = MISC::remove_space( regex.str( 6 ) );
+            }
+            else {
+                name = MISC::remove_space( regex.str( 8 ) );
+                value = MISC::remove_space( regex.str( 9 ) );
+            }
+        }
+
+        if( name.empty() ) break;
+
+        offset = regex.pos( 0 );
+
+        if( name[ 0 ] == '\"' ) name = MISC::cut_str( name, "\"", "\"" );
+
+        if( value[ 0 ] == '\"' ) value = MISC::cut_str( value, "\"", "\"" );
+
+#ifdef _DEBUG
+        std::cout << "offset = " << offset << " "
+                  << regex.str( 0 ) << std::endl
+                  << "name = " << name << " value = " << value << std::endl;
+#endif
+
+        data.push_back( MISC::FormDatum{ std::move( name ), std::move( value ) } );
+    }
+    return data;
+}
+
+
+// HTMLのform要素から action属性(送信先URLのパス) を取得する
+// 2ch互換板に特化して実装しているため他の掲示板で期待した結果を返す保証はない
+// 詳細は実装やテストコードを参照
+//
+std::string MISC::parse_html_form_action( const std::string& html )
+{
+    const char pattern[] = R"(<form +method=("POST"|POST)[^>]* action="(\.\.)?(/test/(sub)?bbs\.cgi(\?[^"]*)?))";
+    const char pattern_same_hierarchy[] = R"(<form +method=("POST"|POST)[^>]* action="\.(/(sub)?bbs\.cgi(\?[^"]*)?))";
+    JDLIB::Regex regex;
+    constexpr std::size_t offset = 0;
+    constexpr bool icase = true; // 大文字小文字区別しない
+    constexpr bool newline = false;  // . に改行をマッチさせる
+    constexpr bool usemigemo = false;
+    constexpr bool wchar = false;
+
+    std::string path;
+    if( regex.exec( pattern, html, offset, icase, newline, usemigemo, wchar ) ) {
+        path = regex.str( 3 );
+    }
+    else if( regex.exec( pattern_same_hierarchy, html, offset, icase, newline, usemigemo, wchar ) ) {
+        path = "/test" + regex.str( 2 );
+    }
+    return path;
+}
