@@ -43,6 +43,15 @@ namespace MISC
          WINtoUNIX
      };
 
+     // parse_html_form_data() の戻り値
+     struct FormDatum
+     {
+         std::string name;
+         std::string value;
+
+         bool operator==( const FormDatum& rhs ) const { return name == rhs.name && value == rhs.value; }
+     };
+
     // str を "\n" ごとに区切ってlistにして出力
     std::list< std::string > get_lines( const std::string& str );
 
@@ -149,6 +158,13 @@ namespace MISC
     // HTMLアンエスケープ
     std::string html_unescape( const std::string& str );
 
+    // HTML文字参照をデコード( completely=trueの場合は '&' '<' '>' '"' を含める )
+    std::string chref_decode( const char* str, const int lng, const bool completely = true );
+    inline std::string chref_decode( const std::string& str, const bool completely = true )
+    {
+        return MISC::chref_decode( str.c_str(), str.size(), completely );
+    }
+
     // URL中のスキームを判別する
     // 戻り値 : スキームタイプ
     // length    : "http://"等の文字数
@@ -183,7 +199,7 @@ namespace MISC
 
     // 文字コードを coding_from から coding_to に変換
     // 遅いので連続的な処理が必要な時は使わないこと
-    std::string Iconv( const std::string& str, const std::string& coding_from, const std::string& coding_to );
+    std::string Iconv( const std::string& str, const std::string& coding_to, const std::string& coding_from );
 
     // 「&#数字;」形式の数字参照文字列の中の「数字」部分の文字列長
     //
@@ -275,6 +291,14 @@ namespace MISC
     // selfの先頭部分がstartsと等しいか（ヌル終端文字列バージョン）
     // Unicode正規化は行わなずバイト列として比較する
     bool starts_with( const char* self, const char* starts );
+
+    // HTMLからform要素を解析してinput,textarea要素の名前と値を返す
+    std::vector<FormDatum> parse_html_form_data( const std::string& html );
+
+    // HTMLのform要素から action属性(送信先URLのパス) を取得する
+    // 2ch互換板に特化して実装しているため他の掲示板で期待した結果を返す保証はない
+    // 詳細は実装やテストコードを参照
+    std::string parse_html_form_action( const std::string& html );
 }
 
 
