@@ -15,9 +15,9 @@
 // SEE ALSO: ENVIRONMENT::get_jdversion()
 
 #define MAJORVERSION 0
-#define MINORVERSION 4
+#define MINORVERSION 5
 #define MICROVERSION 0
-#define JDDATE_FALLBACK    "20200718"
+#define JDDATE_FALLBACK    "20210109"
 #define JDTAG     ""
 
 //---------------------------------
@@ -25,11 +25,12 @@
 #define JDCOMMENT "JDim (JD improved) は gtkmm/GTK+ を用いた2chブラウザです。"
 #define JDCOPYRIGHT "(c) 2006-2015 JD project" "\n" \
                     "(c) 2017-2019 yama-natuki" "\n" \
-                    "(c) 2019-2020 JDimproved project"
+                    "(c) 2019-2021 JDimproved project"
 #define JDBBS CONFIG::get_url_jdhp()+"cgi-bin/bbs/support/"
 #define JD2CHLOG CONFIG::get_url_jdhp()+"old2ch/"
 #define JDHELP "https://jdimproved.github.io/JDim/"
 #define JDHELPCMD JDHELP "usrcmd/"
+#define JDHELPREPLSTR JDHELP "replacestr/"
 
 // [ ライセンス表記 ]
 //
@@ -54,32 +55,3 @@
     "Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA)。\n"
 
 #endif
-
-//---------------------------------
-// for windres.rc
-#ifndef DEBUG
-#define JDVER_DEBUG             0
-#else
-#define JDVER_DEBUG             VS_FF_DEBUG
-#endif
-
-#define JDVER_FILEVERSION       MAJORVERSION,MINORVERSION,MICROVERSION,0
-#define JDVER_PRODUCTVERSION    JDVER_FILEVERSION
-
-// Two macros expansion is gcc preprocessor technic
-#define JDRC_VERSION_EXP(a,b,c,d,e) JDRC_VERSION_FMT(a,b,c,d,e)
-#define JDRC_VERSION_FMT(a,b,c,d,e) #a "." #b "." #c "-" d e
-#define JDRC_VERSION_STR JDRC_VERSION_EXP( \
-            MAJORVERSION, MINORVERSION, MICROVERSION, JDTAG, JDDATE_FALLBACK)
-
-#define JDRC_FILEVERSION        JDRC_VERSION_STR
-#define JDRC_PRODUCTVERSION     JDRC_FILEVERSION
-
-#define JDRC_PRODUCTNAME        "JD for Linux"
-#define JDRC_INTERNALNAME       "JD"
-#define JDRC_ORIGINALFILENAME   "jd.exe"
-#define JDRC_COMPANYNAME        "JD project"
-#define JDRC_FILEDESCRIPTION    JDRC_PRODUCTNAME
-#define JDRC_COMMENTS           JDRC_PRODUCTNAME
-#define JDRC_LEGALCOPYRIGHT     JDCOPYRIGHT
-
