@@ -17,6 +17,9 @@
 #include "command.h"
 #include "environment.h"
 
+#include <glib/gi18n.h>
+
+
 using namespace CORE;
 
 LinkFilterDiag::LinkFilterDiag( Gtk::Window* parent, const std::string& url, const std::string& cmd )
@@ -44,8 +47,8 @@ LinkFilterDiag::LinkFilterDiag( Gtk::Window* parent, const std::string& url, con
     set_activate_entry( m_entry_url );
     set_activate_entry( m_entry_cmd );
 
-    get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_vbox );
+    get_content_area()->set_spacing( 8 );
+    get_content_area()->pack_start( m_vbox );
 
     set_title( "フィルタ設定" );
     show_all_children();
@@ -61,15 +64,20 @@ void LinkFilterDiag::slot_show_manual()
 
 
 LinkFilterPref::LinkFilterPref( Gtk::Window* parent, const std::string& url )
-    : SKELETON::PrefDiag( parent, url ),
-      m_label( "追加ボタンを押すとフィルタ設定を追加出来ます。編集するにはダブルクリックします。" ),
-      m_button_top( Gtk::Stock::GOTO_TOP ),
-      m_button_up( Gtk::Stock::GO_UP ),
-      m_button_down( Gtk::Stock::GO_DOWN ),
-      m_button_bottom( Gtk::Stock::GOTO_BOTTOM ),
-      m_button_delete( Gtk::Stock::DELETE ),
-      m_button_add( Gtk::Stock::ADD )
+    : SKELETON::PrefDiag( parent, url )
+    , m_label( "追加ボタンを押すとフィルタ設定を追加出来ます。編集するにはダブルクリックします。" )
+    , m_button_top( g_dpgettext( GTK_DOMAIN, "Stock label, navigation\x04_Top", 24 ), true )
+    , m_button_up( g_dpgettext( GTK_DOMAIN, "Stock label, navigation\x04_Up", 24 ), true )
+    , m_button_down( g_dpgettext( GTK_DOMAIN, "Stock label, navigation\x04_Down", 24 ), true )
+    , m_button_bottom( g_dpgettext( GTK_DOMAIN, "Stock label, navigation\x04_Bottom", 24 ), true )
+    , m_button_delete( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Delete", 12 ), true )
+    , m_button_add( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Add", 12 ), true )
 {
+    m_button_top.set_image_from_icon_name( "go-top" );
+    m_button_up.set_image_from_icon_name( "go-up" );
+    m_button_down.set_image_from_icon_name( "go-down" );
+    m_button_bottom.set_image_from_icon_name( "go-bottom" );
+
     m_button_top.signal_clicked().connect( sigc::mem_fun( *this, &LinkFilterPref::slot_top ) );
     m_button_up.signal_clicked().connect( sigc::mem_fun( *this, &LinkFilterPref::slot_up ) );
     m_button_down.signal_clicked().connect( sigc::mem_fun( *this, &LinkFilterPref::slot_down ) );
@@ -110,9 +118,9 @@ LinkFilterPref::LinkFilterPref( Gtk::Window* parent, const std::string& url )
     m_hbox.pack_start( m_scrollwin, Gtk::PACK_EXPAND_WIDGET );
     m_hbox.pack_start( m_vbuttonbox, Gtk::PACK_SHRINK );
 
-    get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_label, Gtk::PACK_SHRINK );
-    get_vbox()->pack_start( m_hbox );
+    get_content_area()->set_spacing( 8 );
+    get_content_area()->pack_start( m_label, Gtk::PACK_SHRINK );
+    get_content_area()->pack_start( m_hbox );
 
     show_all_children();
     set_title( "リンクフィルタ設定" );
