@@ -116,11 +116,7 @@ void restore_bkup( const bool no_restore_bkup )
 // SIGINTのハンドラ
 void sig_handler( int sig )
 {
-#ifdef _WIN32
-    if( sig == SIGINT ){
-#else
     if( sig == SIGHUP || sig == SIGINT || sig == SIGQUIT ){
-#endif
 
 #ifdef _DEBUG
         std::cout << "sig_handler sig = " << sig << std::endl;
@@ -377,9 +373,7 @@ int main( int argc, char **argv )
                 //break;
 
             case 'm':
-#ifndef _WIN32
                 multi_mode = true;
-#endif
                 break;
 
             case 'n':
@@ -400,10 +394,10 @@ int main( int argc, char **argv )
                 query = "(([0-9]*)x([0-9]*))?\\-([0-9]*)\\+([0-9]*)";
                 if( regex.exec( query, optarg, offset, icase, newline, usemigemo, wchar ) ){
 
-                    if( ! regex.str( 2 ).empty() ) init_w = atoi( regex.str( 2 ).c_str() );
-                    if( ! regex.str( 3 ).empty() ) init_h = atoi( regex.str( 3 ).c_str() );
-                    if( ! regex.str( 4 ).empty() ) init_x = atoi( regex.str( 4 ).c_str() );
-                    if( ! regex.str( 5 ).empty() ) init_y = atoi( regex.str( 5 ).c_str() );
+                    if( regex.length( 2 ) ) init_w = atoi( regex.str( 2 ).c_str() );
+                    if( regex.length( 3 ) ) init_h = atoi( regex.str( 3 ).c_str() );
+                    if( regex.length( 4 ) ) init_x = atoi( regex.str( 4 ).c_str() );
+                    if( regex.length( 5 ) ) init_y = atoi( regex.str( 5 ).c_str() );
                 }
                 else usage( EXIT_FAILURE );
 
@@ -435,7 +429,6 @@ int main( int argc, char **argv )
     }
     /*---------------------------------------------------------------*/
 
-#ifndef _WIN32
     // SIGINT、SIGQUITのハンドラ設定
     struct sigaction sigact;
     sigset_t blockset;
@@ -458,7 +451,6 @@ int main( int argc, char **argv )
         fprintf( stderr, "sigaction failed\n" );
         exit( 1 );
     }
-#endif
 
     Gtk::Main m( &argc, &argv );
 
@@ -530,10 +522,11 @@ int main( int argc, char **argv )
         // マルチモードでなく、メインプロセスでもない場合は問い合わせる
         else if( ! multi_mode && ! iomonitor.is_main_process() )
         {
-            Gtk::MessageDialog* mdiag = new Gtk::MessageDialog( "JDimは既に起動しています。起動しますか？",
-                                                                false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-            int ret = mdiag->run();
-            delete mdiag;
+            Gtk::MessageDialog mdiag( "JDimは既に起動しています。起動しますか？\n\n起動中のJDimが存在しない場合\n"
+                                          + CACHE::path_lock() + " を削除してください。",
+                                      false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
+            mdiag.set_title( "ロックファイルが見つかりました" );
+            int ret = mdiag.run();
             if( ret != Gtk::RESPONSE_YES ) return 0;
         }
     }
@@ -546,7 +539,7 @@ int main( int argc, char **argv )
                                                                 false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
 
             Gtk::CheckButton chk_button( "今後表示しない" );
-            mdiag->get_vbox()->pack_start( chk_button, Gtk::PACK_SHRINK );
+            mdiag->get_content_area()->pack_start( chk_button, Gtk::PACK_SHRINK );
             chk_button.show();
 
             const int ret = mdiag->run();
