@@ -18,6 +18,8 @@
 #include "command.h"
 #include "session.h"
 
+#include <glib/gi18n.h>
+
 #include <sstream>
 
 using namespace MESSAGE;
@@ -76,9 +78,9 @@ std::string MessageViewMain::create_message()
                                      false, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE );
 
             mdiag.set_title( "確認" );
-            mdiag.add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
-            mdiag.add_button( Gtk::Stock::REMOVE, Gtk::RESPONSE_DELETE_EVENT );
-            mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+            mdiag.add_button( g_dgettext( GTK_DOMAIN, "_Cancel" ), Gtk::RESPONSE_CANCEL );
+            mdiag.add_button( g_dgettext( GTK_DOMAIN, "_Remove" ), Gtk::RESPONSE_DELETE_EVENT );
+            mdiag.add_button( g_dgettext( GTK_DOMAIN, "_Yes" ), Gtk::RESPONSE_YES );
 
             switch( mdiag.run() )
             {
@@ -104,8 +106,8 @@ std::string MessageViewMain::create_message()
                                  false, Gtk::MESSAGE_WARNING, Gtk::BUTTONS_NONE );
 
         mdiag.set_title( "！！！誤爆注意！！！" );
-        mdiag.add_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
-        mdiag.add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+        mdiag.add_button( g_dgettext( GTK_DOMAIN, "_No" ), Gtk::RESPONSE_NO );
+        mdiag.add_button( g_dgettext( GTK_DOMAIN, "_Yes" ), Gtk::RESPONSE_YES );
         mdiag.add_button( "スレを開く", Gtk::RESPONSE_YES + 100 );
 
         int ret = mdiag.run();
@@ -205,5 +207,5 @@ void MessageViewNew::write_impl( const std::string& msg )
 
 void MessageViewNew::reload()
 {
-    CORE::core_set_command( "open_board", DBTREE::url_subject( get_url() ), "true" );
+    CORE::core_set_command( "open_board", DBTREE::url_boardbase( get_url() ), "true" );
 }
