@@ -18,7 +18,7 @@ namespace MESSAGE
 
       private:
         void write_impl( const std::string& msg ) override;
-        const std::string create_message() override;
+        std::string create_message() override;
     };
 
 
@@ -27,13 +27,13 @@ namespace MESSAGE
     {
       public:
         MessageViewNew( const std::string& url, const std::string& msg );
-        ~MessageViewNew() noexcept {}
+        ~MessageViewNew() noexcept = default;
 
         void reload() override;
 
       private:
         void write_impl( const std::string& msg ) override;
-        const std::string create_message() override;
+        std::string create_message() override;
     };
 
 }
