@@ -85,7 +85,7 @@ MessageViewBase::MessageViewBase( const std::string& url )
     m_max_line = DBTREE::line_number( get_url() ) * 2;
     m_max_str = DBTREE::message_count( get_url() );
 
-    m_iconv = new JDLIB::Iconv( "UTF-8", DBTREE::board_charset( get_url() ) );;
+    m_iconv = new JDLIB::Iconv( DBTREE::board_charset( get_url() ), "UTF-8" );;
 
     m_lng_iconv = m_max_str * 3;
     if( ! m_lng_iconv ) m_lng_iconv = MAX_STR_ICONV;
@@ -229,7 +229,6 @@ void MessageViewBase::init_color()
 {
     if( m_text_message ){
 
-#if GTKMM_CHECK_VERSION(3,0,0)
         if( CONFIG::get_use_message_gtktheme() ) {
             m_text_message->update_style( u8"" );
         }
@@ -253,12 +252,6 @@ void MessageViewBase::init_color()
                 )",
                 classname, fg, bg, caret_prop, sel_fg, sel_bg ) );
         }
-#else
-        m_text_message->modify_text( Gtk::STATE_NORMAL, Gdk::Color( CONFIG::get_color( COLOR_CHAR_MESSAGE ) ) );
-        m_text_message->modify_text( Gtk::STATE_SELECTED, Gdk::Color( CONFIG::get_color( COLOR_CHAR_MESSAGE_SELECTION ) ) );
-        m_text_message->modify_base( Gtk::STATE_NORMAL, Gdk::Color( CONFIG::get_color( COLOR_BACK_MESSAGE ) ) );
-        m_text_message->modify_base( Gtk::STATE_SELECTED, Gdk::Color( CONFIG::get_color( COLOR_BACK_MESSAGE_SELECTION ) ) );
-#endif // GTKMM_CHECK_VERSION(3,0,0)
     }
 }
 
@@ -433,8 +426,8 @@ void MessageViewBase::set_mail()
 void MessageViewBase::pack_widget()
 {
     // 書き込みビュー
-    m_label_name.set_alignment( Gtk::ALIGN_START, Gtk::ALIGN_CENTER );
-    m_label_mail.set_alignment( Gtk::ALIGN_START, Gtk::ALIGN_CENTER );
+    m_label_name.set_xalign( 0 );
+    m_label_mail.set_xalign( 0 );
     m_label_name.set_text( " 名前 " );
     m_label_mail.set_text( " メール " );
 
@@ -887,7 +880,7 @@ void MessageViewBase::post_fin()
 //
 // タブのページが切り替わったら呼ばれるslot
 //
-void MessageViewBase::slot_switch_page( GtkNotebookPage*, guint page )
+void MessageViewBase::slot_switch_page( Gtk::Widget*, guint page )
 {
 #ifdef _DEBUG
     std::cout << "MessageViewBase::slot_switch_page : " << get_url() << " page = " << page << std::endl;
