@@ -2065,7 +2065,7 @@ std::string Admin::get_current_url()
 //
 // notebookのタブのページが切り替わったら呼ばれるslot
 //
-void Admin::slot_switch_page( GtkNotebookPage*, guint page )
+void Admin::slot_switch_page( Gtk::Widget*, guint page )
 {
     // 起動中とシャットダウン中は処理しない
     if( SESSION::is_booting() ) return;
@@ -2721,7 +2721,7 @@ bool Admin::back_forward_viewhistory( const std::string& url, const bool back, c
                                          false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
                 mdiag.add_button( "タブを開く(_T)", Gtk::RESPONSE_YES );
                 if( enable_next ) mdiag.add_button( "次を開く(_N)", Gtk::RESPONSE_NO );
-                mdiag.add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL );
+                mdiag.add_button( g_dgettext( GTK_DOMAIN, "_Cancel" ), Gtk::RESPONSE_CANCEL );
 
                 int ret = mdiag.run();
                 mdiag.hide();
