@@ -30,11 +30,9 @@ CompletionEntry::CompletionEntry( const int mode )
     m_entry.signal_activate().connect( sigc::mem_fun( *this, &CompletionEntry::slot_entry_acivate ) );
     m_entry.signal_changed().connect( sigc::mem_fun( *this, &CompletionEntry::slot_entry_changed ) );
     m_entry.signal_focus_out_event().connect( sigc::mem_fun(*this, &CompletionEntry::slot_entry_focus_out ) );
-#if GTKMM_CHECK_VERSION(3,0,0)
     m_entry.set_max_width_chars( 1 );
     m_entry.set_width_chars( 1 );
     m_entry.set_hexpand( true );
-#endif
     pack_start( m_entry );
 
     // ポップアップ
@@ -155,7 +153,6 @@ void CompletionEntry::show_popup( const bool show_all )
 
     m_treeview.unset_cursor();
     m_treeview.scroll_to_point( -1, 0 );
-#if GTKMM_CHECK_VERSION(3,0,0)
     Gdk::RGBA rgba;
     if( !get_style_context()->lookup_color( "theme_bg_color", rgba ) ) {
 #ifdef _DEBUG
@@ -164,9 +161,6 @@ void CompletionEntry::show_popup( const bool show_all )
 #endif
     }
     m_treeview.get_column_cell_renderer( 0 )->property_cell_background_rgba() = rgba;
-#else
-    m_treeview.get_column_cell_renderer( 0 )->property_cell_background_gdk() = get_style()->get_bg( Gtk::STATE_NORMAL );
-#endif // GTKMM_CHECK_VERSION(3,0,0)
 }
 
 
