@@ -74,167 +74,6 @@ void DragableNoteBook::clock_in()
 }
 
 
-//
-// Auroraなどテーマによっては m_notebook_toolbar が m_notebook_view に上書きされて
-// 消えてしまうのでもう一度 m_notebook_toolbar を描画する
-//
-#if !GTKMM_CHECK_VERSION(3,0,0)
-bool DragableNoteBook::on_expose_event( GdkEventExpose* event )
-{
-    const bool ret =  Gtk::VBox::on_expose_event( event );
-
-    // ツールバー再描画
-   if( m_notebook_toolbar.get_parent() == this ){
-
-        const int min_toolbar_height = 4;
-        const Alloc_NoteBook alloc = get_alloc_notebook();
-        const int y_start = get_show_tabs() ? alloc.y_tabbar + alloc.height_tabbar : alloc.y_toolbar;
-        const int y_end = y_start + alloc.height_toolbar;
-
-        if( alloc.height_toolbar > min_toolbar_height  // ツールバーの中身が表示されている
-            && y_start <= event->area.y + event->area.height && y_end >= event->area.y ){
-
-            GdkEventExpose event_toolbar = *event;
-            if( event_toolbar.area.y < y_start ){
-                event_toolbar.area.height -= ( y_start - event_toolbar.area.y );
-                event_toolbar.area.y = y_start;
-            }
-            if( event_toolbar.area.y + event_toolbar.area.height > y_end ) event_toolbar.area.height = y_end - event_toolbar.area.y;
-
-#ifdef _DEBUG
-            std::cout << "DragableNoteBook::on_expose_event"
-                      << " y_s = " << y_start
-                      << " y_e = " << y_end
-                      << " x = " << event->area.x
-                      << " y = " << event->area.y
-                      << " w = " << event->area.width
-                      << " h = " << event->area.height
-                      << "\n-> x_t = " << event_toolbar.area.x
-                      << " y_t = " << event_toolbar.area.y
-                      << " w_t = " << event_toolbar.area.width
-                      << " h_t = " << event_toolbar.area.height
-                      << std::endl;
-#endif
-            if( event_toolbar.area.height ){
- 
-                propagate_expose( m_notebook_toolbar, &event_toolbar );
-
-                // (注意) Auroraなどテーマによってはクリップ領域( event->area )を無視するものがあり
-                // ビューのスクロールバーが消えてしまう時があるので明示的に再描画する
-                m_notebook_view.redraw_scrollbar();
-            }
-        }
-    }
-    return ret;
-}
-#endif // !GTKMM_CHECK_VERSION(3,0,0)
-
-
-//
-// DragableNoteBook を構成している各Notebookの高さ
-// 及びタブの高さと位置を取得 ( 枠の描画用 )
-//
-#if !GTKMM_CHECK_VERSION(3,0,0)
-Alloc_NoteBook DragableNoteBook::get_alloc_notebook()
-{
-    Alloc_NoteBook alloc;
-
-    m_notebook_tab.get_alloc_tab( alloc );
-
-    alloc.y_tabbar = m_notebook_tab.get_allocation().get_y();
-    alloc.height_tabbar = m_notebook_tab.get_allocation().get_height();
-
-    alloc.y_toolbar = m_notebook_toolbar.get_allocation().get_y();
-    alloc.height_toolbar = m_notebook_toolbar.get_allocation().get_height();
-
-    const int offset_tabbar = ( get_show_tabs() ? alloc.height_tabbar - ( alloc.y_tab + alloc.height_tab ) : 0 );
-    alloc.x_box = m_notebook_view.get_allocation().get_x();
-    alloc.y_box = m_notebook_view.get_allocation().get_y() - alloc.height_toolbar - offset_tabbar;
-    alloc.width_box =m_notebook_view.get_allocation().get_width();
-    alloc.height_box = offset_tabbar + alloc.height_toolbar + m_notebook_view.get_allocation().get_height();
-
-#ifdef _DEBUG
-    std::cout << "DragableNoteBook::get_alloc_notebook"
-              << " x_tab = " << alloc.x_tab
-              << " w_tab = " << alloc.width_tab
-              << " h_tab = " << alloc.height_tab
-              << " y_tabbar = " << alloc.y_tabbar
-              << " h_tabbar = " << alloc.height_tabbar
-              << " y_toolbar = " << alloc.y_toolbar
-              << " h_toolbar = " << alloc.height_toolbar
-              << " x_box = " << alloc.x_box
-              << " y_box = " << alloc.y_box
-              << " w_box = " << alloc.width_box
-              << " h_box = " << alloc.height_box
-              << std::endl;
-#endif
-
-    return alloc;
-}
-#endif // !GTKMM_CHECK_VERSION(3,0,0)
-
-
-//
-// 枠描画
-//
-// gtknotebook.c( Revision 19593, Sat Feb 16 04:09:15 2008 UTC ) からのハック。環境やバージョンによっては問題が出るかもしれないので注意
-//
-#if !GTKMM_CHECK_VERSION(3,0,0)
-void DragableNoteBook::draw_box( Gtk::Widget* widget, GdkEventExpose* event )
-{
-    const Glib::RefPtr<Gdk::Window> win = widget->get_window();
-    const Gdk::Rectangle rect( &(event->area) );
-    Alloc_NoteBook alloc = get_alloc_notebook();
-
-    if( alloc.height_box > 0 ){
-
-        if( get_show_tabs() ){
-
-            // gtk2.18以降？では新しいタブを開くときに一瞬タブが消える場合がある
-            // その場合は保存しておいた座標と高さを利用してboxを描画する
-            if( ! alloc.height_tab ){
-
-                if( ! m_alloc_old.height_tab ) return;
-
-                alloc.y_box = m_alloc_old.y_box;
-                alloc.height_box = m_alloc_old.height_box;
-            }
-            else m_alloc_old = alloc;
-
-            widget->get_style()->paint_box_gap( win,
-                                                Gtk::STATE_NORMAL,
-                                                Gtk::SHADOW_OUT,
-                                                rect,
-                                                *widget,
-                                                "notebook",
-                                                alloc.x_box,
-                                                alloc.y_box,
-                                                alloc.width_box,
-                                                alloc.height_box,
-                                                Gtk::POS_TOP,
-                                                alloc.x_tab,
-                                                alloc.width_tab
-                );
-        }
-        else{
-
-            widget->get_style()->paint_box( win,
-                                            Gtk::STATE_NORMAL,
-                                            Gtk::SHADOW_OUT,
-                                            rect,
-                                            *widget,
-                                            "notebook",
-                                            alloc.x_box,
-                                            alloc.y_box,
-                                            alloc.width_box,
-                                            alloc.height_box
-                );
-        }
-    }
-}
-#endif // !GTKMM_CHECK_VERSION(3,0,0)
-
-
 void DragableNoteBook::set_show_tabs( bool show_tabs )
 {
 #ifdef _DEBUG
@@ -564,7 +403,7 @@ bool DragableNoteBook::adjust_tabwidth()
 //
 // notebook_tabのタブが切り替わったときに呼ばれるslot
 //
-void DragableNoteBook::slot_switch_page_tab( GtkNotebookPage* bookpage, guint page )
+void DragableNoteBook::slot_switch_page_tab( Gtk::Widget* bookpage, guint page )
 {
     // view も切り替える
     m_notebook_view.set_current_page( page );
@@ -683,7 +522,6 @@ bool DragableNoteBook::slot_scroll_event( GdkEventScroll* event )
         next_page = ( get_current_page() + 1 ) % get_n_pages();
         ret = true;
     }
-#if GTKMM_CHECK_VERSION(3,3,18)
     else if( event->direction == GDK_SCROLL_SMOOTH ) {
         constexpr double smooth_scroll_factor{ 4.0 };
         m_smooth_dy += smooth_scroll_factor * event->delta_y;
@@ -698,7 +536,6 @@ bool DragableNoteBook::slot_scroll_event( GdkEventScroll* event )
             m_smooth_dy = 0.0;
         }
     }
-#endif // GTKMM_CHECK_VERSION(3,3,18)
 
     if( ret ) {
         set_current_page( next_page );
