@@ -27,7 +27,7 @@ namespace SKELETON
     class TabLabel;
     class IconPopup;
 
-    typedef sigc::signal< void, GtkNotebookPage*, int > SIG_SWITCH_PAGE;
+    typedef sigc::signal< void, Gtk::Widget*, int > SIG_SWITCH_PAGE;
     typedef sigc::signal< void, int > SIG_TAB_CLICKED;
     typedef sigc::signal< void, int > SIG_TAB_CLOSE;
     typedef sigc::signal< void, int > SIG_TAB_RELOAD;
@@ -95,9 +95,7 @@ namespace SKELETON
 
         Alloc_NoteBook m_alloc_old;
 
-#if GTKMM_CHECK_VERSION(3,3,18)
         double m_smooth_dy{ 0.0 }; // GDK_SCROLL_SMOOTH のスクロール変化量
-#endif
 
       public:
 
@@ -115,11 +113,6 @@ namespace SKELETON
 
         void clock_in();
 
-#if !GTKMM_CHECK_VERSION(3,0,0)
-        // 枠描画
-        void draw_box( Gtk::Widget* widget, GdkEventExpose* event );
-#endif
-
         bool get_show_tabs() const { return m_show_tabs; }
         void set_show_tabs( bool show_tabs );
         void set_scrollable( bool scrollable );
@@ -166,16 +159,6 @@ namespace SKELETON
 
       private:
 
-#if !GTKMM_CHECK_VERSION(3,0,0)
-        bool on_expose_event( GdkEventExpose* event ) override;
-#endif
-
-#if !GTKMM_CHECK_VERSION(3,0,0)
-        // DragableNoteBook を構成している各Notebookの高さ
-        // 及びタブの高さと位置を取得 ( 枠の描画用 )
-        Alloc_NoteBook get_alloc_notebook();
-#endif
-
         // ツールバー取得
         SKELETON::ToolBar* get_toolbar( int page );
 
@@ -183,7 +166,7 @@ namespace SKELETON
         SKELETON::TabLabel* create_tablabel( const std::string& url );
 
         // notebook_tabのタブが切り替わったときに呼び出されるslot
-        void slot_switch_page_tab( GtkNotebookPage*, guint page );
+        void slot_switch_page_tab( Gtk::Widget*, guint page );
 
         // notebook_tab の上でボタンを押した/離した
         bool slot_button_press_event( GdkEventButton* event );
