@@ -32,19 +32,13 @@
 using namespace SKELETON;
 
 
-#if GTKMM_CHECK_VERSION(3,0,0)
 constexpr const char* DragTreeView::s_css_classname;
-#endif
 
 DragTreeView::DragTreeView( const std::string& url, const std::string& dndtarget,
     const bool use_usr_fontcolor, const std::string& fontname, const int colorid_text, const int colorid_bg, const int colorid_bg_even )
-    : JDTreeViewBase(),
-      m_url( url ),
-      m_dndtarget( dndtarget ),
-      m_dragging( false ),
-      m_use_bg_even( false ),
-      m_popup_win( nullptr ),
-      m_popup_shown( false )
+    : JDTreeViewBase()
+    , m_url( url )
+    , m_dndtarget( dndtarget )
 {
 #ifdef _DEBUG
     std::cout << "DragTreeView::DragTreeView\n";
@@ -54,11 +48,9 @@ DragTreeView::DragTreeView( const std::string& url, const std::string& dndtarget
     set_rules_hint( CONFIG::get_use_tree_gtkrc() );
     add_events( Gdk::LEAVE_NOTIFY_MASK );
 
-#if GTKMM_CHECK_VERSION(3,0,0)
     auto context = get_style_context();
     context->add_class( s_css_classname );
     context->add_provider( m_provider, GTK_STYLE_PROVIDER_PRIORITY_APPLICATION );
-#endif
 
     if( use_usr_fontcolor ){
         init_color( colorid_text, colorid_bg, colorid_bg_even );
@@ -126,10 +118,8 @@ void DragTreeView::redraw_view()
 void DragTreeView::init_color( const int colorid_text, const int colorid_bg, const int colorid_bg_even )
 {
     if( CONFIG::get_use_tree_gtkrc() ) {
-#if GTKMM_CHECK_VERSION(3,0,0)
         m_use_bg_even = false;
         m_provider->load_from_data( u8"" );
-#endif
         return;
     }
 
@@ -141,7 +131,6 @@ void DragTreeView::init_color( const int colorid_text, const int colorid_bg, con
     m_use_bg_even = ! ( CONFIG::get_color( colorid_bg ) == CONFIG::get_color( colorid_bg_even ) );
     m_color_bg_even.set( CONFIG::get_color( colorid_bg_even ) );
 
-#if GTKMM_CHECK_VERSION(3,0,0)
     // TreeViewの偶数/奇数行を指定するCSSセレクタは動作しないバージョンが
     // 存在するため偶数行の背景色設定は既存のコードをそのまま使う
     // https://gitlab.gnome.org/GNOME/gtk/issues/581
@@ -156,10 +145,6 @@ void DragTreeView::init_color( const int colorid_text, const int colorid_bg, con
                   << err.what() << std::endl;
 #endif
     }
-#else // !GTKMM_CHECK_VERSION(3,0,0)
-    modify_text( get_state(), m_color_text );
-    modify_base( get_state(), m_color_bg );
-#endif
 }
 
 
@@ -170,11 +155,7 @@ void DragTreeView::init_font( const std::string& fontname )
 {
     Pango::FontDescription pfd( fontname );
     pfd.set_weight( Pango::WEIGHT_NORMAL );
-#if GTKMM_CHECK_VERSION(3,0,0)
     override_font( pfd );
-#else
-    modify_font( pfd );
-#endif
 }
 
 
@@ -504,7 +485,6 @@ void DragTreeView::wheelscroll( GdkEventScroll* event )
 
     if( event->direction == GDK_SCROLL_UP ) val = MAX( 0, val - scr_inc );
     else if( event->direction == GDK_SCROLL_DOWN ) val = MIN( adj->get_upper() - adj->get_page_size(), val + scr_inc );
-#if GTKMM_CHECK_VERSION(3,3,18)
     else if( event->direction == GDK_SCROLL_SMOOTH ) {
         constexpr double smooth_scroll_factor = 4.0;
         m_smooth_dy += smooth_scroll_factor * event->delta_y;
@@ -518,7 +498,6 @@ void DragTreeView::wheelscroll( GdkEventScroll* event )
         auto hadj = get_hadjustment();
         hadj->set_value( hadj->get_value() + scr_inc * smooth_scroll_factor_x * event->delta_x );
     }
-#endif
     adj->set_value( val );
 
 #ifdef _DEBUG
@@ -595,11 +574,7 @@ void DragTreeView::slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel
 
     // 偶数行に色を塗る
     if( even ){
-#if GTKMM_CHECK_VERSION(3,0,0)
         cell->property_cell_background_rgba() = m_color_bg_even;
-#else
-        cell->property_cell_background_gdk() = m_color_bg_even;
-#endif
         cell->property_cell_background_set() = true;
     }
 
