@@ -123,10 +123,8 @@ namespace SKELETON
     class EditView : public Gtk::ScrolledWindow
     {
         EditTextView m_textview;
-#if GTKMM_CHECK_VERSION(3,0,0)
         static constexpr const char* s_css_classname = u8"jd-editview";
         Glib::RefPtr< Gtk::CssProvider > m_provider = Gtk::CssProvider::create();
-#endif
 
     public:
 
@@ -140,38 +138,23 @@ namespace SKELETON
         Glib::RefPtr< Gtk::TextBuffer > get_buffer(){ return m_textview.get_buffer(); }
 
         void set_text( const Glib::ustring& text ){ m_textview.get_buffer()->set_text( text ); }
-        Glib::ustring get_text(){
-#ifdef _WIN32
-            return MISC::utf8_fix_wavedash( m_textview.get_buffer()->get_text(), MISC::WINtoUNIX );
-#else
-            return m_textview.get_buffer()->get_text();
-#endif
-        }
+        Glib::ustring get_text() const { return m_textview.get_buffer()->get_text(); }
 
         void set_wrap_mode( Gtk::WrapMode wrap_mode ){ m_textview.set_wrap_mode( wrap_mode ); }
 
-#if GTKMM_CHECK_VERSION(3,0,0)
         const char* get_css_classname() const noexcept { return s_css_classname; }
         // EditTextViewのスタイルを更新する
         void update_style( const Glib::ustring& custom_css );
-#else
-        void modify_text( Gtk::StateType state, const Gdk::Color& color ){ m_textview.modify_text( state, color ); }
-        void modify_base( Gtk::StateType state, const Gdk::Color& color ){ m_textview.modify_base( state, color ); }
-#endif
 
         void insert_str( const std::string& str, bool use_br ){ m_textview.insert_str( str, use_br ); }
 
         void set_editable( bool editable ){ m_textview.set_editable( editable ); }
         void set_accepts_tab( bool accept ){ m_textview.set_accepts_tab( accept ); }
 
-#if GTKMM_CHECK_VERSION(3,0,0)
         void modify_font( const Pango::FontDescription& font_desc )
         {
             m_textview.override_font( font_desc );
         }
-#else
-        void modify_font( const Pango::FontDescription& font_desc ){ m_textview.modify_font( font_desc ); }
-#endif
 
         void focus_view(){ m_textview.grab_focus(); }
 
