@@ -10,6 +10,8 @@
 #include "dispatchmanager.h"
 #include "global.h"
 
+#include <glib/gi18n.h>
+
 
 using namespace SKELETON;
 
@@ -47,16 +49,9 @@ MsgDiag::MsgDiag( Gtk::Window* parent,
 MsgDiag::~MsgDiag() noexcept = default;
 
 
-void MsgDiag::add_default_button( const Gtk::StockID& stock_id, const int id )
-{
-    Gtk::Button* button = Gtk::manage( new Gtk::Button( stock_id ) );
-    add_default_button( button, id );
-}
-
-
 void MsgDiag::add_default_button( const Glib::ustring& label, const int id )
 {
-    Gtk::Button* button = Gtk::manage( new Gtk::Button( label ) );
+    Gtk::Button* button = Gtk::manage( new Gtk::Button( label, true ) );
     add_default_button( button, id );
 }
 
@@ -153,36 +148,30 @@ MsgCheckDiag::MsgCheckDiag( Gtk::Window* parent,
                 
     Gtk::HBox* hbox = Gtk::manage( new Gtk::HBox );
     hbox->pack_start( m_chkbutton, Gtk::PACK_EXPAND_WIDGET, mrg );
-    get_vbox()->pack_start( *hbox, Gtk::PACK_SHRINK );
-
-    Gtk::Button* button = nullptr;
+    get_content_area()->pack_start( *hbox, Gtk::PACK_SHRINK );
 
     if( buttons == Gtk::BUTTONS_OK ){
 
-        button = Gtk::manage( new Gtk::Button( Gtk::Stock::OK ) );
-        add_default_button( button, Gtk::RESPONSE_OK );
+        add_default_button( g_dgettext( GTK_DOMAIN, "_OK" ), Gtk::RESPONSE_OK );
     }
     else if( buttons == Gtk::BUTTONS_OK_CANCEL ){
-        add_button( Gtk::Stock::NO, Gtk::RESPONSE_CANCEL );
+        add_button( g_dgettext( GTK_DOMAIN, "_No" ), Gtk::RESPONSE_CANCEL );
 
-        button = Gtk::manage( new Gtk::Button( Gtk::Stock::OK ) );
-        add_default_button( button, Gtk::RESPONSE_OK );
+        add_default_button( g_dgettext( GTK_DOMAIN, "_OK" ), Gtk::RESPONSE_OK );
     }
     else if( buttons == Gtk::BUTTONS_YES_NO ){
 
         if( default_response == Gtk::RESPONSE_NO ){
 
-            button = Gtk::manage( new Gtk::Button( Gtk::Stock::NO ) );
-            add_default_button( button, Gtk::RESPONSE_NO );
+            add_default_button( g_dgettext( GTK_DOMAIN, "_No" ), Gtk::RESPONSE_NO );
 
-            add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+            add_button( g_dgettext( GTK_DOMAIN, "_Yes" ), Gtk::RESPONSE_YES );
         }
         else{
 
-            add_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
+            add_button( g_dgettext( GTK_DOMAIN, "_No" ), Gtk::RESPONSE_NO );
 
-            button = Gtk::manage( new Gtk::Button( Gtk::Stock::YES ) );
-            add_default_button( button, Gtk::RESPONSE_YES );
+            add_default_button( g_dgettext( GTK_DOMAIN, "_Yes" ), Gtk::RESPONSE_YES );
         }
     }
 
@@ -201,8 +190,8 @@ MsgOverwriteDiag::MsgOverwriteDiag( Gtk::Window* parent )
     : SKELETON::MsgDiag( parent, "ファイルが存在します。ファイル名を変更して保存しますか？", 
                          false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE )
 {
-    add_button( Gtk::Stock::NO, Gtk::RESPONSE_NO );
-    add_button( Gtk::Stock::YES, Gtk::RESPONSE_YES );
+    add_button( g_dgettext( GTK_DOMAIN, "_No" ), Gtk::RESPONSE_NO );
+    add_button( g_dgettext( GTK_DOMAIN, "_Yes" ), Gtk::RESPONSE_YES );
     add_button( "上書き", OVERWRITE_YES );
     add_button( "すべていいえ", OVERWRITE_NO_ALL );
     add_button( "すべて上書き", OVERWRITE_YES_ALL );
