@@ -11,10 +11,15 @@
 #include "dispatchmanager.h"
 #include "global.h"
 
+#include <glib/gi18n.h>
+
+
 using namespace SKELETON;
 
 PrefDiag::PrefDiag( Gtk::Window* parent, const std::string& url, const bool add_cancel, const bool add_apply, const bool add_open )
-    : Gtk::Dialog(), m_url( url ), m_bt_ok( nullptr ), m_bt_apply( Gtk::Stock::APPLY )
+    : Gtk::Dialog()
+    , m_url( url )
+    , m_bt_apply( g_dgettext( GTK_DOMAIN, "_Apply" ), true )
 {
     if( add_apply ){
         m_bt_apply.signal_clicked().connect( sigc::mem_fun(*this, &PrefDiag::slot_apply_clicked ) );
@@ -23,12 +28,12 @@ PrefDiag::PrefDiag( Gtk::Window* parent, const std::string& url, const bool add_
     }
 
     if( add_cancel ){
-        add_button( Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL )
+        add_button( g_dgettext( GTK_DOMAIN, "_Cancel" ), Gtk::RESPONSE_CANCEL )
         ->signal_clicked().connect( sigc::mem_fun(*this, &PrefDiag::slot_cancel_clicked ) );
     }
 
-    if( add_open ) m_bt_ok = add_button( Gtk::Stock::OPEN, Gtk::RESPONSE_OK );
-    else m_bt_ok = add_button( Gtk::Stock::OK, Gtk::RESPONSE_OK );
+    if( add_open ) m_bt_ok = add_button( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Open", 12 ), Gtk::RESPONSE_OK );
+    else m_bt_ok = add_button( g_dgettext( GTK_DOMAIN, "_OK" ), Gtk::RESPONSE_OK );
 
     m_bt_ok->signal_clicked().connect( sigc::mem_fun(*this, &PrefDiag::slot_ok_clicked ) );
 
@@ -97,7 +102,6 @@ int PrefDiag::run(){
 
 
 // ダイアログのサイズをデフォルトのスクリーンに対する比率で設定する
-#if GTKMM_CHECK_VERSION(3,0,0)
 void PrefDiag::set_default_size_ratio( double ratio )
 {
     const auto screen = Gdk::Screen::get_default();
@@ -105,7 +109,6 @@ void PrefDiag::set_default_size_ratio( double ratio )
     const int height = static_cast< int >( screen->get_height() * ratio );
     Gtk::Dialog::set_default_size( width, height );
 }
-#endif
 
 
 // タイマーのslot関数
