@@ -11,22 +11,31 @@
 #include "global.h"
 #include "session.h"
 
+#include <glib/gi18n.h>
+
+
 using namespace SKELETON;
 
 #define ROW_COLOR "WhiteSmoke"
 
 SelectItemPref::SelectItemPref( Gtk::Window* parent, const std::string& url )
-    : SKELETON::PrefDiag( parent, url, true, true ),
-      m_button_top( Gtk::Stock::GOTO_TOP ),
-      m_button_up( Gtk::Stock::GO_UP ),
-      m_button_down( Gtk::Stock::GO_DOWN ),
-      m_button_bottom( Gtk::Stock::GOTO_BOTTOM ),
-      m_button_delete( Gtk::Stock::GO_FORWARD, std::string(), Gtk::ICON_SIZE_BUTTON ),
-      m_button_add( Gtk::Stock::GO_BACK, std::string(), Gtk::ICON_SIZE_BUTTON ),
-      m_button_default( Gtk::Stock::REVERT_TO_SAVED )
+    : SKELETON::PrefDiag( parent, url, true, true )
+    , m_button_top( g_dpgettext( GTK_DOMAIN, "Stock label, navigation\x04_Top", 24 ), true )
+    , m_button_up( g_dpgettext( GTK_DOMAIN, "Stock label, navigation\x04_Up", 24 ), true )
+    , m_button_down( g_dpgettext( GTK_DOMAIN, "Stock label, navigation\x04_Down", 24 ), true )
+    , m_button_bottom( g_dpgettext( GTK_DOMAIN, "Stock label, navigation\x04_Bottom", 24 ), true )
+    , m_button_default( g_dpgettext( GTK_DOMAIN, "Stock label\x04_Revert", 12 ), true )
 {
     m_list_default_data.clear();
 
+    m_button_top.set_image_from_icon_name( "go-top" );
+    m_button_up.set_image_from_icon_name( "go-up" );
+    m_button_down.set_image_from_icon_name( "go-down" );
+    m_button_bottom.set_image_from_icon_name( "go-bottom" );
+
+    m_button_delete.set_image_from_icon_name( "go-next" );
+    m_button_add.set_image_from_icon_name( "go-previous" );
+
     pack_widgets();
 }
 
@@ -124,8 +133,8 @@ void SelectItemPref::pack_widgets()
 
     m_hbox.pack_start( m_scroll_hidden, Gtk::PACK_EXPAND_WIDGET );
 
-    get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_hbox );
+    get_content_area()->set_spacing( 8 );
+    get_content_area()->pack_start( m_hbox );
 
     show_all_children();
 }
