@@ -22,10 +22,9 @@ namespace SKELETON
 {
     class TextLoader : public SKELETON::Loadable
     {
-        bool m_loaded; // 読み込み済みか
+        bool m_loaded{}; // 読み込み済みか
 
-        char* m_rawdata;
-        int m_lng_rawdata;
+        std::string m_rawdata;
         std::string m_data;
 
       public:
@@ -64,6 +63,9 @@ namespace SKELETON
 
         void receive_data( const char* data, size_t size ) override;
         void receive_finish() override;
+
+        // HTTP応答ヘッダーのクッキーを取り扱う場合は派生クラスでoverrideする
+        virtual void receive_cookies() {}
     };
 }
 
