@@ -2,6 +2,8 @@
 //
 // DragableNoteBookを構成するview表示用の Notebook
 //
+// TODO: 使われなくなったコンストラクタの引数を整理する
+// TODO: 使われなくなった SKELETON::View::redraw_scrollbar() を整理する
 
 #ifndef _VIEWNOTE_H
 #define _VIEWNOTE_H
@@ -14,22 +16,10 @@ namespace SKELETON
 
     class ViewNotebook : public Gtk::Notebook
     {
-#if !GTKMM_CHECK_VERSION(3,0,0)
-        DragableNoteBook* m_parent;
-#endif
-
       public:
 
-        explicit ViewNotebook( DragableNoteBook* parent );
+        explicit ViewNotebook( DragableNoteBook* );
         ~ViewNotebook() noexcept;
-
-        void redraw_scrollbar();
-
-#if !GTKMM_CHECK_VERSION(3,0,0)
-      protected:
-
-        bool on_expose_event( GdkEventExpose* event ) override;
-#endif
     };
 }
 
