@@ -3,12 +3,12 @@
 #ifndef _URLREPLACEMANAGER_H
 #define _URLREPLACEMANAGER_H
 
-#include <string>
-#include <list>
-#include <map>
-
 #include "jdlib/jdregex.h"
 
+#include <string>
+#include <vector>
+
+
 namespace CORE
 {
     enum
@@ -24,7 +24,7 @@ namespace CORE
 
     struct UrlreplaceItem
     {
-        std::string match;
+        JDLIB::RegexPattern creg;
         std::string replace;
         std::string referer;
         int imgctrl;
@@ -33,8 +33,7 @@ namespace CORE
 
     class Urlreplace_Manager
     {
-        std::list< UrlreplaceItem > m_list_cmd;
-        std::map< std::string, int > m_map_imgctrl; // 画像コントロールのキャッシュ
+        std::vector<UrlreplaceItem> m_list_cmd;
 
       public:
 
@@ -45,7 +44,7 @@ namespace CORE
         bool exec( std::string& url );
 
         // URLからリファラを求める
-        bool referer( const std::string& url, std::string& referer );
+        bool referer( const std::string& url, std::string& refstr );
 
         // URLの画像コントロールを取得する
         int get_imgctrl( const std::string& url );
@@ -53,10 +52,6 @@ namespace CORE
       private:
 
         void conf2list( const std::string& conf );
-        int get_imgctrl_impl( const std::string& url );
-
-        // 置換文字列を変換
-        void replace( JDLIB::Regex& regex, std::string& str );
     };
 
     ///////////////////////////////////////
