@@ -46,8 +46,8 @@ UsrCmdDiag::UsrCmdDiag( Gtk::Window* parent, const Glib::ustring& name, const Gl
     m_vbox.pack_start( m_hbox_cmd, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_entry_cmd, Gtk::PACK_SHRINK );
 
-    get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_vbox );
+    get_content_area()->set_spacing( 8 );
+    get_content_area()->pack_start( m_vbox );
 
     set_activate_entry( m_entry_name );
     set_activate_entry( m_entry_cmd );
@@ -87,12 +87,12 @@ UsrCmdPref::UsrCmdPref( Gtk::Window* parent, const std::string& url )
     m_scrollwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
     m_scrollwin.set_size_request( 640, 400 );
 
-    get_vbox()->set_spacing( 8 );
-    get_vbox()->pack_start( m_label, Gtk::PACK_SHRINK );
-    get_vbox()->pack_start( m_scrollwin );
+    get_content_area()->set_spacing( 8 );
+    get_content_area()->pack_start( m_label, Gtk::PACK_SHRINK );
+    get_content_area()->pack_start( m_scrollwin );
 
     m_ckbt_hide_usrcmd.set_active( CONFIG::get_hide_usrcmd() );
-    get_vbox()->pack_start( m_ckbt_hide_usrcmd, Gtk::PACK_SHRINK );
+    get_content_area()->pack_start( m_ckbt_hide_usrcmd, Gtk::PACK_SHRINK );
 
     // ポップアップメニュー
     m_action_group = Gtk::ActionGroup::create();
