@@ -21,7 +21,7 @@ namespace XML
       public:
 
         // 文字列を元にノードツリーを作る場合( html = HTMLモード )
-        Document( const std::string& str, const bool html = false );
+        explicit Document( const std::string& str, const bool html = false );
 
         // Gtk::TreeStore を元にノードツリーを作る場合
         // ただし列は SKELETON::EditColumns を継承したものであること
@@ -44,10 +44,10 @@ namespace XML
         // Gtk::TreeStore をセットする
         // ただし列は SKELETON::EditColumns を継承したものであること
         void set_treestore( Glib::RefPtr< Gtk::TreeStore >& treestore, SKELETON::EditColumns& columns,
-                            const std::string& root_name, std::list< Gtk::TreePath >& list_path_expand );
+                            const std::string& root_name, std::list< Gtk::TreePath >& list_path_expand ) const;
 
         // ルート要素を取得する
-        Dom* get_root_element( const std::string& node_name = std::string() );
+        Dom* get_root_element( const std::string& node_name = std::string() ) const;
     };
 }
 
