@@ -46,7 +46,7 @@ Dom::Dom( const int type, const std::string& name, const bool html )
 }
 
 // デストラクタ
-Dom::~Dom()
+Dom::~Dom() noexcept
 {
 #ifdef _DEBUG
     std::cout << "~Dom() : " << m_nodeName << ", " << m_childNodes.size() << std::endl;
@@ -71,15 +71,12 @@ Dom::Dom( const Dom& dom )
 //
 // 子ノードのクリア
 //
-void Dom::clear()
+void Dom::clear() noexcept
 {
-    std::list< Dom* >::iterator it = m_childNodes.begin();
-    while( it != m_childNodes.end() )
+    for( Dom* child : m_childNodes )
     {
-        if( *it ) delete *it;
-        ++it;
+        if( child ) delete child;
     }
-
     m_childNodes.clear();
 }
 
@@ -91,7 +88,7 @@ void Dom::parse( const std::string& str )
 {
     if( str.empty() || str.size() > SIZE_OF_RAWDATA ) return;
 
-    size_t current_pos = 0, tag_lt_pos = 0, tag_gt_pos = 0;
+    size_t current_pos = 0;
     const size_t str_length = str.length();
 
     while( current_pos < str_length )
@@ -104,7 +101,7 @@ void Dom::parse( const std::string& str )
         std::string next_source;
 
         // "<"を探す
-        tag_lt_pos = str.find( '<', current_pos );
+        const std::size_t tag_lt_pos = str.find( '<', current_pos );
 
         // タグの前のテキストノード
         if( current_pos < tag_lt_pos )
@@ -125,20 +122,22 @@ void Dom::parse( const std::string& str )
         // 要素ノード
         else if( current_pos == tag_lt_pos )
         {
-            tag_gt_pos = str.find( '>', tag_lt_pos + 1 );
+            const std::size_t tag_gt_pos = str.find( '>', tag_lt_pos + 1 );
 
             current_pos = tag_gt_pos + 1;
 
             // 開始タグの中身( <element attr="value"> )を取り出す
             std::string open_tag = str.substr( tag_lt_pos + 1, tag_gt_pos - tag_lt_pos - 1 );
+            if( open_tag.empty() ) continue;
 
-            // タグの中身がアルファベットで始まっているか
-            bool is_alpha = ( ( open_tag[0] >= 'A' && open_tag[0] <= 'Z' ) || ( open_tag[0] >= 'a' && open_tag[0] <= 'z' ) );
+            // タグの中身がアルファベットで始まっているかチェック
+            if( !( open_tag[0] >= 'A' && open_tag[0] <= 'Z' ) && !( open_tag[0] >= 'a' && open_tag[0] <= 'z' ) ) {
+                continue;
+            }
 
             // タグ構造が壊れてる場合
             size_t broken_pos = 0;
-            if( open_tag.empty() || ! is_alpha ) continue;
-            else if( ( broken_pos = open_tag.find( '<' ) ) != std::string::npos )
+            if( ( broken_pos = open_tag.find( '<' ) ) != std::string::npos )
             {
                  current_pos += broken_pos;
                  continue;
@@ -206,7 +205,7 @@ void Dom::parse( const std::string& str )
                     else if( close_tag.compare( 0, name.length() + 1, "/" + name ) == 0 ) --count;
 
                     // 終了タグを見つける必要数が 0 になったらループを抜ける
-                    if( count <= 0 ) break;
+                    if( count == 0 ) break;
                 }
 
                 // 必要な終了タグが見付からないまま上記のループを抜けた場合は、全体のループを抜ける
@@ -221,19 +220,17 @@ void Dom::parse( const std::string& str )
         std::cout << "Dom:parse():---------------------------------------\n";
         std::cout << "nodeName : " << name << "\n";
         std::cout << "nodeType : " << type << "\n";
-        std::map< std::string, std::string >::iterator it = attributes_pair.begin();
-        while( it != attributes_pair.end() )
+        for( const auto& attr : attributes_pair )
         {
-            std::cout << "Attribute: " << "name=" << (*it).first << ", value=" << (*it).second << std::endl;
-            ++it;
+            std::cout << "Attribute: " << "name=" << attr.first << ", value=" << attr.second << std::endl;
         }
         std::cout << "nodeValue: " << value << std::endl;
 #endif
 
         // ノードを追加
         Dom* node = appendChild( type, name );
-        node->attributes( attributes_pair );
-        node->nodeValue( value );
+        node->m_attributes = std::move( attributes_pair );
+        node->m_nodeValue = std::move( value );
 
         // 再帰
         if( ! next_source.empty() ) node->parse( next_source );
@@ -244,7 +241,7 @@ void Dom::parse( const std::string& str )
 //
 // 属性ペアのリストを作成
 //
-std::map< std::string, std::string > Dom::create_attribute( const std::string& str )
+std::map< std::string, std::string > Dom::create_attribute( const std::string& str ) const
 {
     std::map< std::string, std::string > attributes_pair;
 
@@ -352,12 +349,6 @@ std::string Dom::get_xml( const int n ) const
     // テキストノードの文字列
     std::string text;
 
-    // 属性
-    std::map< std::string, std::string >::const_iterator attr_it = m_attributes.cbegin();
-
-    // 子要素
-    std::list< Dom* >::const_iterator child_it = m_childNodes.cbegin();
-
     // ノードの種類別に処理
     switch( m_nodeType )
     {
@@ -371,10 +362,9 @@ std::string Dom::get_xml( const int n ) const
             xml << indent << "<" << m_nodeName;
 
             // 属性を追加
-            while( attr_it != m_attributes.cend() )
+            for( const auto& attr : m_attributes )
             {
-                xml << " " << (*attr_it).first << "=\"" << (*attr_it).second << "\"";
-                ++attr_it;
+                xml << " " << attr.first << "=\"" << attr.second << "\"";
             }
 
             // 子要素がある場合
@@ -382,11 +372,10 @@ std::string Dom::get_xml( const int n ) const
             {
                 xml << ">\n";
 
-                while( child_it != m_childNodes.cend() )
+                for( const Dom* child : m_childNodes )
                 {
                     // 子要素をたどる
-                    xml << (*child_it)->get_xml( n + 2 );
-                    ++child_it;
+                    xml << child->get_xml( n + 2 );
                 }
 
                 xml << indent << "</" << m_nodeName << ">\n";
@@ -414,11 +403,10 @@ std::string Dom::get_xml( const int n ) const
 
             if( ! m_childNodes.empty() ) xml << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
 
-            while( child_it != m_childNodes.cend() )
+            for( const Dom* child : m_childNodes )
             {
                 // 子要素をたどる
-                xml << (*child_it)->get_xml();
-                ++child_it;
+                xml << child->get_xml();
             }
 
             break;
@@ -438,16 +426,13 @@ void Dom::parse( const Gtk::TreeModel::Children& children, SKELETON::EditColumns
     if( children.empty() ) return;
 
     // Gtk::TreeModel::Children を走査
-    Gtk::TreeModel::iterator it = children.begin();
-    while( it != children.end() )
+    for( const Gtk::TreeModel::Row& row : children )
     {
-        Gtk::TreeModel::Row row = *it;
-
         // 各値を取得( skeleton/editcolumns.h を参照 )
         const int type = row[ columns.m_type ];
-        const Glib::ustring url = row[ columns.m_url ];
-        const Glib::ustring data = row[ columns.m_data ];
-        const Glib::ustring name = row[ columns.m_name ];
+        const Glib::ustring& url = row[ columns.m_url ];
+        const Glib::ustring& data = row[ columns.m_data ];
+        const Glib::ustring& name = row[ columns.m_name ];
         const size_t dirid = row[ columns.m_dirid ];
         const bool expand = row[ columns.m_expand ];
 
@@ -466,11 +451,10 @@ void Dom::parse( const Gtk::TreeModel::Children& children, SKELETON::EditColumns
                 if( dirid ) node->setAttribute( "dirid", dirid );
 
                 // 再帰
-                if( ! row.children().empty() ) node->parse( row.children(), columns );
+                const Gtk::TreeModel::Children sub_children = row.children();
+                if( ! sub_children.empty() ) node->parse( sub_children, columns );
             }
         }
-
-        ++it;
     }
 }
 
@@ -484,18 +468,17 @@ void Dom::parse( const Gtk::TreeModel::Children& children, SKELETON::EditColumns
 //
 void Dom::append_treestore( Glib::RefPtr< Gtk::TreeStore >& treestore,
                             SKELETON::EditColumns& columns,
-                             std::list< Gtk::TreePath >& list_path_expand,
-                             const Gtk::TreeModel::Row& parent )
+                            std::list< Gtk::TreePath >& list_path_expand,
+                            const Gtk::TreeModel::Row& parent ) const
 {
     // ノードの子要素を走査
-    std::list< Dom* >::iterator it = m_childNodes.begin();
-    while( it != m_childNodes.end() )
+    for( const Dom* child : m_childNodes )
     {
-        const int node_type = (*it)->nodeType();
+        const int node_type = child->nodeType();
 
         if( node_type == NODE_TYPE_ELEMENT )
         {
-            const int type = XML::get_type( (*it)->nodeName() );
+            const int type = XML::get_type( child->nodeName() );
 
             if( type != TYPE_UNKNOWN )
             {
@@ -506,51 +489,25 @@ void Dom::append_treestore( Glib::RefPtr< Gtk::TreeStore >& treestore,
                 else row = *( treestore->append() );
 
                 // 各値をセット
-                columns.setup_row( row, (*it)->getAttribute( "url" ), (*it)->getAttribute( "name" ), (*it)->getAttribute( "data" ), type, 0 );
+                columns.setup_row( row, child->getAttribute( "url" ), child->getAttribute( "name" ),
+                                   child->getAttribute( "data" ), type, 0 );
 
                 if( type == TYPE_DIR ){
 
-                    row[ columns.m_dirid ] = atoi( (*it)->getAttribute( "dirid" ).c_str() );
+                    row[ columns.m_dirid ] = atoi( child->getAttribute( "dirid" ).c_str() );
 
                     // 開いているツリーを追加
-                    if( (*it)->getAttribute( "open" ) == "y" ) list_path_expand.push_back( treestore->get_path( row ) );
+                    if( child->getAttribute( "open" ) == "y" ) list_path_expand.push_back( treestore->get_path( row ) );
                 }
 
                 // 再帰
-                if( (*it)->hasChildNodes() ) (*it)->append_treestore( treestore, columns, list_path_expand, row );
+                if( child->hasChildNodes() ) child->append_treestore( treestore, columns, list_path_expand, row );
             }
         }
-
-        ++it;
     }
 }
 
 
-
-//
-// プロパティを扱うアクセッサ
-//
-int Dom::nodeType()
-{
-    return m_nodeType;
-}
-
-std::string Dom::nodeName()
-{
-    return m_nodeName;
-}
-
-std::string Dom::nodeValue()
-{
-    return m_nodeValue;
-}
-
-void Dom::nodeValue( const std::string& value )
-{
-    m_nodeValue = value;
-}
-
-
 //
 // getElementById()
 //
@@ -558,18 +515,16 @@ Dom* Dom::getElementById( const std::string& id ) const
 {
     Dom* node = nullptr;
 
-    std::list< Dom* >::const_iterator it = m_childNodes.cbegin();
-    while( it != m_childNodes.cend() )
+    for( Dom* child : m_childNodes )
     {
-        if( (*it)->nodeType() == NODE_TYPE_ELEMENT )
+        if( child->nodeType() == NODE_TYPE_ELEMENT )
         {
-            if( (*it)->getAttribute( "id" ) == id ) node = *it;
+            if( child->getAttribute( "id" ) == id ) node = child;
             // 再帰
-            else if( (*it)->hasChildNodes() ) node = (*it)->getElementById( id );
+            else if( child->hasChildNodes() ) node = child->getElementById( id );
 
             if( node ) break;
         }
-        ++it;
     }
 
     return node;
@@ -579,82 +534,35 @@ Dom* Dom::getElementById( const std::string& id ) const
 //
 // getElementsByTagName()
 //
-DomList Dom::getElementsByTagName( const std::string& name ) const
+std::list<Dom*> Dom::getElementsByTagName( const std::string& name ) const
 {
-    DomList domlist;
+    std::list<Dom*> domlist;
 
-    std::list< Dom* >::const_iterator it = m_childNodes.cbegin();
-    while( it != m_childNodes.cend() )
+    for( Dom* child : m_childNodes )
     {
-        if( (*it)->nodeType() == NODE_TYPE_ELEMENT )
+        if( child->nodeType() == NODE_TYPE_ELEMENT )
         {
-            if( (*it)->nodeName() == name ) domlist.push_back( *it );
+            if( child->nodeName() == name ) domlist.push_back( child );
 
             // 再帰
-            DomList sub_nodes = (*it)->getElementsByTagName( name );
-            domlist.splice( domlist.end(), sub_nodes );
+            std::list<Dom*> sub_nodes = child->getElementsByTagName( name );
+            domlist.splice( domlist.end(), std::move( sub_nodes ) );
         }
-        ++it;
     }
 
     return domlist;
 }
 
 
-//
-// ノード：ownerDocument
-//
-Dom* Dom::ownerDocument() const
-{
-    Dom* parent = m_parentNode;
-
-    while( parent )
-    {
-        if( parent->nodeType() == NODE_TYPE_DOCUMENT ) break;
-        else parent = parent->parentNode();
-    }
-
-    return parent;    
-}
-
-
-//
-// ノード：parentNode
-//
-Dom* Dom::parentNode()
-{
-    return m_parentNode;
-}
-
-void Dom::parentNode( Dom* parent )
-{
-    m_parentNode = parent;
-}
-
-
 //
 // ノード：hasChildNodes
 //
-bool Dom::hasChildNodes()
+bool Dom::hasChildNodes() const noexcept
 {
     return ! m_childNodes.empty();
 }
 
 
-//
-// ノード：childNodes
-//
-DomList Dom::childNodes() const
-{
-    DomList result;
-
-    // DomList に std::list< Dom* > を代入している
-    result = m_childNodes;
-
-    return result;
-}
-
-
 //
 // dom の子ノードをコピーする
 //
@@ -662,24 +570,15 @@ void Dom::copy_childNodes( const Dom& dom )
 {
     clear();
 
-    DomList children;
-    children = dom.m_childNodes;
+    for( const Dom* child : dom.m_childNodes )
+    {
+        Dom* node = new Dom( child->m_nodeType, child->m_nodeName );
+        node->m_nodeValue = child->m_nodeValue;
+        node->m_parentNode = this;
+        node->m_attributes = child->m_attributes;
+        node->copy_childNodes( *child );
 
-    if( children.size() ){
-
-        std::list< Dom* >::iterator it = children.begin();
-        while( it != children.end() )
-        {
-            Dom* node = new Dom( (*it)->nodeType(), (*it)->nodeName() );
-            node->nodeValue( (*it)->nodeValue() );
-            node->parentNode( this );
-            node->attributes( (*it)->attributes() );
-            node->copy_childNodes( *(*it) );
-
-            m_childNodes.push_back( node );
-
-            ++it;
-        }
+        m_childNodes.push_back( node );
     }
 }
 
@@ -695,31 +594,14 @@ Dom* Dom::firstChild() const
 }
 
 
-//
-// ノード：lastChild
-//
-Dom* Dom::lastChild() const
-{
-    if( m_childNodes.empty() ) return nullptr;
-
-    return m_childNodes.back();
-}
-
-
 //
 // ノード：appendChild()
 //
 Dom* Dom::appendChild( const int node_type, const std::string& node_name )
 {
-    Dom* node = nullptr;
-    
-    {
-        node = new Dom( node_type, node_name, m_html );
-
-        node->parentNode( this );
-
-        m_childNodes.push_back( node );
-    }
+    Dom* node = new Dom( node_type, node_name, m_html );
+    node->m_parentNode = this;
+    m_childNodes.push_back( node );
 
     return node;
 }
@@ -733,149 +615,32 @@ bool Dom::removeChild( Dom* node )
     if( ! node ) return false;
 
     m_childNodes.remove( node );
-
-    if( node ) delete node;
+    delete node;
 
     return true;
 }
 
 
-//
-// ノード：replaceChild()
-//
-Dom* Dom::replaceChild( const int node_type, const std::string& node_name, Dom* oldNode )
-{
-    Dom* newNode = nullptr;
-
-    newNode = new Dom( node_type, node_name );
-
-    std::list< Dom* >::iterator it = m_childNodes.begin();
-    while( it != m_childNodes.end() )
-    {
-        if( *it == oldNode )
-        {
-            newNode->parentNode( oldNode->parentNode() );
-            m_childNodes.erase( it );
-            m_childNodes.insert( it, newNode );
-            break;
-        }
-        ++it;
-    }
-
-    if( oldNode ) delete oldNode;
-
-    return newNode;
-}
-
-
 //
 // ノード：insertBefore()
 //
 Dom* Dom::insertBefore( const int node_type, const std::string& node_name, Dom* insNode )
 {
+    if( ! insNode ) return appendChild( node_type, node_name );
+
     Dom* newNode = nullptr;
 
-    newNode = new Dom( node_type, node_name );
-
-    std::list< Dom* >::iterator it = m_childNodes.begin();
-    while( it != m_childNodes.end() )
+    const auto it = std::find( m_childNodes.begin(), m_childNodes.end(), insNode );
+    if( it != m_childNodes.end() )
     {
-        if( *it == insNode )
-        {
-            newNode->parentNode( insNode->parentNode() );
-            m_childNodes.insert( it, newNode );
-            break;
-        }
-        ++it;
+        newNode = new Dom( node_type, node_name );
+        newNode->m_parentNode = insNode->m_parentNode;
+        m_childNodes.insert( it, newNode );
     }
-
     return newNode;
 }
 
 
-//
-// ノード：previousSibling
-//
-Dom* Dom::previousSibling() const
-{
-    Dom* previous = nullptr;
-
-    DomList brothers = m_parentNode->childNodes();
-
-    std::list< Dom* >::iterator it = brothers.begin();
-    while( it != brothers.end() )
-    {
-        if( it != brothers.begin() && *it == this )
-        {
-            previous = *( --it );
-            break;
-        }
-        ++it;
-    }
-
-    return previous;
-}
-
-
-//
-// ノード：nextSibling
-//
-Dom* Dom::nextSibling() const
-{
-    Dom* next = nullptr;
-
-    DomList brothers = m_parentNode->childNodes();
-
-    std::list< Dom* >::iterator it = brothers.begin();
-    while( it != brothers.end() )
-    {
-        if( *it == this )
-        {
-            ++it;
-            if( it != brothers.end() ) next = *it;
-            break;
-        }
-        ++it;
-    }
-
-    return next;
-}
-
-
-//
-// 属性：attributes
-//
-std::map< std::string, std::string > Dom::attributes()
-{
-    return m_attributes;
-}
-
-void Dom::attributes( const std::map< std::string, std::string > attributes )
-{
-    if( ! attributes.empty() ) m_attributes = attributes;
-}
-
-
-//
-// 属性：hasAttributes()
-//
-bool Dom::hasAttributes()
-{
-    return ! m_attributes.empty();
-}
-
-
-//
-// 属性：hasAttribute()
-//
-bool Dom::hasAttribute( const std::string& name ) const
-{
-    if( name.empty() ) return false;
-
-    return m_attributes.find( name ) != m_attributes.end();
-}
-
-
 //
 // 属性：getAttribute()
 //
@@ -926,25 +691,3 @@ bool Dom::setAttribute( const std::string& name, const int value )
 
     return true;
 }
-
-
-//
-// 属性：removeAttribute()
-//
-bool Dom::removeAttribute( const std::string& name )
-{
-    bool result = false;
-
-    if( name.empty() ) return result;
-
-    std::map< std::string, std::string >::iterator it = m_attributes.find( name );
-
-    if( it != m_attributes.end() )
-    {
-        m_attributes.erase( it );
-        result = true;
-    }
-
-    return result;
-}
-
