@@ -11,7 +11,6 @@
 #include <set>
 #include <gtkmm.h>
 
-#include "domlist.h"
 
 namespace SKELETON
 {
@@ -30,8 +29,6 @@ namespace XML
         NODE_TYPE_DOCUMENT
     };
 
-    class DomList;
-
     class Dom
     {
         // HTMLの時に空要素として扱う要素を格納する
@@ -55,10 +52,10 @@ namespace XML
       private:
 
         // このクラスの代入演算子は使わない
-        Dom& operator=( const Dom& );
+        Dom& operator=( const Dom& ) = delete;
 
         // 属性ペアのリストを作成
-        std::map< std::string, std::string > create_attribute( const std::string& str );
+        std::map< std::string, std::string > create_attribute( const std::string& str ) const;
 
       protected:
 
@@ -73,37 +70,37 @@ namespace XML
         void parse( const Gtk::TreeModel::Children& children, SKELETON::EditColumns& columns );
 
         // プロパティをセットするアクセッサ
-        void parentNode( Dom* parent );
+        void parentNode( Dom* parent ) = delete;
         void copy_childNodes( const Dom& dom ); // dom の子ノードをコピーする
 
         // ノードを分解して Gtk::TreeStore へ Gtk::TreeModel::Row を追加
         // ただし列は SKELETON::EditColumns を継承したものであること
         void append_treestore( Glib::RefPtr< Gtk::TreeStore >& treestore,
                                SKELETON::EditColumns& columns,
-                                std::list< Gtk::TreePath >& list_path_expand,
-                                const Gtk::TreeModel::Row& parnet = Gtk::TreeModel::Row() );
+                               std::list< Gtk::TreePath >& list_path_expand,
+                               const Gtk::TreeModel::Row& parnet = Gtk::TreeModel::Row() ) const;
 
       public:
 
         // コンストラクタ、デストラクタ
         Dom( const int type, const std::string& name, const bool html = false );
-        virtual ~Dom();
+        virtual ~Dom() noexcept;
 
         // クリア
-        void clear();
+        void clear() noexcept;
 
         // XMLタグ構造の文字列を生成
         std::string get_xml( const int n = 0 ) const;
 
         // getElement(s)By*()
         Dom* getElementById( const std::string& id ) const;
-        DomList getElementsByTagName( const std::string& name ) const;
+        std::list<Dom*> getElementsByTagName( const std::string& name ) const;
 
         // プロパティを扱うアクセッサ
-        int nodeType();
-        std::string nodeName();
-        std::string nodeValue();
-        void nodeValue( const std::string& value );
+        int nodeType() const noexcept { return m_nodeType; }
+        std::string nodeName() const { return m_nodeName; }
+        std::string nodeValue() const { return m_nodeValue; }
+        void nodeValue( const std::string& value ) { m_nodeValue = value; }
 
         // ノード
         // 注意：appendChild(), replaceChild(), insertBefore() は
@@ -112,29 +109,31 @@ namespace XML
         // delete忘れを防ぐために外部でnewしない方が良いだろうという
         // 事で、メンバ関数の内部でnewして追加されたノードのポインタ
         // を返すようにしてあります。
+        //
+        // クラス外で使用していないメンバ関数は削除してあります。
 
-        Dom* ownerDocument() const;
-        Dom* parentNode();
-        bool hasChildNodes();
-        DomList childNodes() const;
+        Dom* ownerDocument() const noexcept = delete;
+        Dom* parentNode() const noexcept = delete;
+        bool hasChildNodes() const noexcept;
+        std::list<Dom*> childNodes() const { return m_childNodes; }
         Dom* firstChild() const;
-        Dom* lastChild() const;
+        Dom* lastChild() const = delete;
         Dom* appendChild( const int node_type, const std::string& node_name );
         bool removeChild( Dom* node );
-        Dom* replaceChild( const int node_type, const std::string& node_name, Dom* oldNode );
+        Dom* replaceChild( const int node_type, const std::string& node_name, Dom* oldNode ) = delete;
         Dom* insertBefore( const int node_type, const std::string& node_name, Dom* insNode );
-        Dom* previousSibling() const;
-        Dom* nextSibling() const;
+        Dom* previousSibling() const = delete;
+        Dom* nextSibling() const = delete;
 
         // 属性
-        bool hasAttributes();
-        std::map< std::string, std::string > attributes();
-        void attributes( const std::map< std::string, std::string > attributes );
-        bool hasAttribute( const std::string& name ) const;
+        bool hasAttributes() const noexcept = delete;
+        std::map< std::string, std::string > attributes() const = delete;
+        void attributes( std::map< std::string, std::string > attributes ) = delete;
+        bool hasAttribute( const std::string& name ) const = delete;
         std::string getAttribute( const std::string& name ) const;
         bool setAttribute( const std::string& name, const std::string& value );
         bool setAttribute( const std::string& name, const int value );
-        bool removeAttribute( const std::string& name );
+        bool removeAttribute( const std::string& name ) = delete;
     };
 }
 
