@@ -542,4 +542,277 @@ TEST_F(MISC_StartsWith, null_terminated_string)
     EXPECT_FALSE( MISC::starts_with( "hello", "helloworld" ) );
 }
 
+
+class MISC_ParseHtmlFormData : public ::testing::Test {};
+
+TEST_F(MISC_ParseHtmlFormData, empty_html)
+{
+    auto result = MISC::parse_html_form_data( std::string{} );
+    EXPECT_TRUE( result.empty() );
+}
+
+TEST_F(MISC_ParseHtmlFormData, hidden_datum)
+{
+    auto result = MISC::parse_html_form_data( "<input type=hidden name=FOO value=100>" );
+    decltype(result) expect{ { "FOO", "100" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, hidden_datum_uppercase)
+{
+    auto result = MISC::parse_html_form_data( "<INPUT TYPE=hidden NAME=FOO VALUE=100>" );
+    decltype(result) expect{ { "FOO", "100" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, hidden_datum_with_double_quotes)
+{
+    auto result = MISC::parse_html_form_data( R"(<input type="hidden" name="FOO" value="100">)" );
+    decltype(result) expect{ { "FOO", "100" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, submit_datum)
+{
+    auto result = MISC::parse_html_form_data( "<input type=submit value=書き込む name=submit>" );
+    decltype(result) expect{ { "submit", "書き込む" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, submit_datum_with_double_quotes)
+{
+    auto result = MISC::parse_html_form_data( R"(<input type="submit" value="書き込む" name="submit">)" );
+    decltype(result) expect{ { "submit", "書き込む" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, textarea_datum)
+{
+    auto result = MISC::parse_html_form_data( "<textarea name=MESSAGE>あかさたな</textarea>" );
+    decltype(result) expect{ { "MESSAGE", "あかさたな" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, textarea_have_tag)
+{
+    auto result = MISC::parse_html_form_data( "<textarea name=MESSAGE>あか<br>さたな</textarea>" );
+    decltype(result) expect{ { "MESSAGE", "あか<br>さたな" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, textarea_datum_uppercase)
+{
+    auto result = MISC::parse_html_form_data( "<TEXTAREA NAME=MESSAGE>あかさたな</TEXTAREA>" );
+    decltype(result) expect{ { "MESSAGE", "あかさたな" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, textarea_datum_with_double_quotes)
+{
+    auto result = MISC::parse_html_form_data( R"(<textarea name="MESSAGE">"あかさたな"</textarea>)" );
+    decltype(result) expect{ { "MESSAGE", "あかさたな" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, multi_data_1)
+{
+    auto result = MISC::parse_html_form_data( R"(<textarea name="MESSAGE">"あかさたな"</textarea>)"
+                                              "<input type=submit value=書き込む name=submit>"
+                                              R"(<input type="hidden" name="FOO" value="100">)" );
+    decltype(result) expect{ { "MESSAGE", "あかさたな" }, { "submit", "書き込む" }, { "FOO", "100" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, multi_data_2)
+{
+    auto result = MISC::parse_html_form_data( "<input type=submit value=書き込む name=submit>"
+                                              R"(<input type="hidden" name="FOO" value="100">)"
+                                              R"(<textarea name="MESSAGE">"あかさたな"</textarea>)" );
+    decltype(result) expect{ { "submit", "書き込む" }, { "FOO", "100" }, { "MESSAGE", "あかさたな" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, multi_data_3)
+{
+    auto result = MISC::parse_html_form_data( R"(<input type="hidden" name="FOO" value="100">)"
+                                              R"(<textarea name="MESSAGE">"あかさたな"</textarea>)"
+                                              "<input type=submit value=書き込む name=submit>" );
+    decltype(result) expect{ { "FOO", "100" }, { "MESSAGE", "あかさたな" }, { "submit", "書き込む" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, hidden_empty_name_by_double_quotes)
+{
+    auto result = MISC::parse_html_form_data( R"(<input type="hidden" name="" value="100">)" );
+    decltype(result) expect{ { std::string{}, "100" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, hidden_empty_value_by_double_quotes)
+{
+    auto result = MISC::parse_html_form_data( R"(<input type="hidden" name=FOO value="">)" );
+    decltype(result) expect{ { "FOO", std::string{} } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, submit_empty_name_by_double_quotes)
+{
+    auto result = MISC::parse_html_form_data( R"(<input type="submit" value=書き込む name="">)" );
+    decltype(result) expect{ { std::string{}, "書き込む" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, submit_empty_value_by_double_quotes)
+{
+    auto result = MISC::parse_html_form_data( R"(<input type="submit" value="" name=submit>)" );
+    decltype(result) expect{ { "submit", std::string{} } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, textarea_empty_name_by_double_quotes)
+{
+    auto result = MISC::parse_html_form_data( R"(<textarea name="">あかさたな</textarea>)" );
+    decltype(result) expect{ { std::string{}, "あかさたな" } };
+    EXPECT_EQ( result, expect );
+}
+
+TEST_F(MISC_ParseHtmlFormData, textarea_empty_value_by_double_quotes)
+{
+    auto result = MISC::parse_html_form_data( R"(<textarea name="MESSAGE"></textarea>)" );
+    decltype(result) expect{ { "MESSAGE", std::string{} } };
+    EXPECT_EQ( result, expect );
+}
+
+
+class MISC_ParseHtmlFormActionTest : public ::testing::Test {};
+
+TEST_F(MISC_ParseHtmlFormActionTest, empty_html)
+{
+    std::string result = MISC::parse_html_form_action( std::string{} );
+    EXPECT_EQ( result, std::string{} );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, unquote_post)
+{
+    const std::string html = R"(<form method=POST action="/test/bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, "/test/bbs.cgi" );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, quote_post)
+{
+    const std::string html = R"(<form method="POST" action="/test/bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, "/test/bbs.cgi" );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, subbbscgi)
+{
+    const std::string html = R"(<form method="POST" action="/test/subbbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, "/test/subbbs.cgi" );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, with_parameter)
+{
+    const std::string html = R"(<form method="POST" action="/test/bbs.cgi?foo=bar">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, "/test/bbs.cgi?foo=bar" );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, ignore_attributes)
+{
+    const std::string html = R"(<form method="POST" accept-charset="Shift_JIS" action="/test/bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, "/test/bbs.cgi" );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, relative_path_an_upper_order)
+{
+    const std::string html = R"(<form method="POST" action="../test/bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, "/test/bbs.cgi" );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, relative_path_same_hierarchy)
+{
+    std::string html = R"(<form method="POST" action="./bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, "/test/bbs.cgi" );
+
+    html = R"(<form method="POST" action="./subbbs.cgi">")";
+    result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, "/test/subbbs.cgi" );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, relative_path_double_upper_orders)
+{
+    const std::string html = R"(<form method="POST" action="../../test/bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, std::string{} );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, relative_path_middle_upper_order)
+{
+    const std::string html = R"(<form method="POST" action="/test/../bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, std::string{} );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, absolute_path_without_scheme)
+{
+    const std::string html = R"(<form method="POST" action="//example.test/test/bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, std::string{} );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, http_url)
+{
+    const std::string html = R"(<form method="POST" action="http://example.test/test/bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, std::string{} );
+}
+
+TEST_F(MISC_ParseHtmlFormActionTest, https_url)
+{
+    const std::string html = R"(<form method="POST" action="https://example.test/test/bbs.cgi">")";
+    std::string result = MISC::parse_html_form_action( html );
+    EXPECT_EQ( result, std::string{} );
+}
+
+
+class ChrefDecodeTest : public ::testing::Test {};
+
+TEST_F(ChrefDecodeTest, empty)
+{
+    const std::string result = MISC::chref_decode( std::string{}, true );
+    EXPECT_EQ( result, std::string{} );
+}
+
+TEST_F(ChrefDecodeTest, decimal_hello)
+{
+    const std::string result = MISC::chref_decode( std::string{ "&#104;&#101;&#108;&#108;&#111;" }, true );
+    EXPECT_EQ( result, "hello" );
+}
+
+TEST_F(ChrefDecodeTest, hexadecimal_hello)
+{
+    const std::string result = MISC::chref_decode( std::string{ "&#x68;&#x65;&#X6c;&#x6C;&#x6f;" }, true );
+    EXPECT_EQ( result, "hello" );
+}
+
+TEST_F(ChrefDecodeTest, escape_html_char_completely)
+{
+    const std::string input = "&#60;&#62;&#38;&#34; &#x3c;&#x3e;&#x26;&#x22; &lt;&gt;&amp;&quot;";
+    const std::string result = MISC::chref_decode( input, true );
+    EXPECT_EQ( result, R"(<>&" <>&" <>&")" );
+}
+
+TEST_F(ChrefDecodeTest, escape_html_char_keeping)
+{
+    const std::string input = "&#60;&#62;&#38;&#34; &#x3c;&#x3e;&#x26;&#x22; &lt;&gt;&amp;&quot;";
+    const std::string result = MISC::chref_decode( input, false );
+    EXPECT_EQ( result, "&lt;&gt;&amp;&quot; &lt;&gt;&amp;&quot; &lt;&gt;&amp;&quot;" );
+}
+
 } // namespace
